@@ -117,6 +117,16 @@ public class DefaultSaveModeHandler implements SaveModeHandler {
         }
     }
 
+    @Override
+    public void handleSchemaSaveModeWithRestore() {
+        if (SchemaSaveMode.ERROR_WHEN_SCHEMA_NOT_EXIST == schemaSaveMode) {
+            errorWhenSchemaNotExist();
+        } else if (SchemaSaveMode.CREATE_SCHEMA_WHEN_NOT_EXIST == schemaSaveMode
+                || SchemaSaveMode.RECREATE_SCHEMA == schemaSaveMode) {
+            createSchemaWhenNotExist();
+        }
+    }
+
     protected void recreateSchema() {
         if (tableExists()) {
             dropTable();
