@@ -163,6 +163,7 @@ public class PhysicalColumn extends Column {
             Object defaultValue,
             String comment,
             String sourceType,
+            String sinkType,
             Map<String, Object> options,
             boolean isUnsigned,
             boolean isZeroFill,
@@ -177,6 +178,7 @@ public class PhysicalColumn extends Column {
                 defaultValue,
                 comment,
                 sourceType,
+                sinkType,
                 options,
                 isUnsigned,
                 isZeroFill,
@@ -297,6 +299,7 @@ public class PhysicalColumn extends Column {
                 defaultValue,
                 comment,
                 sourceType,
+                sinkType,
                 options,
                 isUnsigned,
                 isZeroFill,
@@ -315,6 +318,7 @@ public class PhysicalColumn extends Column {
                 defaultValue,
                 comment,
                 sourceType,
+                sinkType,
                 options,
                 isUnsigned,
                 isZeroFill,
@@ -333,6 +337,7 @@ public class PhysicalColumn extends Column {
                 defaultValue,
                 comment,
                 sourceType,
+                sinkType,
                 options,
                 isUnsigned,
                 isZeroFill,
@@ -351,6 +356,7 @@ public class PhysicalColumn extends Column {
                 defaultValue,
                 comment,
                 newSourceType,
+                sinkType,
                 options,
                 isUnsigned,
                 isZeroFill,
