@@ -17,6 +17,8 @@
 
 package org.apache.seatunnel.api.table.type;
 
+import org.apache.seatunnel.shade.com.google.common.collect.Maps;
+
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 
@@ -43,6 +45,9 @@ public class SeaTunnelRowTest {
                         new Object[] {
                             1, "test", 1L, new BigDecimal("3333.333"),
                         }));
+
+        Map<String, Object> objectMap = Maps.newHashMap();
+        objectMap.put("name", "cosmos");
         SeaTunnelRow row =
                 new SeaTunnelRow(
                         new Object[] {
@@ -58,7 +63,8 @@ public class SeaTunnelRowTest {
                             new Float[] {1F, 2F},
                             new Boolean[] {Boolean.TRUE, Boolean.FALSE},
                             new Byte[] {1, 2, 3, 4},
-                            new Short[] {Short.parseShort("1")}
+                            new Short[] {Short.parseShort("1")},
+                            new Map[] {objectMap}
                         });
 
         SeaTunnelRow row2 =
@@ -76,14 +82,15 @@ public class SeaTunnelRowTest {
                             new Float[] {1F, 2F, null},
                             new Boolean[] {Boolean.TRUE, Boolean.FALSE, null},
                             new Byte[] {1, 2, 3, 4, null},
-                            new Short[] {Short.parseShort("1"), null}
+                            new Short[] {Short.parseShort("1"), null},
+                            new Map[] {objectMap}
                         });
 
         SeaTunnelRowType rowType =
                 new SeaTunnelRowType(
                         new String[] {
                             "f0", "f1", "f2", "f3", "f4", "f5", "f6", "f7", "f8", "f9", "f10",
-                            "f11", "f12"
+                            "f11", "f12", "f13"
                         },
                         new SeaTunnelDataType<?>[] {
                             BasicType.INT_TYPE,
@@ -107,14 +114,17 @@ public class SeaTunnelRowTest {
                             ArrayType.FLOAT_ARRAY_TYPE,
                             ArrayType.BOOLEAN_ARRAY_TYPE,
                             ArrayType.BYTE_ARRAY_TYPE,
-                            ArrayType.SHORT_ARRAY_TYPE
+                            ArrayType.SHORT_ARRAY_TYPE,
+                            new ArrayType<>(
+                                    Map[].class,
+                                    new MapType<>(BasicType.STRING_TYPE, BasicType.STRING_TYPE))
                         });
 
-        Assertions.assertEquals(249, row.getBytesSize(rowType));
-        Assertions.assertEquals(249, row.getBytesSize());
+        Assertions.assertEquals(259, row.getBytesSize(rowType));
+        Assertions.assertEquals(259, row.getBytesSize());
 
-        Assertions.assertEquals(249, row2.getBytesSize(rowType));
-        Assertions.assertEquals(249, row2.getBytesSize());
+        Assertions.assertEquals(259, row2.getBytesSize(rowType));
+        Assertions.assertEquals(259, row2.getBytesSize());
     }
 
     @Test
