@@ -189,19 +189,7 @@ public class ConnectorOptionCheckTest {
 
     private Set<String> buildWhiteList() {
         Set<String> whiteList = new HashSet<>();
-        whiteList.add("JdbcSinkOptions");
-        whiteList.add("TypesenseSourceOptions");
-        whiteList.add("TypesenseSinkOptions");
-        whiteList.add("PulsarSinkOptions");
-        whiteList.add("PulsarSourceOptions");
         whiteList.add("MongodbSinkOptions");
-        whiteList.add("RocketMqSinkOptions");
-        whiteList.add("SocketSinkOptions");
-        whiteList.add("SelectDBSinkOptions");
-        whiteList.add("RocketMqSourceOptions");
-        whiteList.add("TablestoreSinkOptions");
-        whiteList.add("TableStoreDBSourceOptions");
-        whiteList.add("SocketSourceOptions");
         whiteList.add("PostgresIncrementalSourceOptions");
         whiteList.add("SqlServerIncrementalSourceOptions");
         whiteList.add("OracleIncrementalSourceOptions");
