@@ -46,7 +46,8 @@ public class AllFileSpecificationCheckTest {
     @BeforeAll
     public static void beforeAll() throws IOException {
         List<String> fileTypesCanNotRead =
-                Arrays.asList("parquet", "orc", "xlsx", "xls", "png", "jar", "lzo", "zip", "ico");
+                Arrays.asList(
+                        "parquet", "orc", "xlsx", "xls", "png", "jar", "lzo", "zip", "ico", "jks");
         List<String> fileCanNotRead =
                 Arrays.asList(
                         "seatunnel-connectors-v2/connector-file/connector-file-base/src/test/resources/encoding/gbk.json",
