@@ -22,6 +22,7 @@ import org.apache.seatunnel.connectors.cdc.base.source.IncrementalSource;
 import io.debezium.relational.RelationalDatabaseConnectorConfig;
 
 import java.util.List;
+import java.util.Map;
 import java.util.Properties;
 
 /**
@@ -49,6 +50,7 @@ public abstract class JdbcSourceConfig extends BaseSourceConfig {
             List<String> databaseList,
             List<String> tableList,
             int splitSize,
+            Map<String, String> splitColumn,
             double distributionFactorUpper,
             double distributionFactorLower,
             int sampleShardingThreshold,
@@ -70,6 +72,7 @@ public abstract class JdbcSourceConfig extends BaseSourceConfig {
                 startupConfig,
                 stopConfig,
                 splitSize,
+                splitColumn,
                 distributionFactorUpper,
                 distributionFactorLower,
                 sampleShardingThreshold,
