@@ -68,4 +68,20 @@ public class ClickhouseTable implements Serializable {
             return tableName;
         }
     }
+
+    public String getLocalDatabase() {
+        if (distributedEngine != null) {
+            return distributedEngine.getDatabase();
+        } else {
+            return database;
+        }
+    }
+
+    public String getLocalTableIdentifier() {
+        if (distributedEngine != null) {
+            return String.format("%s.%s", getLocalDatabase(), getLocalTableName());
+        } else {
+            return String.format("%s.%s", database, tableName);
+        }
+    }
 }
