@@ -18,6 +18,9 @@
 package org.apache.seatunnel.connectors.seatunnel.clickhouse.util;
 
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
+import org.apache.seatunnel.api.table.catalog.TablePath;
+import org.apache.seatunnel.api.table.type.SeaTunnelRow;
+import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
 import org.apache.seatunnel.connectors.seatunnel.clickhouse.config.ClickhouseBaseOptions;
 
 import org.apache.commons.collections4.MapUtils;
@@ -26,12 +29,20 @@ import org.apache.commons.lang3.StringUtils;
 import com.clickhouse.client.ClickHouseCredentials;
 import com.clickhouse.client.ClickHouseNode;
 import com.clickhouse.client.ClickHouseProtocol;
+import com.clickhouse.client.ClickHouseRecord;
+import lombok.extern.slf4j.Slf4j;
+import net.sf.jsqlparser.JSQLParserException;
+import net.sf.jsqlparser.parser.CCJSqlParserUtil;
+import net.sf.jsqlparser.statement.Statement;
+import net.sf.jsqlparser.util.TablesNamesFinder;
 
 import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.util.stream.Collectors;
 
+@Slf4j
 public class ClickhouseUtil {
 
     public static List<ClickHouseNode> createNodes(ReadonlyConfig config) {
@@ -81,4 +92,39 @@ public class ClickhouseUtil {
                         })
                 .collect(Collectors.toList());
     }
+
+    public static SeaTunnelRow convertToSeaTunnelRow(
+            ClickHouseRecord record, SeaTunnelRowType seaTunnelRowType, String tableId) {
+        Object[] values = new Object[seaTunnelRowType.getFieldNames().length];
+        for (int i = 0; i < record.size(); i++) {
+            if (record.getValue(i) == null || record.getValue(i).isNullOrEmpty()) {
+                values[i] = null;
+            } else {
+                values[i] =
+                        TypeConvertUtil.valueUnwrap(
+                                seaTunnelRowType.getFieldType(i), record.getValue(i));
+            }
+        }
+        SeaTunnelRow seaTunnelRow = new SeaTunnelRow(values);
+        seaTunnelRow.setTableId(tableId);
+        return seaTunnelRow;
+    }
+
+    public static TablePath extractTablePathFromSql(String sql) {
+        try {
+            Statement statement = CCJSqlParserUtil.parse(sql);
+
+            TablesNamesFinder tablesNamesFinder = new TablesNamesFinder();
+            Set<String> tableNames = tablesNamesFinder.getTables(statement);
+            if (tableNames.size() == 1) {
+                String tableFullName = tableNames.iterator().next();
+                return TablePath.of(tableFullName);
+            }
+
+            return TablePath.DEFAULT;
+        } catch (JSQLParserException e) {
+            log.warn("Failed to parse SQL statement: {}, exception: {}", sql, e);
+            return TablePath.DEFAULT;
+        }
+    }
 }
