@@ -60,7 +60,8 @@ public class DorisCreateTableTest {
         columns.add(
                 PhysicalColumn.of(
                         "age", BasicType.INT_TYPE, (Long) null, true, null, "test comment"));
-        columns.add(PhysicalColumn.of("score", BasicType.INT_TYPE, (Long) null, true, null, ""));
+        columns.add(
+                PhysicalColumn.of("score", BasicType.INT_TYPE, (Long) null, true, null, "'N'-N"));
         columns.add(PhysicalColumn.of("gender", BasicType.BYTE_TYPE, (Long) null, true, null, ""));
         columns.add(
                 PhysicalColumn.of("create_time", BasicType.LONG_TYPE, (Long) null, true, null, ""));
@@ -119,13 +120,13 @@ public class DorisCreateTableTest {
                                         .build(),
                                 Collections.emptyMap(),
                                 Collections.emptyList(),
-                                ""),
+                                "doris test comment"),
                         DorisTypeConverterV1.INSTANCE);
         Assertions.assertEquals(
                 result,
                 "CREATE TABLE IF NOT EXISTS `test1`.`test2` (                                                                                                                                                   \n"
                         + "`id` BIGINT NULL ,`age` INT NULL COMMENT 'test comment'  ,       \n"
-                        + "`name` STRING NULL ,`score` INT NULL  , \n"
+                        + "`name` STRING NULL ,`score` INT NULL COMMENT '''N''-N' , \n"
                         + "`create_time` DATETIME NOT NULL ,  \n"
                         + "`gender` TINYINT NULL   \n"
                         + ") ENGINE=OLAP  \n"
@@ -153,7 +154,7 @@ public class DorisCreateTableTest {
                                 .build(),
                         Collections.emptyMap(),
                         Collections.emptyList(),
-                        "");
+                        "doris test comment");
         TablePath tablePath = TablePath.of("test1.test2");
         SeaTunnelRuntimeException actualSeaTunnelRuntimeException =
                 Assertions.assertThrows(
@@ -263,7 +264,7 @@ public class DorisCreateTableTest {
                                         .build(),
                                 Collections.emptyMap(),
                                 Collections.emptyList(),
-                                ""),
+                                "doris test comment"),
                         DorisTypeConverterV1.INSTANCE);
         String expected =
                 "CREATE TABLE IF NOT EXISTS `tpch`.`lineitem` (\n"
@@ -328,7 +329,7 @@ public class DorisCreateTableTest {
                                         .build(),
                                 Collections.emptyMap(),
                                 Collections.emptyList(),
-                                ""),
+                                "doris test comment"),
                         DorisTypeConverterV1.INSTANCE);
 
         Assertions.assertEquals(
@@ -380,7 +381,7 @@ public class DorisCreateTableTest {
                                         .build(),
                                 Collections.emptyMap(),
                                 Collections.emptyList(),
-                                ""),
+                                "doris test comment"),
                         DorisTypeConverterV1.INSTANCE);
 
         Assertions.assertEquals(
@@ -394,4 +395,123 @@ public class DorisCreateTableTest {
                         + " partitioned by `id`,`age`,`name`;",
                 result);
     }
+
+    @Test
+    public void testTableComment() {
+        List<Column> columns = new ArrayList<>();
+
+        columns.add(
+                PhysicalColumn.of(
+                        "id",
+                        BasicType.LONG_TYPE,
+                        (Long) null,
+                        true,
+                        null,
+                        "This is the ID column"));
+        columns.add(
+                PhysicalColumn.of(
+                        "name",
+                        BasicType.STRING_TYPE,
+                        (Long) null,
+                        true,
+                        null,
+                        "This is the name column"));
+        columns.add(
+                PhysicalColumn.of(
+                        "age",
+                        BasicType.INT_TYPE,
+                        (Long) null,
+                        true,
+                        null,
+                        "This is the age column"));
+        columns.add(PhysicalColumn.of("score", BasicType.INT_TYPE, (Long) null, true, null, ""));
+        columns.add(
+                PhysicalColumn.of(
+                        "gender",
+                        BasicType.BYTE_TYPE,
+                        (Long) null,
+                        true,
+                        null,
+                        "This is the gender column"));
+        columns.add(
+                PhysicalColumn.of(
+                        "create_time",
+                        BasicType.LONG_TYPE,
+                        (Long) null,
+                        true,
+                        null,
+                        "This is the create_time column"));
+
+        String result =
+                DorisCatalogUtil.getCreateTableStatement(
+                        "CREATE TABLE IF NOT EXISTS `${database}`.`${table}` (\n"
+                                + "${rowtype_primary_key},\n"
+                                + "${rowtype_fields}\n"
+                                + ") ENGINE=OLAP\n"
+                                + " UNIQUE KEY (${rowtype_primary_key})\n"
+                                + "COMMENT '${comment}'\n"
+                                + "DISTRIBUTED BY HASH (${rowtype_primary_key})\n"
+                                + " PROPERTIES (\n"
+                                + "\"replication_allocation\" = \"tag.location.default: 1\",\n"
+                                + "\"in_memory\" = \"false\",\n"
+                                + "\"storage_format\" = \"V2\",\n"
+                                + "\"disable_auto_compaction\" = \"false\"\n"
+                                + ")",
+                        TablePath.of("test1.test2"),
+                        CatalogTable.of(
+                                TableIdentifier.of("test", "test1", "test2"),
+                                TableSchema.builder()
+                                        .primaryKey(PrimaryKey.of("", Arrays.asList("id", "age")))
+                                        .constraintKey(
+                                                Arrays.asList(
+                                                        ConstraintKey.of(
+                                                                ConstraintKey.ConstraintType
+                                                                        .UNIQUE_KEY,
+                                                                "unique_key",
+                                                                Collections.singletonList(
+                                                                        ConstraintKey
+                                                                                .ConstraintKeyColumn
+                                                                                .of(
+                                                                                        "name",
+                                                                                        ConstraintKey
+                                                                                                .ColumnSortType
+                                                                                                .DESC))),
+                                                        ConstraintKey.of(
+                                                                ConstraintKey.ConstraintType
+                                                                        .UNIQUE_KEY,
+                                                                "unique_key2",
+                                                                Collections.singletonList(
+                                                                        ConstraintKey
+                                                                                .ConstraintKeyColumn
+                                                                                .of(
+                                                                                        "score",
+                                                                                        ConstraintKey
+                                                                                                .ColumnSortType
+                                                                                                .ASC)))))
+                                        .columns(columns)
+                                        .build(),
+                                Collections.emptyMap(),
+                                Collections.emptyList(),
+                                "doris test comment"),
+                        DorisTypeConverterV1.INSTANCE);
+
+        Assertions.assertEquals(
+                result,
+                "CREATE TABLE IF NOT EXISTS `test1`.`test2` (\n"
+                        + "`id` BIGINT NULL COMMENT 'This is the ID column',`age` INT NULL COMMENT 'This is the age column',\n"
+                        + "`name` STRING NULL COMMENT 'This is the name column',\n"
+                        + "`score` INT NULL ,\n"
+                        + "`gender` TINYINT NULL COMMENT 'This is the gender column',\n"
+                        + "`create_time` BIGINT NULL COMMENT 'This is the create_time column'\n"
+                        + ") ENGINE=OLAP\n"
+                        + " UNIQUE KEY (`id`,`age`)\n"
+                        + "COMMENT 'doris test comment'\n"
+                        + "DISTRIBUTED BY HASH (`id`,`age`)\n"
+                        + " PROPERTIES (\n"
+                        + "\"replication_allocation\" = \"tag.location.default: 1\",\n"
+                        + "\"in_memory\" = \"false\",\n"
+                        + "\"storage_format\" = \"V2\",\n"
+                        + "\"disable_auto_compaction\" = \"false\"\n"
+                        + ")");
+    }
 }
