@@ -19,11 +19,11 @@ package org.apache.seatunnel.connectors.seatunnel.file.hdfs.source.config;
 
 import org.apache.seatunnel.api.configuration.Option;
 import org.apache.seatunnel.api.configuration.Options;
-import org.apache.seatunnel.connectors.seatunnel.file.config.BaseSourceConfigOptions;
+import org.apache.seatunnel.connectors.seatunnel.file.config.FileBaseSourceOptions;
 
 import static org.apache.hadoop.fs.CommonConfigurationKeysPublic.FS_DEFAULT_NAME_KEY;
 
-public class HdfsSourceConfigOptions extends BaseSourceConfigOptions {
+public class HdfsSourceConfigOptions extends FileBaseSourceOptions {
     public static final Option<String> DEFAULT_FS =
             Options.key(FS_DEFAULT_NAME_KEY)
                     .stringType()
