@@ -20,7 +20,7 @@ package org.apache.seatunnel.connectors.seatunnel.file.config;
 import org.apache.seatunnel.shade.com.google.common.collect.Lists;
 
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
-import org.apache.seatunnel.api.table.catalog.schema.TableSchemaOptions;
+import org.apache.seatunnel.api.options.ConnectorCommonOptions;
 
 import lombok.Getter;
 
@@ -35,7 +35,7 @@ public abstract class BaseMultipleTableFileSourceConfig implements Serializable
     @Getter private List<BaseFileSourceConfig> fileSourceConfigs;
 
     public BaseMultipleTableFileSourceConfig(ReadonlyConfig fileSourceRootConfig) {
-        if (fileSourceRootConfig.getOptional(TableSchemaOptions.TABLE_CONFIGS).isPresent()) {
+        if (fileSourceRootConfig.getOptional(ConnectorCommonOptions.TABLE_CONFIGS).isPresent()) {
             parseFromFileSourceConfigs(fileSourceRootConfig);
         } else {
             parseFromFileSourceConfig(fileSourceRootConfig);
@@ -44,7 +44,7 @@ public abstract class BaseMultipleTableFileSourceConfig implements Serializable
 
     private void parseFromFileSourceConfigs(ReadonlyConfig fileSourceRootConfig) {
         this.fileSourceConfigs =
-                fileSourceRootConfig.get(TableSchemaOptions.TABLE_CONFIGS).stream()
+                fileSourceRootConfig.get(ConnectorCommonOptions.TABLE_CONFIGS).stream()
                         .map(ReadonlyConfig::fromMap)
                         .map(this::getBaseSourceConfig)
                         .collect(Collectors.toList());
