@@ -38,6 +38,7 @@ import org.apache.seatunnel.format.csv.processor.CsvLineProcessor;
 import org.apache.seatunnel.format.csv.processor.DefaultCsvLineProcessor;
 
 import org.apache.commons.csv.CSVFormat;
+import org.apache.commons.csv.CSVFormat.Builder;
 import org.apache.commons.csv.CSVParser;
 import org.apache.commons.csv.CSVRecord;
 
@@ -57,10 +58,12 @@ import java.util.stream.Collectors;
 @Slf4j
 public class CsvReadStrategy extends AbstractReadStrategy {
     private CsvDeserializationSchema deserializationSchema;
-    private DateUtils.Formatter dateFormat = FileBaseSourceOptions.DATE_FORMAT.defaultValue();
+    private DateUtils.Formatter dateFormat =
+            FileBaseSourceOptions.DATE_FORMAT_LEGACY.defaultValue();
     private DateTimeUtils.Formatter datetimeFormat =
-            FileBaseSourceOptions.DATETIME_FORMAT.defaultValue();
-    private TimeUtils.Formatter timeFormat = FileBaseSourceOptions.TIME_FORMAT.defaultValue();
+            FileBaseSourceOptions.DATETIME_FORMAT_LEGACY.defaultValue();
+    private TimeUtils.Formatter timeFormat =
+            FileBaseSourceOptions.TIME_FORMAT_LEGACY.defaultValue();
     private CompressFormat compressFormat = FileBaseSourceOptions.COMPRESS_CODEC.defaultValue();
     private CsvLineProcessor processor;
     private int[] indexes;
@@ -100,8 +103,9 @@ public class CsvReadStrategy extends AbstractReadStrategy {
                 actualInputStream = inputStream;
                 break;
         }
-
-        CSVFormat csvFormat = CSVFormat.DEFAULT;
+        Builder builder =
+                CSVFormat.EXCEL.builder().setIgnoreEmptyLines(true).setDelimiter(getDelimiter());
+        CSVFormat csvFormat = builder.build();
         if (firstLineAsHeader) {
             csvFormat = csvFormat.withFirstRecordAsHeader();
         }
@@ -198,7 +202,7 @@ public class CsvReadStrategy extends AbstractReadStrategy {
         ReadonlyConfig readonlyConfig = ReadonlyConfig.fromConfig(pluginConfig);
         CsvDeserializationSchema.Builder builder =
                 CsvDeserializationSchema.builder()
-                        .delimiter(",")
+                        .delimiter(getDelimiter())
                         .csvLineProcessor(processor)
                         .nullFormat(
                                 readonlyConfig
@@ -213,6 +217,11 @@ public class CsvReadStrategy extends AbstractReadStrategy {
         return getActualSeaTunnelRowTypeInfo();
     }
 
+    private String getDelimiter() {
+        ReadonlyConfig readonlyConfig = ReadonlyConfig.fromConfig(pluginConfig);
+        return readonlyConfig.getOptional(FileBaseSourceOptions.FIELD_DELIMITER).orElse(",");
+    }
+
     @Override
     public void setCatalogTable(CatalogTable catalogTable) {
         SeaTunnelRowType rowType = catalogTable.getSeaTunnelRowType();
@@ -227,7 +236,7 @@ public class CsvReadStrategy extends AbstractReadStrategy {
         initFormatter();
         CsvDeserializationSchema.Builder builder =
                 CsvDeserializationSchema.builder()
-                        .delimiter(",")
+                        .delimiter(getDelimiter())
                         .csvLineProcessor(processor)
                         .nullFormat(
                                 readonlyConfig
@@ -264,20 +273,21 @@ public class CsvReadStrategy extends AbstractReadStrategy {
     }
 
     private void initFormatter() {
-        if (pluginConfig.hasPath(FileBaseSourceOptions.DATE_FORMAT.key())) {
+        if (pluginConfig.hasPath(FileBaseSourceOptions.DATE_FORMAT_LEGACY.key())) {
             dateFormat =
                     DateUtils.Formatter.parse(
-                            pluginConfig.getString(FileBaseSourceOptions.DATE_FORMAT.key()));
+                            pluginConfig.getString(FileBaseSourceOptions.DATE_FORMAT_LEGACY.key()));
         }
-        if (pluginConfig.hasPath(FileBaseSourceOptions.DATETIME_FORMAT.key())) {
+        if (pluginConfig.hasPath(FileBaseSourceOptions.DATETIME_FORMAT_LEGACY.key())) {
             datetimeFormat =
                     DateTimeUtils.Formatter.parse(
-                            pluginConfig.getString(FileBaseSourceOptions.DATETIME_FORMAT.key()));
+                            pluginConfig.getString(
+                                    FileBaseSourceOptions.DATETIME_FORMAT_LEGACY.key()));
         }
-        if (pluginConfig.hasPath(FileBaseSourceOptions.TIME_FORMAT.key())) {
+        if (pluginConfig.hasPath(FileBaseSourceOptions.TIME_FORMAT_LEGACY.key())) {
             timeFormat =
                     TimeUtils.Formatter.parse(
-                            pluginConfig.getString(FileBaseSourceOptions.TIME_FORMAT.key()));
+                            pluginConfig.getString(FileBaseSourceOptions.TIME_FORMAT_LEGACY.key()));
         }
         if (pluginConfig.hasPath(FileBaseSourceOptions.COMPRESS_CODEC.key())) {
             String compressCodec =
