@@ -113,9 +113,9 @@ public class FtpFileSinkFactory extends BaseMultipleTableFileSinkFactory {
                         FileBaseSinkOptions.ENCODING)
                 .optional(FileBaseSinkOptions.SINK_COLUMNS)
                 .optional(FileBaseSinkOptions.IS_ENABLE_TRANSACTION)
-                .optional(FileBaseSinkOptions.DATE_FORMAT)
-                .optional(FileBaseSinkOptions.DATETIME_FORMAT)
-                .optional(FileBaseSinkOptions.TIME_FORMAT)
+                .optional(FileBaseSinkOptions.DATE_FORMAT_LEGACY)
+                .optional(FileBaseSinkOptions.DATETIME_FORMAT_LEGACY)
+                .optional(FileBaseSinkOptions.TIME_FORMAT_LEGACY)
                 .optional(FtpFileSinkOptions.FTP_CONNECTION_MODE)
                 .optional(FileBaseSinkOptions.SINGLE_FILE_MODE)
                 .optional(FileBaseSinkOptions.BATCH_SIZE)
