@@ -26,9 +26,10 @@ import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.common.config.CheckConfigUtil;
 import org.apache.seatunnel.common.config.CheckResult;
 import org.apache.seatunnel.common.constants.PluginType;
+import org.apache.seatunnel.connectors.seatunnel.file.config.FileBaseOptions;
 import org.apache.seatunnel.connectors.seatunnel.file.config.FileSystemType;
 import org.apache.seatunnel.connectors.seatunnel.file.oss.jindo.config.OssConf;
-import org.apache.seatunnel.connectors.seatunnel.file.oss.jindo.config.OssConfigOptions;
+import org.apache.seatunnel.connectors.seatunnel.file.oss.jindo.config.OssFileSinkOptions;
 import org.apache.seatunnel.connectors.seatunnel.file.oss.jindo.exception.OssJindoConnectorException;
 import org.apache.seatunnel.connectors.seatunnel.file.sink.BaseFileSink;
 
@@ -49,11 +50,11 @@ public class OssFileSink extends BaseFileSink {
         CheckResult result =
                 CheckConfigUtil.checkAllExists(
                         pluginConfig,
-                        OssConfigOptions.FILE_PATH.key(),
-                        OssConfigOptions.ENDPOINT.key(),
-                        OssConfigOptions.ACCESS_KEY.key(),
-                        OssConfigOptions.ACCESS_SECRET.key(),
-                        OssConfigOptions.BUCKET.key());
+                        FileBaseOptions.FILE_PATH.key(),
+                        OssFileSinkOptions.ENDPOINT.key(),
+                        OssFileSinkOptions.ACCESS_KEY.key(),
+                        OssFileSinkOptions.ACCESS_SECRET.key(),
+                        OssFileSinkOptions.BUCKET.key());
         if (!result.isSuccess()) {
             throw new OssJindoConnectorException(
                     SeaTunnelAPIErrorCode.CONFIG_VALIDATION_FAILED,
