@@ -29,4 +29,11 @@ public class HiveSinkOptions extends HiveOptions {
                     .defaultValue(false)
                     .withDescription(
                             "Flag to decide whether to drop partition metadata from Hive Metastore during an abort operation. Note: this only affects the metadata in the metastore, the data in the partition will always be deleted(data generated during the synchronization process).");
+
+    public static final Option<Boolean> OVERWRITE =
+            Options.key("overwrite")
+                    .booleanType()
+                    .defaultValue(false)
+                    .withDescription(
+                            "Flag to decide whether to use overwrite mode when inserting data into Hive. If set to true, for non-partitioned tables, the existing data in the table will be deleted before inserting new data. For partitioned tables, the data in the relevant partition will be deleted before inserting new data.");
 }
