@@ -465,7 +465,7 @@ public class HttpClientProvider implements AutoCloseable {
         headers.forEach(request::addHeader);
     }
 
-    private void addBody(HttpEntityEnclosingRequestBase request, Map<String, Object> body)
+    static void addBody(HttpEntityEnclosingRequestBase request, Map<String, Object> body)
             throws UnsupportedEncodingException {
         if (MapUtils.isEmpty(body)) {
             body = new HashMap<>();
@@ -489,10 +489,13 @@ public class HttpClientProvider implements AutoCloseable {
                 request.setEntity(new UrlEncodedFormEntity(parameters, ENCODING));
             }
         } else {
-            request.addHeader(HTTP.CONTENT_TYPE, APPLICATION_JSON);
+            // if user no define content-type, set default content-type
+            if (!request.containsHeader(HTTP.CONTENT_TYPE)) {
+                request.addHeader(HTTP.CONTENT_TYPE, APPLICATION_JSON);
+            }
+
             StringEntity entity =
                     new StringEntity(JsonUtils.toJsonString(body), ContentType.APPLICATION_JSON);
-            entity.setContentEncoding(new BasicHeader(HTTP.CONTENT_TYPE, APPLICATION_JSON));
             request.setEntity(entity);
         }
     }
