@@ -105,6 +105,25 @@ public class HttpSource extends AbstractSingleSplitSource<SeaTunnelRow> {
             if (pageConfig.hasPath(HttpSourceOptions.PAGE_FIELD.key())) {
                 pageInfo.setPageField(pageConfig.getString(HttpSourceOptions.PAGE_FIELD.key()));
             }
+
+            if (pageConfig.hasPath(HttpSourceOptions.PAGE_TYPE.key())) {
+                pageInfo.setPageType(pageConfig.getString(HttpSourceOptions.PAGE_TYPE.key()));
+            }
+            if (pageConfig.hasPath(HttpSourceOptions.PAGE_CURSOR_FIELD_NAME.key())) {
+                pageInfo.setPageCursorFieldName(
+                        pageConfig.getString(HttpSourceOptions.PAGE_CURSOR_FIELD_NAME.key()));
+            }
+            if (pageConfig.hasPath(HttpSourceOptions.PAGE_CURSOR_RESPONSE_FIELD.key())) {
+                pageInfo.setPageCursorResponseField(
+                        pageConfig.getString(HttpSourceOptions.PAGE_CURSOR_RESPONSE_FIELD.key()));
+            }
+            if (pageConfig.hasPath(HttpSourceOptions.USE_PLACEHOLDER_REPLACEMENT.key())) {
+                pageInfo.setUsePlaceholderReplacement(
+                        pageConfig.getBoolean(HttpSourceOptions.USE_PLACEHOLDER_REPLACEMENT.key()));
+            } else {
+                pageInfo.setUsePlaceholderReplacement(
+                        HttpSourceOptions.USE_PLACEHOLDER_REPLACEMENT.defaultValue());
+            }
         }
     }
 
