@@ -36,6 +36,8 @@ import org.apache.seatunnel.connectors.seatunnel.http.config.JsonField;
 import org.apache.seatunnel.connectors.seatunnel.http.config.PageInfo;
 import org.apache.seatunnel.connectors.seatunnel.http.exception.HttpConnectorErrorCode;
 import org.apache.seatunnel.connectors.seatunnel.http.exception.HttpConnectorException;
+import org.apache.seatunnel.connectors.seatunnel.http.util.JsonPathProcessorFactory;
+import org.apache.seatunnel.connectors.seatunnel.http.util.JsonPathUtils;
 
 import org.apache.commons.collections4.MapUtils;
 
@@ -73,6 +75,11 @@ public class HttpSourceReader extends AbstractSingleSplitReader<SeaTunnelRow> {
             Configuration.defaultConfiguration().addOptions(DEFAULT_OPTIONS);
     private boolean noMoreElementFlag = true;
     private Optional<PageInfo> pageInfoOptional = Optional.empty();
+    /**
+     * Holds the original request body template for placeholder replacement. This ensures that the
+     * state is not unintentionally mutated during pagination.
+     */
+    private String rawBody = null;
 
     public HttpSourceReader(
             HttpParameter httpParameter,
@@ -85,6 +92,7 @@ public class HttpSourceReader extends AbstractSingleSplitReader<SeaTunnelRow> {
         this.deserializationCollector = new DeserializationCollector(deserializationSchema);
         this.jsonField = jsonField;
         this.contentJson = contentJson;
+        this.rawBody = httpParameter.getBody();
     }
 
     public HttpSourceReader(
@@ -100,6 +108,7 @@ public class HttpSourceReader extends AbstractSingleSplitReader<SeaTunnelRow> {
         this.jsonField = jsonField;
         this.contentJson = contentJson;
         this.pageInfoOptional = Optional.ofNullable(pageInfo);
+        this.rawBody = httpParameter.getBody();
     }
 
     @Override
@@ -206,14 +215,10 @@ public class HttpSourceReader extends AbstractSingleSplitReader<SeaTunnelRow> {
         }
 
         // 2. param in body
-        if (!Strings.isNullOrEmpty(this.httpParameter.getBody())) {
+        if (!Strings.isNullOrEmpty(this.rawBody)) {
             String processedBody =
                     processBodyString(
-                            this.httpParameter.getBody(),
-                            pageField,
-                            pageValue,
-                            usePlaceholderReplacement);
-
+                            this.rawBody, pageField, pageValue, usePlaceholderReplacement);
             // Process cursor if available
             if (pageInfo.getPageCursorFieldName() != null && pageInfo.getCursor() != null) {
                 processedBody =
@@ -269,7 +274,7 @@ public class HttpSourceReader extends AbstractSingleSplitReader<SeaTunnelRow> {
                 }
             }
             map.putAll(updatedMap);
-        } else if (map.containsKey(pageField)) {
+        } else if (pageField != null && map.containsKey(pageField)) {
             // Key-based replacement
             map.put(pageField, pageValue);
         }
@@ -344,7 +349,6 @@ public class HttpSourceReader extends AbstractSingleSplitReader<SeaTunnelRow> {
                         pollAndCollectData(output);
                         Thread.sleep(10);
                     }
-
                 } else {
                     // default page number pagination
                     Long pageIndex = info.getPageIndex();
@@ -418,47 +422,15 @@ public class HttpSourceReader extends AbstractSingleSplitReader<SeaTunnelRow> {
         deserializationCollector.collect(contentData.getBytes(), output);
     }
 
-    private List<Map<String, String>> parseToMap(List<List<String>> datas, JsonField jsonField) {
-        List<Map<String, String>> decodeDatas = new ArrayList<>(datas.size());
-        String[] keys = jsonField.getFields().keySet().toArray(new String[] {});
-
-        for (List<String> data : datas) {
-            Map<String, String> decodeData = new HashMap<>(jsonField.getFields().size());
-            final int[] index = {0};
-            data.forEach(
-                    field -> {
-                        decodeData.put(keys[index[0]], field);
-                        index[0]++;
-                    });
-            decodeDatas.add(decodeData);
-        }
-
-        return decodeDatas;
-    }
-
     private List<List<String>> decodeJSON(String data) {
         ReadContext jsonReadContext = JsonPath.using(jsonConfiguration).parse(data);
-        List<List<String>> results = new ArrayList<>(jsonPaths.length);
-        for (JsonPath path : jsonPaths) {
-            List<String> result = jsonReadContext.read(path);
-            results.add(result);
-        }
-        for (int i = 1; i < results.size(); i++) {
-            List<?> result0 = results.get(0);
-            List<?> result = results.get(i);
-            if (result0.size() != result.size()) {
-                throw new HttpConnectorException(
-                        HttpConnectorErrorCode.FIELD_DATA_IS_INCONSISTENT,
-                        String.format(
-                                "[%s](%d) and [%s](%d) the number of parsing records is inconsistent.",
-                                jsonPaths[0].getPath(),
-                                result0.size(),
-                                jsonPaths[i].getPath(),
-                                result.size()));
-            }
-        }
+        return JsonPathProcessorFactory.getProcessor(
+                        this.jsonPaths, httpParameter.isJsonFiledMissedReturnNull())
+                .processJsonData(jsonReadContext, this.jsonPaths);
+    }
 
-        return dataFlip(results);
+    private List<Map<String, String>> parseToMap(List<List<String>> datas, JsonField jsonField) {
+        return JsonPathUtils.parseToMap(datas, jsonField);
     }
 
     private String getPartOfJson(String data) {
@@ -467,8 +439,8 @@ public class HttpSourceReader extends AbstractSingleSplitReader<SeaTunnelRow> {
     }
 
     private List<List<String>> dataFlip(List<List<String>> results) {
-
         List<List<String>> datas = new ArrayList<>();
+
         for (int i = 0; i < results.size(); i++) {
             List<String> result = results.get(i);
             if (i == 0) {
@@ -487,15 +459,11 @@ public class HttpSourceReader extends AbstractSingleSplitReader<SeaTunnelRow> {
                 }
             }
         }
+
         return datas;
     }
 
     private void initJsonPath(JsonField jsonField) {
-        jsonPaths = new JsonPath[jsonField.getFields().size()];
-        for (int index = 0; index < jsonField.getFields().keySet().size(); index++) {
-            jsonPaths[index] =
-                    JsonPath.compile(
-                            jsonField.getFields().values().toArray(new String[] {})[index]);
-        }
+        jsonPaths = JsonPathUtils.createJsonPaths(jsonField);
     }
 }
