@@ -61,8 +61,12 @@ public class IrisCatalog extends AbstractJdbcCatalog {
             "SELECT TABLE_SCHEMA,TABLE_NAME FROM INFORMATION_SCHEMA.Tables WHERE TABLE_SCHEMA='%s' and TABLE_TYPE != 'SYSTEM TABLE' and TABLE_TYPE != 'SYSTEM VIEW'";
 
     public IrisCatalog(
-            String catalogName, String username, String password, JdbcUrlUtil.UrlInfo urlInfo) {
-        super(catalogName, username, password, urlInfo, null);
+            String catalogName,
+            String username,
+            String password,
+            JdbcUrlUtil.UrlInfo urlInfo,
+            String driverClass) {
+        super(catalogName, username, password, urlInfo, null, driverClass);
     }
 
     @Override
