@@ -19,39 +19,40 @@ package org.apache.seatunnel.connectors.seatunnel.jdbc.config;
 
 import org.apache.seatunnel.api.configuration.Option;
 import org.apache.seatunnel.api.configuration.Options;
+import org.apache.seatunnel.connectors.seatunnel.jdbc.source.StringSplitMode;
 
 import java.util.List;
 
 @SuppressWarnings("checkstyle:MagicNumber")
-public interface JdbcSourceOptions {
+public class JdbcSourceOptions extends JdbcCommonOptions {
 
-    Option<String> TABLE_PATH =
+    public static final Option<String> TABLE_PATH =
             Options.key("table_path")
                     .stringType()
                     .noDefaultValue()
                     .withDescription("table full path");
 
-    Option<String> WHERE_CONDITION =
+    public static final Option<String> WHERE_CONDITION =
             Options.key("where_condition")
                     .stringType()
                     .noDefaultValue()
                     .withDescription(
                             "Common row filter conditions for all tables/queries, must start with `where`. for example `where id > 100`");
 
-    Option<List<JdbcSourceTableConfig>> TABLE_LIST =
+    public static final Option<List<JdbcSourceTableConfig>> TABLE_LIST =
             Options.key("table_list")
                     .listType(JdbcSourceTableConfig.class)
                     .noDefaultValue()
                     .withDescription("table list config");
 
-    Option<Integer> SPLIT_SIZE =
+    public static final Option<Integer> SPLIT_SIZE =
             Options.key("split.size")
                     .intType()
                     .defaultValue(8096)
                     .withDescription(
                             "The split size (number of rows) of table snapshot, captured tables are split into multiple splits when read     of table.");
 
-    Option<Double> SPLIT_EVEN_DISTRIBUTION_FACTOR_UPPER_BOUND =
+    public static final Option<Double> SPLIT_EVEN_DISTRIBUTION_FACTOR_UPPER_BOUND =
             Options.key("split.even-distribution.factor.upper-bound")
                     .doubleType()
                     .defaultValue(100.0d)
@@ -62,7 +63,7 @@ public interface JdbcSourceOptions {
                                     + " and the query for splitting would happen when it is uneven."
                                     + " The distribution factor could be calculated by (MAX(id) - MIN(id) + 1) / rowCount.");
 
-    Option<Double> SPLIT_EVEN_DISTRIBUTION_FACTOR_LOWER_BOUND =
+    public static final Option<Double> SPLIT_EVEN_DISTRIBUTION_FACTOR_LOWER_BOUND =
             Options.key("split.even-distribution.factor.lower-bound")
                     .doubleType()
                     .defaultValue(0.05d)
@@ -73,7 +74,7 @@ public interface JdbcSourceOptions {
                                     + " and the query for splitting would happen when it is uneven."
                                     + " The distribution factor could be calculated by (MAX(id) - MIN(id) + 1) / rowCount.");
 
-    Option<Integer> SPLIT_SAMPLE_SHARDING_THRESHOLD =
+    public static final Option<Integer> SPLIT_SAMPLE_SHARDING_THRESHOLD =
             Options.key("split.sample-sharding.threshold")
                     .intType()
                     .defaultValue(1000) // 1000 shards
@@ -84,7 +85,8 @@ public interface JdbcSourceOptions {
                                     + "the sample sharding strategy will be used. "
                                     + "This strategy can help to handle large datasets more efficiently. "
                                     + "The default value is 1000 shards.");
-    Option<Integer> SPLIT_INVERSE_SAMPLING_RATE =
+
+    public static final Option<Integer> SPLIT_INVERSE_SAMPLING_RATE =
             Options.key("split.inverse-sampling.rate")
                     .intType()
                     .defaultValue(1000) // 1/1000 sampling rate
@@ -94,15 +96,67 @@ public interface JdbcSourceOptions {
                                     + "For example, a value of 1000 means a sampling rate of 1/1000. "
                                     + "This parameter is used when the sample sharding strategy is triggered.");
 
-    Option<Boolean> USE_SELECT_COUNT =
+    public static final Option<Boolean> USE_SELECT_COUNT =
             Options.key("use_select_count")
                     .booleanType()
                     .defaultValue(false)
                     .withDescription("Use select count for table count");
 
-    Option<Boolean> SKIP_ANALYZE =
+    public static final Option<Boolean> SKIP_ANALYZE =
             Options.key("skip_analyze")
                     .booleanType()
                     .defaultValue(false)
                     .withDescription("Skip the analysis of table count");
+
+    public static final Option<Boolean> USE_REGEX =
+            Options.key("use_regex")
+                    .booleanType()
+                    .defaultValue(false)
+                    .withDescription("Use regular expression for table path matching");
+
+    public static final Option<Integer> FETCH_SIZE =
+            Options.key("fetch_size")
+                    .intType()
+                    .defaultValue(0)
+                    .withDescription(
+                            "For queries that return a large number of objects, "
+                                    + "you can configure the row fetch size used in the query to improve performance by reducing the number database hits required to satisfy the selection criteria. Zero means use jdbc default value.");
+
+    public static final Option<String> PARTITION_COLUMN =
+            Options.key("partition_column")
+                    .stringType()
+                    .noDefaultValue()
+                    .withDescription("partition column");
+
+    public static final Option<String> PARTITION_UPPER_BOUND =
+            Options.key("partition_upper_bound")
+                    .stringType()
+                    .noDefaultValue()
+                    .withDescription("partition upper bound");
+
+    public static final Option<String> PARTITION_LOWER_BOUND =
+            Options.key("partition_lower_bound")
+                    .stringType()
+                    .noDefaultValue()
+                    .withDescription("partition lower bound");
+
+    public static final Option<Integer> PARTITION_NUM =
+            Options.key("partition_num")
+                    .intType()
+                    .noDefaultValue()
+                    .withDescription("partition num");
+
+    public static final Option<StringSplitMode> STRING_SPLIT_MODE =
+            Options.key("split.string_split_mode")
+                    .enumType(StringSplitMode.class)
+                    .defaultValue(StringSplitMode.SAMPLE)
+                    .withDescription(
+                            "Supports different string splitting algorithms. By default, `sample` is used to determine the split by sampling the string value. You can switch to `charset_based` to enable charset-based string splitting algorithm. When set to `charset_based`, the algorithm assumes characters of partition_column are within ASCII range 32-126, which covers most character-based splitting scenarios.");
+
+    public static final Option<String> STRING_SPLIT_MODE_COLLATE =
+            Options.key("split.string_split_mode_collate")
+                    .stringType()
+                    .noDefaultValue()
+                    .withDescription(
+                            "Specifies the collation to use when string_split_mode is set to `charset_based` and the table has a special collation. If not specified, the database's default collation will be used.");
 }
