@@ -33,7 +33,7 @@ import java.io.Serializable;
 import java.sql.SQLException;
 import java.util.function.Supplier;
 
-import static com.google.common.base.Preconditions.checkNotNull;
+import static org.apache.seatunnel.shade.com.google.common.base.Preconditions.checkNotNull;
 
 /** A JDBC outputFormat */
 public class JdbcOutputFormat<I, E extends JdbcBatchStatementExecutor<I>> implements Serializable {
