@@ -38,7 +38,7 @@ public class DatabaseIdentifier {
     public static final String TABLE_STORE = "Tablestore";
     public static final String TERADATA = "Teradata";
     public static final String VERTICA = "Vertica";
-    public static final String OCENABASE = "OceanBase";
+    public static final String OCEANBASE = "OceanBase";
     public static final String TIDB = "TiDB";
     public static final String XUGU = "XUGU";
     public static final String IRIS = "IRIS";
@@ -46,4 +46,5 @@ public class DatabaseIdentifier {
     public static final String OPENGAUSS = "OpenGauss";
     public static final String HIGHGO = "Highgo";
     public static final String GREENPLUM = "Greenplum";
+    public static final String PRESTO = "Presto";
 }
