@@ -17,6 +17,7 @@
 
 package org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.db2;
 
+import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.DatabaseIdentifier;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.JdbcDialect;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.JdbcDialectFactory;
 
@@ -26,6 +27,11 @@ import com.google.auto.service.AutoService;
 @AutoService(JdbcDialectFactory.class)
 public class DB2DialectFactory implements JdbcDialectFactory {
 
+    @Override
+    public String dialectFactoryName() {
+        return DatabaseIdentifier.DB_2;
+    }
+
     @Override
     public boolean acceptsURL(String url) {
         return url.startsWith("jdbc:db2:");
