@@ -16,6 +16,7 @@
  */
 package org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.highgo;
 
+import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.DatabaseIdentifier;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.JdbcDialectFactory;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.psql.PostgresDialectFactory;
 
@@ -23,6 +24,11 @@ import com.google.auto.service.AutoService;
 
 @AutoService(JdbcDialectFactory.class)
 public class HighGoDialectFactory extends PostgresDialectFactory {
+    @Override
+    public String dialectFactoryName() {
+        return DatabaseIdentifier.HIGHGO;
+    }
+
     @Override
     public boolean acceptsURL(String url) {
         return url.startsWith("jdbc:highgo:");
