@@ -29,6 +29,7 @@ import org.apache.seatunnel.api.table.type.LocalTimeType;
 import org.apache.seatunnel.api.table.type.PrimitiveByteArrayType;
 import org.apache.seatunnel.common.exception.CommonError;
 import org.apache.seatunnel.connectors.seatunnel.common.source.TypeDefineUtils;
+import org.apache.seatunnel.connectors.seatunnel.jdbc.config.JdbcCommonOptions;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.DatabaseIdentifier;
 
 import com.google.auto.service.AutoService;
@@ -74,6 +75,7 @@ public class MySqlTypeConverter implements TypeConverter<BasicTypeDefine<MysqlTy
     static final String MYSQL_LONGTEXT = "LONGTEXT";
     static final String MYSQL_JSON = "JSON";
     static final String MYSQL_ENUM = "ENUM";
+    static final String MYSQL_SET = "SET";
 
     // ------------------------------time-------------------------
     static final String MYSQL_DATE = "DATE";
@@ -107,13 +109,19 @@ public class MySqlTypeConverter implements TypeConverter<BasicTypeDefine<MysqlTy
             new MySqlTypeConverter(MySqlVersion.V_5_7);
 
     private final MySqlVersion version;
-
-    public MySqlTypeConverter(MySqlVersion version) {
-        this.version = version;
-    }
+    private final boolean intTypeNarrowing;
 
     public MySqlTypeConverter() {
-        this(MySqlVersion.V_5_7);
+        this(MySqlVersion.V_5_7, JdbcCommonOptions.INT_TYPE_NARROWING.defaultValue());
+    }
+
+    public MySqlTypeConverter(MySqlVersion version) {
+        this(version, JdbcCommonOptions.INT_TYPE_NARROWING.defaultValue());
+    }
+
+    public MySqlTypeConverter(MySqlVersion version, boolean intTypeNarrowing) {
+        this.version = version;
+        this.intTypeNarrowing = intTypeNarrowing;
     }
 
     @Override
@@ -158,7 +166,7 @@ public class MySqlTypeConverter implements TypeConverter<BasicTypeDefine<MysqlTy
                 }
                 break;
             case MYSQL_TINYINT:
-                if (typeDefine.getColumnType().equalsIgnoreCase("tinyint(1)")) {
+                if (typeDefine.getColumnType().equalsIgnoreCase("tinyint(1)") && intTypeNarrowing) {
                     builder.dataType(BasicType.BOOLEAN_TYPE);
                 } else {
                     builder.dataType(BasicType.BYTE_TYPE);
@@ -236,6 +244,7 @@ public class MySqlTypeConverter implements TypeConverter<BasicTypeDefine<MysqlTy
                 builder.scale(decimalUnsignedType.getScale());
                 break;
             case MYSQL_ENUM:
+            case MYSQL_SET:
                 builder.dataType(BasicType.STRING_TYPE);
                 if (typeDefine.getLength() == null || typeDefine.getLength() <= 0) {
                     builder.columnLength(100L);
