@@ -27,7 +27,7 @@ import org.apache.seatunnel.api.table.type.LocalTimeType;
 import org.apache.seatunnel.api.table.type.PrimitiveByteArrayType;
 import org.apache.seatunnel.common.exception.CommonError;
 import org.apache.seatunnel.connectors.seatunnel.common.source.TypeDefineUtils;
-import org.apache.seatunnel.connectors.seatunnel.jdbc.config.JdbcOptions;
+import org.apache.seatunnel.connectors.seatunnel.jdbc.config.JdbcCommonOptions;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.DatabaseIdentifier;
 
 import com.google.auto.service.AutoService;
@@ -71,6 +71,7 @@ public class OracleTypeConverter implements TypeConverter<BasicTypeDefine> {
     public static final String ORACLE_BLOB = "BLOB";
     public static final String ORACLE_RAW = "RAW";
     public static final String ORACLE_LONG_RAW = "LONG RAW";
+    public static final String ORACLE_BFILE = "BFILE";
 
     public static final int MAX_PRECISION = 38;
     public static final int DEFAULT_PRECISION = MAX_PRECISION;
@@ -91,11 +92,11 @@ public class OracleTypeConverter implements TypeConverter<BasicTypeDefine> {
     private final boolean handleBlobAsString;
 
     public OracleTypeConverter() {
-        this(true, JdbcOptions.HANDLE_BLOB_AS_STRING.defaultValue());
+        this(true, JdbcCommonOptions.HANDLE_BLOB_AS_STRING.defaultValue());
     }
 
     public OracleTypeConverter(boolean decimalTypeNarrowing) {
-        this(decimalTypeNarrowing, JdbcOptions.HANDLE_BLOB_AS_STRING.defaultValue());
+        this(decimalTypeNarrowing, JdbcCommonOptions.HANDLE_BLOB_AS_STRING.defaultValue());
     }
 
     public OracleTypeConverter(boolean decimalTypeNarrowing, boolean handleBlobAsString) {
@@ -218,6 +219,10 @@ public class OracleTypeConverter implements TypeConverter<BasicTypeDefine> {
                     builder.columnLength(BYTES_4GB - 1);
                 }
                 break;
+            case ORACLE_BFILE:
+                builder.dataType(PrimitiveByteArrayType.INSTANCE);
+                builder.columnLength(BYTES_4GB - 1);
+                break;
             case ORACLE_RAW:
                 builder.dataType(PrimitiveByteArrayType.INSTANCE);
                 if (typeDefine.getLength() == null || typeDefine.getLength() == 0) {
