@@ -17,6 +17,7 @@
 
 package org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.teradata;
 
+import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.DatabaseIdentifier;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.JdbcDialect;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.JdbcDialectFactory;
 
@@ -25,6 +26,11 @@ import com.google.auto.service.AutoService;
 @AutoService(JdbcDialectFactory.class)
 public class TeradataDialectFactory implements JdbcDialectFactory {
 
+    @Override
+    public String dialectFactoryName() {
+        return DatabaseIdentifier.TERADATA;
+    }
+
     @Override
     public boolean acceptsURL(String url) {
         return url.startsWith("jdbc:teradata:");
