@@ -20,10 +20,12 @@ package org.apache.seatunnel.connectors.seatunnel.jdbc.utils;
 import org.apache.seatunnel.shade.com.google.common.base.Strings;
 
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
+import org.apache.seatunnel.api.options.ConnectorCommonOptions;
 import org.apache.seatunnel.api.table.catalog.Catalog;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.Column;
 import org.apache.seatunnel.api.table.catalog.ConstraintKey;
+import org.apache.seatunnel.api.table.catalog.PhysicalColumn;
 import org.apache.seatunnel.api.table.catalog.PrimaryKey;
 import org.apache.seatunnel.api.table.catalog.TableIdentifier;
 import org.apache.seatunnel.api.table.catalog.TablePath;
@@ -33,10 +35,9 @@ import org.apache.seatunnel.common.exception.CommonError;
 import org.apache.seatunnel.common.exception.CommonErrorCode;
 import org.apache.seatunnel.common.exception.SeaTunnelRuntimeException;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.AbstractJdbcCatalog;
-import org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.JdbcCatalogOptions;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.utils.CatalogUtils;
+import org.apache.seatunnel.connectors.seatunnel.jdbc.config.JdbcCommonOptions;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.config.JdbcConnectionConfig;
-import org.apache.seatunnel.connectors.seatunnel.jdbc.config.JdbcOptions;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.config.JdbcSourceTableConfig;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.connection.JdbcConnectionProvider;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.JdbcDialect;
@@ -63,6 +64,7 @@ import java.util.stream.Collectors;
 @Slf4j
 public class JdbcCatalogUtils {
     private static final String DEFAULT_CATALOG_NAME = "jdbc_catalog";
+    private static final String DOT_PLACEHOLDER = "__$DOT$__";
 
     public static Map<TablePath, JdbcSourceTable> getTables(
             JdbcConnectionConfig jdbcConnectionConfig, List<JdbcSourceTableConfig> tablesConfig)
@@ -83,24 +85,33 @@ public class JdbcCatalogUtils {
                 Map<String, Map<String, String>> unsupportedTable = new LinkedHashMap<>();
                 for (JdbcSourceTableConfig tableConfig : tablesConfig) {
                     try {
-                        CatalogTable catalogTable =
-                                getCatalogTable(tableConfig, jdbcCatalog, jdbcDialect);
-                        TablePath tablePath = catalogTable.getTableId().toTablePath();
-                        JdbcSourceTable jdbcSourceTable =
-                                JdbcSourceTable.builder()
-                                        .tablePath(tablePath)
-                                        .query(tableConfig.getQuery())
-                                        .partitionColumn(tableConfig.getPartitionColumn())
-                                        .partitionNumber(tableConfig.getPartitionNumber())
-                                        .partitionStart(tableConfig.getPartitionStart())
-                                        .partitionEnd(tableConfig.getPartitionEnd())
-                                        .useSelectCount(tableConfig.getUseSelectCount())
-                                        .skipAnalyze(tableConfig.getSkipAnalyze())
-                                        .catalogTable(catalogTable)
-                                        .build();
-                        tables.put(tablePath, jdbcSourceTable);
-                        if (log.isDebugEnabled()) {
-                            log.debug("Loaded catalog table : {}, {}", tablePath, jdbcSourceTable);
+                        if (StringUtils.isNotEmpty(tableConfig.getTablePath())
+                                && StringUtils.isEmpty(tableConfig.getQuery())
+                                && tableConfig.getUseRegex()) {
+                            processRegexTablePath(jdbcCatalog, jdbcDialect, tableConfig, tables);
+                        } else {
+                            CatalogTable catalogTable =
+                                    getCatalogTable(tableConfig, jdbcCatalog, jdbcDialect);
+                            TablePath tablePath = catalogTable.getTableId().toTablePath();
+                            JdbcSourceTable jdbcSourceTable =
+                                    JdbcSourceTable.builder()
+                                            .tablePath(tablePath)
+                                            .query(tableConfig.getQuery())
+                                            .partitionColumn(tableConfig.getPartitionColumn())
+                                            .partitionNumber(tableConfig.getPartitionNumber())
+                                            .partitionStart(tableConfig.getPartitionStart())
+                                            .partitionEnd(tableConfig.getPartitionEnd())
+                                            .useSelectCount(tableConfig.getUseSelectCount())
+                                            .skipAnalyze(tableConfig.getSkipAnalyze())
+                                            .catalogTable(catalogTable)
+                                            .build();
+                            tables.put(tablePath, jdbcSourceTable);
+                            if (log.isDebugEnabled()) {
+                                log.debug(
+                                        "Loaded catalog table : {}, {}",
+                                        tablePath,
+                                        jdbcSourceTable);
+                            }
                         }
                     } catch (SeaTunnelRuntimeException e) {
                         if (e.getSeaTunnelErrorCode()
@@ -308,13 +319,48 @@ public class JdbcCatalogUtils {
                         tableOfPath.getTableId().getDatabaseName(),
                         tableOfPath.getTableId().getSchemaName(),
                         tableOfPath.getTableId().getTableName());
+        List<Column> columnsWithComment =
+                tableSchemaOfQuery.getColumns().stream()
+                        .map(
+                                column -> {
+                                    return columnsOfPath.containsKey(column.getName())
+                                                    && columnsOfPath
+                                                            .get(column.getName())
+                                                            .getDataType()
+                                                            .getSqlType()
+                                                            .equals(
+                                                                    columnsOfQuery
+                                                                            .get(column.getName())
+                                                                            .getDataType()
+                                                                            .getSqlType())
+                                            ? PhysicalColumn.of(
+                                                    column.getName(),
+                                                    column.getDataType(),
+                                                    column.getColumnLength() == null
+                                                            ? null
+                                                            : Math.toIntExact(
+                                                                    column.getColumnLength()),
+                                                    column.isNullable(),
+                                                    column.getDefaultValue(),
+                                                    columnsOfPath
+                                                            .get(column.getName())
+                                                            .getComment(),
+                                                    column.getSourceType(),
+                                                    column.isUnsigned(),
+                                                    column.isZeroFill(),
+                                                    column.getBitLen(),
+                                                    column.getOptions(),
+                                                    column.getLongColumnLength())
+                                            : column;
+                                })
+                        .collect(Collectors.toList());
         CatalogTable mergedCatalogTable =
                 CatalogTable.of(
                         tableIdentifier,
                         TableSchema.builder()
                                 .primaryKey(primaryKeyOfMerge)
                                 .constraintKey(constraintKeysOfMerge)
-                                .columns(tableSchemaOfQuery.getColumns())
+                                .columns(columnsWithComment)
                                 .build(),
                         tableOfPath.getOptions(),
                         partitionKeysOfMerge,
@@ -396,16 +442,102 @@ public class JdbcCatalogUtils {
 
     private static ReadonlyConfig extractCatalogConfig(JdbcConnectionConfig config) {
         Map<String, Object> catalogConfig = new HashMap<>();
-        catalogConfig.put(JdbcCatalogOptions.BASE_URL.key(), config.getUrl());
+        catalogConfig.put(JdbcCommonOptions.URL.key(), config.getUrl());
         config.getUsername()
-                .ifPresent(val -> catalogConfig.put(JdbcCatalogOptions.USERNAME.key(), val));
+                .ifPresent(val -> catalogConfig.put(JdbcCommonOptions.USERNAME.key(), val));
         config.getPassword()
-                .ifPresent(val -> catalogConfig.put(JdbcCatalogOptions.PASSWORD.key(), val));
+                .ifPresent(val -> catalogConfig.put(JdbcCommonOptions.PASSWORD.key(), val));
         Optional.ofNullable(config.getCompatibleMode())
-                .ifPresent(val -> catalogConfig.put(JdbcCatalogOptions.COMPATIBLE_MODE.key(), val));
+                .ifPresent(val -> catalogConfig.put(JdbcCommonOptions.COMPATIBLE_MODE.key(), val));
         catalogConfig.put(
-                JdbcOptions.DECIMAL_TYPE_NARROWING.key(), config.isDecimalTypeNarrowing());
-        catalogConfig.put(JdbcOptions.HANDLE_BLOB_AS_STRING.key(), config.isHandleBlobAsString());
+                JdbcCommonOptions.DECIMAL_TYPE_NARROWING.key(), config.isDecimalTypeNarrowing());
+        catalogConfig.put(JdbcCommonOptions.INT_TYPE_NARROWING.key(), config.isIntTypeNarrowing());
+        catalogConfig.put(
+                JdbcCommonOptions.HANDLE_BLOB_AS_STRING.key(), config.isHandleBlobAsString());
         return ReadonlyConfig.fromMap(catalogConfig);
     }
+
+    private static void processRegexTablePath(
+            AbstractJdbcCatalog jdbcCatalog,
+            JdbcDialect jdbcDialect,
+            JdbcSourceTableConfig tableConfig,
+            Map<TablePath, JdbcSourceTable> result)
+            throws SQLException {
+
+        String tablePath = tableConfig.getTablePath();
+        log.info("Processing table path with regex: {}", tablePath);
+
+        String processedTablePath = tablePath.replace("\\.", DOT_PLACEHOLDER);
+        log.debug("After replacing escaped dots with placeholder: {}", processedTablePath);
+
+        TablePath parsedPath = jdbcDialect.parse(processedTablePath);
+
+        String databasePattern = parsedPath.getDatabaseName();
+        String schemaPattern = parsedPath.getSchemaName();
+        String tableNamePattern = parsedPath.getTableName();
+
+        if (StringUtils.isEmpty(databasePattern)) {
+            databasePattern = ".*";
+        }
+
+        String fullTablePattern;
+        if (StringUtils.isNotEmpty(schemaPattern)) {
+            fullTablePattern =
+                    String.format(
+                            "%s.%s.%s",
+                            databasePattern.replace(DOT_PLACEHOLDER, "."),
+                            schemaPattern.replace(DOT_PLACEHOLDER, "."),
+                            tableNamePattern.replace(DOT_PLACEHOLDER, "."));
+        } else {
+            fullTablePattern =
+                    String.format(
+                            "%s.%s",
+                            databasePattern.replace(DOT_PLACEHOLDER, "."),
+                            tableNamePattern.replace(DOT_PLACEHOLDER, "."));
+        }
+
+        log.info(
+                "Parsed patterns - database: {}, full table pattern: {}",
+                databasePattern,
+                fullTablePattern);
+
+        Map<String, Object> configMap = new HashMap<>();
+        configMap.put(ConnectorCommonOptions.DATABASE_PATTERN.key(), databasePattern);
+        configMap.put(ConnectorCommonOptions.TABLE_PATTERN.key(), fullTablePattern);
+
+        ReadonlyConfig config = ReadonlyConfig.fromMap(configMap);
+
+        try {
+            List<CatalogTable> catalogTables = jdbcCatalog.getTables(config);
+
+            if (catalogTables.isEmpty()) {
+                log.warn("No tables found matching regex pattern: {}", tablePath);
+                return;
+            }
+
+            for (CatalogTable catalogTable : catalogTables) {
+                TablePath path = catalogTable.getTableId().toTablePath();
+
+                JdbcSourceTable jdbcSourceTable =
+                        JdbcSourceTable.builder()
+                                .tablePath(path)
+                                .partitionColumn(tableConfig.getPartitionColumn())
+                                .partitionNumber(tableConfig.getPartitionNumber())
+                                .partitionStart(tableConfig.getPartitionStart())
+                                .partitionEnd(tableConfig.getPartitionEnd())
+                                .useSelectCount(tableConfig.getUseSelectCount())
+                                .skipAnalyze(tableConfig.getSkipAnalyze())
+                                .catalogTable(catalogTable)
+                                .build();
+
+                result.put(path, jdbcSourceTable);
+                log.info("Found table matching regex pattern: {}", path);
+            }
+
+            log.info("Found {} tables matching regex pattern: {}", catalogTables.size(), tablePath);
+        } catch (Exception e) {
+            log.warn("Error processing table path with regex: {}", tablePath, e);
+            throw new SQLException("Failed to process regex table path: " + tablePath, e);
+        }
+    }
 }
