@@ -30,21 +30,4 @@ public interface ThrowingRunnable<E extends Throwable> {
      * @throws E Exceptions may be thrown.
      */
     void run() throws E;
-
-    /**
-     * Converts a {@link ThrowingRunnable} into a {@link Runnable} which throws all checked
-     * exceptions as unchecked.
-     *
-     * @param throwingRunnable to convert into a {@link Runnable}
-     * @return {@link Runnable} which throws all checked exceptions as unchecked.
-     */
-    static Runnable unchecked(ThrowingRunnable<?> throwingRunnable) {
-        return () -> {
-            try {
-                throwingRunnable.run();
-            } catch (Throwable t) {
-                ExceptionUtils.rethrow(t);
-            }
-        };
-    }
 }
