@@ -75,9 +75,10 @@ class MySqlCatalogTest {
         tablePathMySql = TablePath.of(databaseName, "mysql_to_mysql");
         tablePathPG = TablePath.of(databaseName, "pg_to_mysql");
         tablePathOracle = TablePath.of(databaseName, "oracle_to_mysql");
-        sqlServerCatalog = new SqlServerCatalog("sqlserver", "sa", "root@123", sqlParse, null);
-        mySqlCatalog = new MySqlCatalog("mysql", "root", "123456", MysqlUrlInfo);
-        postgresCatalog = new PostgresCatalog("postgres", "postgres", "postgres", pg, null);
+        sqlServerCatalog =
+                new SqlServerCatalog("sqlserver", "sa", "root@123", sqlParse, null, null);
+        mySqlCatalog = new MySqlCatalog("mysql", "root", "123456", MysqlUrlInfo, null);
+        postgresCatalog = new PostgresCatalog("postgres", "postgres", "postgres", pg, null, null);
         mySqlCatalog.open();
         sqlServerCatalog.open();
         postgresCatalog.open();
