@@ -27,6 +27,7 @@ import org.apache.seatunnel.api.table.catalog.PrimaryKey;
 import org.apache.seatunnel.api.table.catalog.TableIdentifier;
 import org.apache.seatunnel.api.table.catalog.TableSchema;
 import org.apache.seatunnel.api.table.type.BasicType;
+import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.DatabaseIdentifier;
 
 import org.junit.jupiter.api.Assertions;
@@ -37,6 +38,9 @@ import java.util.Collections;
 import java.util.List;
 import java.util.regex.Pattern;
 
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.when;
+
 class PostgresCreateTableSqlBuilderTest {
 
     @Test
@@ -170,4 +174,19 @@ class PostgresCreateTableSqlBuilderTest {
                 Collections.emptyList(),
                 "test table");
     }
+
+    @Test
+    public void testColumnSinkType() {
+        PostgresCreateTableSqlBuilder sqlBuilder = mock(PostgresCreateTableSqlBuilder.class);
+
+        Column column = mock(Column.class);
+        when(column.getSinkType()).thenReturn("VARCHAR(10)");
+        when(column.getDataType()).thenReturn((SeaTunnelDataType) BasicType.INT_TYPE);
+        when(column.getName()).thenReturn("col1");
+        when(sqlBuilder.buildColumnSql(column)).thenCallRealMethod();
+
+        String result = sqlBuilder.buildColumnSql(column);
+
+        Assertions.assertEquals("\"col1\" VARCHAR(10) NOT NULL", result);
+    }
 }
