@@ -81,6 +81,20 @@ public class SqlServerTypeConverterTest {
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType().toLowerCase());
     }
 
+    @Test
+    public void testConvertTinyintIdentity() {
+        BasicTypeDefine<Object> typeDefine =
+                BasicTypeDefine.builder()
+                        .name("test")
+                        .columnType("tinyint identity")
+                        .dataType("tinyint")
+                        .build();
+        Column column = SqlServerTypeConverter.INSTANCE.convert(typeDefine);
+        Assertions.assertEquals(typeDefine.getName(), column.getName());
+        Assertions.assertEquals(BasicType.SHORT_TYPE, column.getDataType());
+        Assertions.assertEquals(SqlServerTypeConverter.SQLSERVER_TINYINT, column.getSourceType());
+    }
+
     @Test
     public void testConvertSmallint() {
         BasicTypeDefine<Object> typeDefine =
@@ -95,6 +109,20 @@ public class SqlServerTypeConverterTest {
         Assertions.assertEquals(typeDefine.getColumnType(), column.getSourceType().toLowerCase());
     }
 
+    @Test
+    public void testConvertSmallintIdentity() {
+        BasicTypeDefine<Object> typeDefine =
+                BasicTypeDefine.builder()
+                        .name("test")
+                        .columnType("smallint identity")
+                        .dataType("smallint")
+                        .build();
+        Column column = SqlServerTypeConverter.INSTANCE.convert(typeDefine);
+        Assertions.assertEquals(typeDefine.getName(), column.getName());
+        Assertions.assertEquals(BasicType.SHORT_TYPE, column.getDataType());
+        Assertions.assertEquals(SqlServerTypeConverter.SQLSERVER_SMALLINT, column.getSourceType());
+    }
+
     @Test
     public void testConvertInt() {
         BasicTypeDefine<Object> typeDefine =
@@ -116,6 +144,20 @@ public class SqlServerTypeConverterTest {
         Assertions.assertEquals("int", column.getSourceType().toLowerCase());
     }
 
+    @Test
+    public void testConvertBigintIdentity() {
+        BasicTypeDefine<Object> typeDefine =
+                BasicTypeDefine.builder()
+                        .name("test")
+                        .columnType("bigint identity")
+                        .dataType("bigint")
+                        .build();
+        Column column = SqlServerTypeConverter.INSTANCE.convert(typeDefine);
+        Assertions.assertEquals(typeDefine.getName(), column.getName());
+        Assertions.assertEquals(BasicType.LONG_TYPE, column.getDataType());
+        Assertions.assertEquals(SqlServerTypeConverter.SQLSERVER_BIGINT, column.getSourceType());
+    }
+
     @Test
     public void testConvertBigint() {
         BasicTypeDefine<Object> typeDefine =
@@ -706,14 +748,14 @@ public class SqlServerTypeConverterTest {
 
         BasicTypeDefine typeDefine = SqlServerTypeConverter.INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
-        Assertions.assertEquals(SqlServerTypeConverter.SQLSERVER_TEXT, typeDefine.getColumnType());
-        Assertions.assertEquals(SqlServerTypeConverter.SQLSERVER_TEXT, typeDefine.getDataType());
+        Assertions.assertEquals(SqlServerTypeConverter.MAX_NVARCHAR, typeDefine.getColumnType());
+        Assertions.assertEquals(SqlServerTypeConverter.MAX_NVARCHAR, typeDefine.getDataType());
 
         column =
                 PhysicalColumn.builder()
                         .name("test")
                         .dataType(BasicType.STRING_TYPE)
-                        .columnLength(8000L)
+                        .columnLength(4000L)
                         .build();
 
         typeDefine = SqlServerTypeConverter.INSTANCE.reconvert(column);
@@ -721,21 +763,22 @@ public class SqlServerTypeConverterTest {
         Assertions.assertEquals(
                 String.format(
                         "%s(%s)",
-                        SqlServerTypeConverter.SQLSERVER_VARCHAR, column.getColumnLength()),
+                        SqlServerTypeConverter.SQLSERVER_NVARCHAR, column.getColumnLength()),
                 typeDefine.getColumnType());
-        Assertions.assertEquals(SqlServerTypeConverter.SQLSERVER_VARCHAR, typeDefine.getDataType());
+        Assertions.assertEquals(
+                SqlServerTypeConverter.SQLSERVER_NVARCHAR, typeDefine.getDataType());
 
         column =
                 PhysicalColumn.builder()
                         .name("test")
                         .dataType(BasicType.STRING_TYPE)
-                        .columnLength(8001L)
+                        .columnLength(4001L)
                         .build();
 
         typeDefine = SqlServerTypeConverter.INSTANCE.reconvert(column);
         Assertions.assertEquals(column.getName(), typeDefine.getName());
-        Assertions.assertEquals(SqlServerTypeConverter.SQLSERVER_TEXT, typeDefine.getColumnType());
-        Assertions.assertEquals(SqlServerTypeConverter.SQLSERVER_TEXT, typeDefine.getDataType());
+        Assertions.assertEquals(SqlServerTypeConverter.MAX_NVARCHAR, typeDefine.getColumnType());
+        Assertions.assertEquals(SqlServerTypeConverter.MAX_NVARCHAR, typeDefine.getDataType());
     }
 
     @Test
