@@ -25,7 +25,6 @@ import org.apache.seatunnel.connectors.seatunnel.common.source.reader.RecordsWit
 import org.apache.seatunnel.connectors.seatunnel.common.source.reader.splitreader.SplitReader;
 import org.apache.seatunnel.connectors.seatunnel.common.source.reader.splitreader.SplitsAddition;
 import org.apache.seatunnel.connectors.seatunnel.common.source.reader.splitreader.SplitsChange;
-import org.apache.seatunnel.connectors.seatunnel.kafka.config.StartMode;
 
 import org.apache.kafka.clients.consumer.ConsumerConfig;
 import org.apache.kafka.clients.consumer.ConsumerRecord;
@@ -173,9 +172,7 @@ public class KafkaPartitionSplitReader
         // Assignment.
         List<TopicPartition> newPartitionAssignments = new ArrayList<>();
         // Starting offsets.
-        Map<TopicPartition, Long> partitionsStartingFromSpecifiedOffsets = new HashMap<>();
-        List<TopicPartition> partitionsStartingFromEarliest = new ArrayList<>();
-        List<TopicPartition> partitionsStartingFromLatest = new ArrayList<>();
+        Map<TopicPartition, Long> partitionsStartingOffsets = new HashMap<>();
         // Stopping offsets.
         List<TopicPartition> partitionsStoppingAtLatest = new ArrayList<>();
 
@@ -185,11 +182,7 @@ public class KafkaPartitionSplitReader
                 .forEach(
                         s -> {
                             newPartitionAssignments.add(s.getTopicPartition());
-                            parseStartingOffsets(
-                                    s,
-                                    partitionsStartingFromEarliest,
-                                    partitionsStartingFromLatest,
-                                    partitionsStartingFromSpecifiedOffsets);
+                            parseStartingOffsets(s, partitionsStartingOffsets);
                             parseStoppingOffsets(s, partitionsStoppingAtLatest);
                         });
 
@@ -198,10 +191,7 @@ public class KafkaPartitionSplitReader
         consumer.assign(newPartitionAssignments);
 
         // Seek on the newly assigned partitions to their stating offsets.
-        seekToStartingOffsets(
-                partitionsStartingFromEarliest,
-                partitionsStartingFromLatest,
-                partitionsStartingFromSpecifiedOffsets);
+        seekToStartingOffsets(partitionsStartingOffsets);
         // Setup the stopping offsets.
         acquireAndSetStoppingOffsets(partitionsStoppingAtLatest);
 
@@ -270,26 +260,11 @@ public class KafkaPartitionSplitReader
         stoppingOffsets.putAll(endOffset);
     }
 
-    private void seekToStartingOffsets(
-            List<TopicPartition> partitionsStartingFromEarliest,
-            List<TopicPartition> partitionsStartingFromLatest,
-            Map<TopicPartition, Long> partitionsStartingFromSpecifiedOffsets) {
-
-        if (!partitionsStartingFromEarliest.isEmpty()) {
-            LOG.trace("Seeking starting offsets to beginning: {}", partitionsStartingFromEarliest);
-            consumer.seekToBeginning(partitionsStartingFromEarliest);
-        }
-
-        if (!partitionsStartingFromLatest.isEmpty()) {
-            LOG.trace("Seeking starting offsets to end: {}", partitionsStartingFromLatest);
-            consumer.seekToEnd(partitionsStartingFromLatest);
-        }
-
-        if (!partitionsStartingFromSpecifiedOffsets.isEmpty()) {
+    private void seekToStartingOffsets(Map<TopicPartition, Long> partitionsStartingOffsets) {
+        if (!partitionsStartingOffsets.isEmpty()) {
             LOG.trace(
-                    "Seeking starting offsets to specified offsets: {}",
-                    partitionsStartingFromSpecifiedOffsets);
-            partitionsStartingFromSpecifiedOffsets.forEach(consumer::seek);
+                    "Seeking starting offsets to specified offsets: {}", partitionsStartingOffsets);
+            partitionsStartingOffsets.forEach(consumer::seek);
         }
     }
 
@@ -308,22 +283,10 @@ public class KafkaPartitionSplitReader
     }
 
     private void parseStartingOffsets(
-            KafkaSourceSplit split,
-            List<TopicPartition> partitionsStartingFromEarliest,
-            List<TopicPartition> partitionsStartingFromLatest,
-            Map<TopicPartition, Long> partitionsStartingFromSpecifiedOffsets) {
+            KafkaSourceSplit split, Map<TopicPartition, Long> partitionsStartingOffsets) {
         TopicPartition tp = split.getTopicPartition();
-        // Parse starting offsets.
-        ConsumerMetadata metadata = kafkaSourceConfig.getMapMetadata().get(split.getTablePath());
-        if (metadata.getStartMode() == StartMode.EARLIEST) {
-            partitionsStartingFromEarliest.add(tp);
-        } else if (metadata.getStartMode() == StartMode.LATEST) {
-            partitionsStartingFromLatest.add(tp);
-        } else if (metadata.getStartMode() == StartMode.GROUP_OFFSETS) {
-            // Do nothing here, the consumer will first try to get the committed offsets of
-            // these partitions by default.
-        } else {
-            partitionsStartingFromSpecifiedOffsets.put(tp, split.getStartOffset());
+        if (split.getStartOffset() >= 0) {
+            partitionsStartingOffsets.put(tp, split.getStartOffset());
         }
     }
 
