@@ -45,9 +45,10 @@ public class KuduSourceTableConfig implements Serializable {
 
     private String filter;
 
-    private KuduSourceTableConfig(String tablePath, CatalogTable catalogTable) {
+    private KuduSourceTableConfig(String tablePath, CatalogTable catalogTable, String filter) {
         this.tablePath = TablePath.of(tablePath);
         this.catalogTable = catalogTable;
+        this.filter = filter;
     }
 
     public static List<KuduSourceTableConfig> of(ReadonlyConfig config) {
@@ -82,6 +83,7 @@ public class KuduSourceTableConfig implements Serializable {
             catalogTable =
                     kuduCatalog.getTable(TablePath.of(config.get(KuduBaseOptions.TABLE_NAME)));
         }
-        return new KuduSourceTableConfig(tableName, catalogTable);
+        return new KuduSourceTableConfig(
+                tableName, catalogTable, config.get(KuduSourceOptions.FILTER));
     }
 }
