@@ -19,4 +19,6 @@ package org.apache.seatunnel.connectors.seatunnel.kudu.state;
 
 import java.io.Serializable;
 
-public class KuduSinkState implements Serializable {}
+public class KuduSinkState implements Serializable {
+    private static final long serialVersionUID = 8724196975203566877L;
+}
