@@ -30,7 +30,6 @@ import org.apache.seatunnel.connectors.seatunnel.maxcompute.exception.Maxcompute
 import com.aliyun.odps.Column;
 import com.aliyun.odps.Table;
 import com.aliyun.odps.TableSchema;
-import com.aliyun.odps.data.ArrayRecord;
 import com.aliyun.odps.data.Binary;
 import com.aliyun.odps.data.Char;
 import com.aliyun.odps.data.Record;
@@ -69,8 +68,11 @@ public class MaxcomputeTypeMapper implements Serializable {
     }
 
     public static Record getMaxcomputeRowData(
-            SeaTunnelRow seaTunnelRow, TableSchema tableSchema, SeaTunnelRowType rowType) {
-        ArrayRecord arrayRecord = new ArrayRecord(tableSchema);
+            Record record,
+            SeaTunnelRow seaTunnelRow,
+            TableSchema tableSchema,
+            SeaTunnelRowType rowType,
+            FormatterContext formatterContext) {
         for (int i = 0; i < seaTunnelRow.getFields().length; i++) {
             String fieldName = rowType.getFieldName(i);
             if (!tableSchema.containsColumn(fieldName)) {
@@ -82,11 +84,12 @@ public class MaxcomputeTypeMapper implements Serializable {
             }
             Column column = tableSchema.getColumn(fieldName);
 
-            arrayRecord.set(
+            record.set(
                     tableSchema.getColumnIndex(fieldName),
-                    resolveObject2Maxcompute(seaTunnelRow.getField(i), column.getTypeInfo()));
+                    resolveObject2Maxcompute(
+                            seaTunnelRow.getField(i), column.getTypeInfo(), formatterContext));
         }
-        return arrayRecord;
+        return record;
     }
 
     public static SeaTunnelRowType getSeaTunnelRowType(ReadonlyConfig config) {
@@ -212,7 +215,8 @@ public class MaxcomputeTypeMapper implements Serializable {
         }
     }
 
-    private static Object resolveObject2Maxcompute(Object field, TypeInfo typeInfo) {
+    private static Object resolveObject2Maxcompute(
+            Object field, TypeInfo typeInfo, FormatterContext formatterContext) {
         if (field == null) {
             return null;
         }
@@ -243,15 +247,19 @@ public class MaxcomputeTypeMapper implements Serializable {
                 origDataMap.forEach(
                         (key, value) ->
                                 dataMap.put(
-                                        resolveObject2Maxcompute(key, keyTypeInfo),
-                                        resolveObject2Maxcompute(value, valueTypeInfo)));
+                                        resolveObject2Maxcompute(
+                                                key, keyTypeInfo, formatterContext),
+                                        resolveObject2Maxcompute(
+                                                value, valueTypeInfo, formatterContext)));
                 return origDataMap;
             case STRUCT:
                 Object[] fields = ((SeaTunnelRow) field).getFields();
                 List<TypeInfo> typeInfos = ((StructTypeInfo) typeInfo).getFieldTypeInfos();
                 ArrayList<Object> origStruct = new ArrayList<>();
                 for (int i = 0; i < fields.length; i++) {
-                    origStruct.add(resolveObject2Maxcompute(fields[i], typeInfos.get(i)));
+                    origStruct.add(
+                            resolveObject2Maxcompute(
+                                    fields[i], typeInfos.get(i), formatterContext));
                 }
                 return new SimpleStruct((StructTypeInfo) typeInfo, origStruct);
             case TINYINT:
@@ -272,6 +280,9 @@ public class MaxcomputeTypeMapper implements Serializable {
             case CHAR:
                 return new Char((String) field);
             case STRING:
+                if (formatterContext.isDateTimeType(field)) {
+                    return formatterContext.formatDateTime(field);
+                }
             case JSON:
                 if (field instanceof byte[]) {
                     return new String((byte[]) field);
