@@ -17,28 +17,22 @@
 
 package org.apache.seatunnel.connectors.seatunnel.openmldb.source;
 
-import org.apache.seatunnel.shade.com.typesafe.config.Config;
-
 import org.apache.seatunnel.api.common.JobContext;
-import org.apache.seatunnel.api.common.PrepareFailException;
-import org.apache.seatunnel.api.common.SeaTunnelAPIErrorCode;
 import org.apache.seatunnel.api.source.Boundedness;
-import org.apache.seatunnel.api.source.SeaTunnelSource;
 import org.apache.seatunnel.api.source.SupportColumnProjection;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
+import org.apache.seatunnel.api.table.catalog.PhysicalColumn;
+import org.apache.seatunnel.api.table.catalog.TableIdentifier;
+import org.apache.seatunnel.api.table.catalog.TableSchema;
 import org.apache.seatunnel.api.table.type.BasicType;
 import org.apache.seatunnel.api.table.type.LocalTimeType;
 import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
-import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
-import org.apache.seatunnel.common.config.CheckConfigUtil;
-import org.apache.seatunnel.common.config.CheckResult;
 import org.apache.seatunnel.common.constants.JobMode;
-import org.apache.seatunnel.common.constants.PluginType;
 import org.apache.seatunnel.common.exception.CommonErrorCodeDeprecated;
 import org.apache.seatunnel.connectors.seatunnel.common.source.AbstractSingleSplitReader;
 import org.apache.seatunnel.connectors.seatunnel.common.source.AbstractSingleSplitSource;
 import org.apache.seatunnel.connectors.seatunnel.common.source.SingleSplitReaderContext;
-import org.apache.seatunnel.connectors.seatunnel.openmldb.config.OpenMldbConfig;
 import org.apache.seatunnel.connectors.seatunnel.openmldb.config.OpenMldbParameters;
 import org.apache.seatunnel.connectors.seatunnel.openmldb.config.OpenMldbSqlExecutor;
 import org.apache.seatunnel.connectors.seatunnel.openmldb.exception.OpenMldbConnectorException;
@@ -47,60 +41,20 @@ import com._4paradigm.openmldb.sdk.Column;
 import com._4paradigm.openmldb.sdk.Schema;
 import com._4paradigm.openmldb.sdk.SqlException;
 import com._4paradigm.openmldb.sdk.impl.SqlClusterExecutor;
-import com.google.auto.service.AutoService;
 
 import java.sql.SQLException;
 import java.sql.Types;
+import java.util.Collections;
 import java.util.List;
 
-@AutoService(SeaTunnelSource.class)
 public class OpenMldbSource extends AbstractSingleSplitSource<SeaTunnelRow>
         implements SupportColumnProjection {
-    private OpenMldbParameters openMldbParameters;
+    private final OpenMldbParameters openMldbParameters;
+    private final CatalogTable catalogTable;
     private JobContext jobContext;
-    private SeaTunnelRowType seaTunnelRowType;
 
-    @Override
-    public String getPluginName() {
-        return "OpenMldb";
-    }
-
-    @Override
-    public void prepare(Config pluginConfig) throws PrepareFailException {
-        CheckResult result =
-                CheckConfigUtil.checkAllExists(
-                        pluginConfig,
-                        OpenMldbConfig.CLUSTER_MODE.key(),
-                        OpenMldbConfig.SQL.key(),
-                        OpenMldbConfig.DATABASE.key());
-        if (!result.isSuccess()) {
-            throw new OpenMldbConnectorException(
-                    SeaTunnelAPIErrorCode.CONFIG_VALIDATION_FAILED,
-                    String.format(
-                            "PluginName: %s, PluginType: %s, Message: %s",
-                            getPluginName(), PluginType.SOURCE, result.getMsg()));
-        }
-        if (pluginConfig.getBoolean(OpenMldbConfig.CLUSTER_MODE.key())) {
-            // cluster mode
-            result =
-                    CheckConfigUtil.checkAllExists(
-                            pluginConfig,
-                            OpenMldbConfig.ZK_HOST.key(),
-                            OpenMldbConfig.ZK_PATH.key());
-        } else {
-            // single mode
-            result =
-                    CheckConfigUtil.checkAllExists(
-                            pluginConfig, OpenMldbConfig.HOST.key(), OpenMldbConfig.PORT.key());
-        }
-        if (!result.isSuccess()) {
-            throw new OpenMldbConnectorException(
-                    SeaTunnelAPIErrorCode.CONFIG_VALIDATION_FAILED,
-                    String.format(
-                            "PluginName: %s, PluginType: %s, Message: %s",
-                            getPluginName(), PluginType.SOURCE, result.getMsg()));
-        }
-        this.openMldbParameters = OpenMldbParameters.buildWithConfig(pluginConfig);
+    public OpenMldbSource(OpenMldbParameters openMldbParameters) {
+        this.openMldbParameters = openMldbParameters;
         OpenMldbSqlExecutor.initSdkOption(openMldbParameters);
         try {
             SqlClusterExecutor sqlExecutor = OpenMldbSqlExecutor.getSqlExecutor();
@@ -108,7 +62,7 @@ public class OpenMldbSource extends AbstractSingleSplitSource<SeaTunnelRow>
                     sqlExecutor.getInputSchema(
                             openMldbParameters.getDatabase(), openMldbParameters.getSql());
             List<Column> columnList = inputSchema.getColumnList();
-            this.seaTunnelRowType = convert(columnList);
+            this.catalogTable = convert(columnList);
         } catch (SQLException | SqlException e) {
             throw new OpenMldbConnectorException(
                     CommonErrorCodeDeprecated.TABLE_SCHEMA_GET_FAILED,
@@ -116,6 +70,11 @@ public class OpenMldbSource extends AbstractSingleSplitSource<SeaTunnelRow>
         }
     }
 
+    @Override
+    public String getPluginName() {
+        return "OpenMldb";
+    }
+
     @Override
     public Boundedness getBoundedness() {
         return JobMode.BATCH.equals(jobContext.getJobMode())
@@ -124,14 +83,15 @@ public class OpenMldbSource extends AbstractSingleSplitSource<SeaTunnelRow>
     }
 
     @Override
-    public SeaTunnelDataType<SeaTunnelRow> getProducedType() {
-        return seaTunnelRowType;
+    public List<CatalogTable> getProducedCatalogTables() {
+        return Collections.singletonList(catalogTable);
     }
 
     @Override
     public AbstractSingleSplitReader<SeaTunnelRow> createReader(
             SingleSplitReaderContext readerContext) throws Exception {
-        return new OpenMldbSourceReader(openMldbParameters, seaTunnelRowType, readerContext);
+        return new OpenMldbSourceReader(
+                openMldbParameters, catalogTable.getSeaTunnelRowType(), readerContext);
     }
 
     @Override
@@ -166,14 +126,24 @@ public class OpenMldbSource extends AbstractSingleSplitSource<SeaTunnelRow>
         }
     }
 
-    private SeaTunnelRowType convert(List<Column> columnList) {
-        String[] fieldsName = new String[columnList.size()];
-        SeaTunnelDataType<?>[] fieldsType = new SeaTunnelDataType<?>[columnList.size()];
+    private CatalogTable convert(List<Column> columnList) {
+        TableSchema.Builder builder = TableSchema.builder();
         for (int i = 0; i < columnList.size(); i++) {
             Column column = columnList.get(i);
-            fieldsName[i] = column.getColumnName();
-            fieldsType[i] = convertSeaTunnelDataType(column.getSqlType());
+            builder.column(
+                    PhysicalColumn.of(
+                            column.getColumnName(),
+                            convertSeaTunnelDataType(column.getSqlType()),
+                            (Long) null,
+                            column.isNotNull(),
+                            null,
+                            null));
         }
-        return new SeaTunnelRowType(fieldsName, fieldsType);
+        return CatalogTable.of(
+                TableIdentifier.of("OpenMldb", openMldbParameters.getDatabase(), "default"),
+                builder.build(),
+                null,
+                null,
+                null);
     }
 }
