@@ -22,6 +22,7 @@ import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.table.catalog.Catalog;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.Column;
+import org.apache.seatunnel.api.table.catalog.PrimaryKey;
 import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.catalog.TableSchema;
 import org.apache.seatunnel.api.table.catalog.exception.CatalogException;
@@ -38,6 +39,7 @@ import org.apache.seatunnel.connectors.seatunnel.paimon.exception.PaimonConnecto
 import org.apache.seatunnel.connectors.seatunnel.paimon.sink.PaimonSink;
 import org.apache.seatunnel.connectors.seatunnel.paimon.utils.SchemaUtil;
 
+import org.apache.paimon.CoreOptions;
 import org.apache.paimon.catalog.Identifier;
 import org.apache.paimon.schema.Schema;
 import org.apache.paimon.schema.SchemaChange;
@@ -51,6 +53,8 @@ import lombok.extern.slf4j.Slf4j;
 
 import java.io.Closeable;
 import java.io.IOException;
+import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
@@ -103,7 +107,8 @@ public class PaimonCatalog implements Catalog, PaimonTable {
 
     @Override
     public boolean databaseExists(String databaseName) throws CatalogException {
-        return catalog.databaseExists(databaseName);
+        List<String> listDatabases = catalog.listDatabases();
+        return listDatabases.contains(databaseName);
     }
 
     @Override
@@ -123,7 +128,16 @@ public class PaimonCatalog implements Catalog, PaimonTable {
 
     @Override
     public boolean tableExists(TablePath tablePath) throws CatalogException {
-        return catalog.tableExists(toIdentifier(tablePath));
+        Identifier identifier = toIdentifier(tablePath);
+        List<String> tables = new ArrayList<>();
+        try {
+            if (databaseExists(identifier.getDatabaseName())) {
+                tables = catalog.listTables(identifier.getDatabaseName());
+            }
+        } catch (org.apache.paimon.catalog.Catalog.DatabaseNotExistException e) {
+            return false;
+        }
+        return tables.contains(identifier.getTableName());
     }
 
     @Override
@@ -218,7 +232,9 @@ public class PaimonCatalog implements Catalog, PaimonTable {
         Schema.Builder builder = Schema.newBuilder();
         schema.fields()
                 .forEach(field -> builder.column(field.name(), field.type(), field.description()));
-        builder.options(schema.options());
+        Map<String, String> options = new HashMap<>(schema.options());
+        options.remove(CoreOptions.PATH.key());
+        builder.options(options);
         builder.primaryKey(schema.primaryKeys());
         builder.partitionKeys(schema.partitionKeys());
         builder.comment(schema.comment());
@@ -271,6 +287,10 @@ public class PaimonCatalog implements Catalog, PaimonTable {
                 });
 
         List<String> partitionKeys = schema.partitionKeys();
+        List<String> primaryKyes = schema.primaryKeys();
+        if (!primaryKyes.isEmpty()) {
+            builder.primaryKey(PrimaryKey.of("pk", primaryKyes));
+        }
 
         return CatalogTable.of(
                 org.apache.seatunnel.api.table.catalog.TableIdentifier.of(
@@ -298,7 +318,9 @@ public class PaimonCatalog implements Catalog, PaimonTable {
             }
         } else if (cause instanceof RuntimeException) {
             String message = cause.getMessage();
-            if (message.contains("Cannot define 'bucket-key' in unaware or dynamic bucket mode.")) {
+            // https://github.com/apache/paimon/pull/3320/files#diff-d3e068ea8caf83d2371f0eaa1cbf3d02ff06e1c1cdceec5fab2e065cecd96230
+            if (message.contains(
+                    "Cannot define 'bucket-key' with bucket -1, please specify a bucket number.")) {
                 throw new PaimonConnectorException(
                         PaimonConnectorErrorCode.WRITE_PROPS_BUCKET_KEY_ERROR, message);
             }
