@@ -22,8 +22,8 @@ import org.apache.seatunnel.api.configuration.util.OptionRule;
 import org.apache.seatunnel.api.table.catalog.Catalog;
 import org.apache.seatunnel.api.table.factory.CatalogFactory;
 import org.apache.seatunnel.api.table.factory.Factory;
-import org.apache.seatunnel.connectors.seatunnel.paimon.config.PaimonConfig;
-import org.apache.seatunnel.connectors.seatunnel.paimon.config.PaimonSinkConfig;
+import org.apache.seatunnel.connectors.seatunnel.paimon.config.PaimonBaseOptions;
+import org.apache.seatunnel.connectors.seatunnel.paimon.config.PaimonSinkOptions;
 
 import com.google.auto.service.AutoService;
 
@@ -42,19 +42,24 @@ public class PaimonCatalogFactory implements CatalogFactory {
     @Override
     public OptionRule optionRule() {
         return OptionRule.builder()
-                .required(PaimonConfig.WAREHOUSE, PaimonConfig.DATABASE, PaimonConfig.TABLE)
+                .required(
+                        PaimonBaseOptions.WAREHOUSE,
+                        PaimonBaseOptions.DATABASE,
+                        PaimonBaseOptions.TABLE)
                 .optional(
-                        PaimonConfig.HDFS_SITE_PATH,
-                        PaimonConfig.HADOOP_CONF,
-                        PaimonConfig.HADOOP_CONF_PATH,
-                        PaimonConfig.CATALOG_TYPE,
-                        PaimonSinkConfig.SCHEMA_SAVE_MODE,
-                        PaimonSinkConfig.DATA_SAVE_MODE,
-                        PaimonSinkConfig.PRIMARY_KEYS,
-                        PaimonSinkConfig.PARTITION_KEYS,
-                        PaimonSinkConfig.WRITE_PROPS)
+                        PaimonBaseOptions.HDFS_SITE_PATH,
+                        PaimonBaseOptions.HADOOP_CONF,
+                        PaimonBaseOptions.HADOOP_CONF_PATH,
+                        PaimonBaseOptions.CATALOG_TYPE,
+                        PaimonSinkOptions.SCHEMA_SAVE_MODE,
+                        PaimonSinkOptions.DATA_SAVE_MODE,
+                        PaimonSinkOptions.PRIMARY_KEYS,
+                        PaimonSinkOptions.PARTITION_KEYS,
+                        PaimonSinkOptions.WRITE_PROPS)
                 .conditional(
-                        PaimonConfig.CATALOG_TYPE, PaimonCatalogEnum.HIVE, PaimonConfig.CATALOG_URI)
+                        PaimonBaseOptions.CATALOG_TYPE,
+                        PaimonCatalogEnum.HIVE,
+                        PaimonBaseOptions.CATALOG_URI)
                 .build();
     }
 }
