@@ -17,6 +17,7 @@
 
 package org.apache.seatunnel.connectors.seatunnel.paimon.catalog;
 
+import org.apache.seatunnel.connectors.seatunnel.paimon.config.PaimonBaseOptions;
 import org.apache.seatunnel.connectors.seatunnel.paimon.config.PaimonConfig;
 import org.apache.seatunnel.connectors.seatunnel.paimon.config.PaimonHadoopConfiguration;
 import org.apache.seatunnel.connectors.seatunnel.paimon.exception.PaimonConnectorErrorCode;
@@ -31,6 +32,7 @@ import org.apache.paimon.catalog.CatalogContext;
 import org.apache.paimon.catalog.CatalogFactory;
 import org.apache.paimon.options.CatalogOptions;
 import org.apache.paimon.options.Options;
+import org.apache.paimon.privilege.PrivilegedCatalog;
 
 import lombok.extern.slf4j.Slf4j;
 
@@ -46,7 +48,7 @@ public class PaimonCatalogLoader implements Serializable {
 
     private static final String HDFS_PREFIX = "hdfs://";
     private static final String S3A_PREFIX = "s3a://";
-    /** ********* Hdfs constants ************* */
+    /** ******* Hdfs constants ************* */
     private static final String HDFS_IMPL = "org.apache.hadoop.hdfs.DistributedFileSystem";
 
     private static final String HDFS_IMPL_KEY = "fs.hdfs.impl";
@@ -58,12 +60,16 @@ public class PaimonCatalogLoader implements Serializable {
     private String catalogUri;
 
     private PaimonHadoopConfiguration paimonHadoopConfiguration;
+    protected String user;
+    protected String password;
 
     public PaimonCatalogLoader(PaimonConfig paimonConfig) {
         this.warehouse = paimonConfig.getWarehouse();
         this.catalogType = paimonConfig.getCatalogType();
         this.catalogUri = paimonConfig.getCatalogUri();
         this.paimonHadoopConfiguration = PaimonSecurityContext.loadHadoopConfig(paimonConfig);
+        this.user = paimonConfig.getUser();
+        this.password = paimonConfig.getPassword();
     }
 
     public Catalog loadCatalog() {
@@ -72,6 +78,10 @@ public class PaimonCatalogLoader implements Serializable {
         final Map<String, String> optionsMap = new HashMap<>(1);
         optionsMap.put(CatalogOptions.WAREHOUSE.key(), warehouse);
         optionsMap.put(CatalogOptions.METASTORE.key(), catalogType.getType());
+        if (StringUtils.isNotBlank(user) && StringUtils.isNotBlank(password)) {
+            optionsMap.put(PaimonBaseOptions.USER.key(), user);
+            optionsMap.put(PaimonBaseOptions.PASSWORD.key(), password);
+        }
         if (warehouse.startsWith(HDFS_PREFIX)) {
             checkConfiguration(paimonHadoopConfiguration, HDFS_DEF_FS_NAME);
             paimonHadoopConfiguration.set(HDFS_IMPL_KEY, HDFS_IMPL);
@@ -91,13 +101,23 @@ public class PaimonCatalogLoader implements Serializable {
         final CatalogContext catalogContext =
                 CatalogContext.create(options, paimonHadoopConfiguration);
         try {
-            return PaimonSecurityContext.runSecured(
-                    () -> CatalogFactory.createCatalog(catalogContext));
+            // If paimon privilege enabled, there will be system tables named user.sys and
+            // privilege.sys in the warehouse.
+            // It returns a PrivilegedCatalog. Otherwise, it returns a CachingCatalog.
+            // If paimon privilege enabled, perform user and password verification accordingly.
+            Catalog catalog =
+                    PaimonSecurityContext.runSecured(
+                            () -> CatalogFactory.createCatalog(catalogContext));
+            if (catalog instanceof PrivilegedCatalog
+                    && StringUtils.isBlank(user)
+                    && StringUtils.isBlank(password)) {
+                throw new IllegalArgumentException(
+                        "paimon privilege is enabled, user and password is required");
+            }
+            return catalog;
         } catch (Exception e) {
             throw new PaimonConnectorException(
-                    PaimonConnectorErrorCode.LOAD_CATALOG,
-                    "Failed to perform SecurityContext.runSecured",
-                    e);
+                    PaimonConnectorErrorCode.LOAD_CATALOG, e.getMessage(), e);
         }
     }
 
