@@ -29,6 +29,7 @@ import org.apache.seatunnel.api.sink.SupportMultiTableSink;
 import org.apache.seatunnel.api.sink.SupportSaveMode;
 import org.apache.seatunnel.api.sink.SupportSchemaEvolutionSink;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
+import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.schema.SchemaChangeType;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.connectors.seatunnel.paimon.catalog.PaimonCatalog;
@@ -36,6 +37,7 @@ import org.apache.seatunnel.connectors.seatunnel.paimon.config.PaimonHadoopConfi
 import org.apache.seatunnel.connectors.seatunnel.paimon.config.PaimonSinkConfig;
 import org.apache.seatunnel.connectors.seatunnel.paimon.handler.PaimonSaveModeHandler;
 import org.apache.seatunnel.connectors.seatunnel.paimon.security.PaimonSecurityContext;
+import org.apache.seatunnel.connectors.seatunnel.paimon.sink.bucket.PaimonBucketAssignerFactory;
 import org.apache.seatunnel.connectors.seatunnel.paimon.sink.commit.PaimonAggregatedCommitInfo;
 import org.apache.seatunnel.connectors.seatunnel.paimon.sink.commit.PaimonAggregatedCommitter;
 import org.apache.seatunnel.connectors.seatunnel.paimon.sink.commit.PaimonCommitInfo;
@@ -47,6 +49,7 @@ import java.io.IOException;
 import java.util.Arrays;
 import java.util.List;
 import java.util.Optional;
+import java.util.UUID;
 
 public class PaimonSink
         implements SeaTunnelSink<
@@ -75,11 +78,28 @@ public class PaimonSink
 
     private final PaimonHadoopConfiguration paimonHadoopConfiguration;
 
+    private final PaimonBucketAssignerFactory paimonBucketAssignerFactory;
+
+    private final String commitUser = UUID.randomUUID().toString();
+
     public PaimonSink(ReadonlyConfig readonlyConfig, CatalogTable catalogTable) {
         this.readonlyConfig = readonlyConfig;
         this.paimonSinkConfig = new PaimonSinkConfig(readonlyConfig);
         this.catalogTable = catalogTable;
         this.paimonHadoopConfiguration = PaimonSecurityContext.loadHadoopConfig(paimonSinkConfig);
+        this.paimonBucketAssignerFactory = new PaimonBucketAssignerFactory();
+        try (PaimonCatalog paimonCatalog = PaimonCatalog.loadPaimonCatalog(readonlyConfig)) {
+            paimonCatalog.open();
+            boolean databaseExists =
+                    paimonCatalog.databaseExists(this.paimonSinkConfig.getNamespace());
+            if (databaseExists) {
+                TablePath tablePath = catalogTable.getTablePath();
+                boolean tableExists = paimonCatalog.tableExists(tablePath);
+                if (tableExists) {
+                    this.paimonTable = paimonCatalog.getPaimonTable(tablePath);
+                }
+            }
+        }
     }
 
     @Override
@@ -94,9 +114,11 @@ public class PaimonSink
                 readonlyConfig,
                 catalogTable,
                 paimonTable,
+                commitUser,
                 jobContext,
                 paimonSinkConfig,
-                paimonHadoopConfiguration);
+                paimonHadoopConfiguration,
+                paimonBucketAssignerFactory);
     }
 
     @Override
@@ -113,10 +135,12 @@ public class PaimonSink
                 readonlyConfig,
                 catalogTable,
                 paimonTable,
+                commitUser,
                 states,
                 jobContext,
                 paimonSinkConfig,
-                paimonHadoopConfiguration);
+                paimonHadoopConfiguration,
+                paimonBucketAssignerFactory);
     }
 
     @Override
@@ -152,6 +176,11 @@ public class PaimonSink
         this.paimonTable = table;
     }
 
+    @Override
+    public Table getLoadTable() {
+        return paimonTable;
+    }
+
     @Override
     public Optional<CatalogTable> getWriteCatalogTable() {
         return Optional.ofNullable(catalogTable);
