@@ -24,11 +24,10 @@ import org.apache.seatunnel.connectors.seatunnel.paimon.exception.PaimonConnecto
 import org.apache.seatunnel.connectors.seatunnel.paimon.exception.PaimonConnectorException;
 import org.apache.seatunnel.connectors.seatunnel.paimon.security.PaimonSecurityContext;
 
+import org.apache.paimon.table.FileStoreTable;
 import org.apache.paimon.table.Table;
 import org.apache.paimon.table.sink.CommitMessage;
-import org.apache.paimon.table.sink.StreamTableCommit;
-import org.apache.paimon.table.sink.TableCommit;
-import org.apache.paimon.table.sink.WriteBuilder;
+import org.apache.paimon.table.sink.TableCommitImpl;
 
 import lombok.extern.slf4j.Slf4j;
 
@@ -38,6 +37,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.concurrent.CopyOnWriteArrayList;
+import java.util.stream.Collectors;
 
 /** Paimon connector aggregated committer class */
 @Slf4j
@@ -47,57 +47,94 @@ public class PaimonAggregatedCommitter
 
     private static final long serialVersionUID = 1L;
 
-    private final WriteBuilder tableWriteBuilder;
+    private final FileStoreTable table;
 
     public PaimonAggregatedCommitter(
             Table table, PaimonHadoopConfiguration paimonHadoopConfiguration) {
-        this.tableWriteBuilder = table.newStreamWriteBuilder();
+        this.table = (FileStoreTable) table;
         PaimonSecurityContext.shouldEnableKerberos(paimonHadoopConfiguration);
     }
 
     @Override
     public List<PaimonAggregatedCommitInfo> commit(
             List<PaimonAggregatedCommitInfo> aggregatedCommitInfo) throws IOException {
-        try (TableCommit tableCommit = tableWriteBuilder.newCommit()) {
+        aggregatedCommitInfo.stream()
+                .collect(Collectors.groupingBy(PaimonAggregatedCommitInfo::getCommitUser))
+                .forEach(this::commit);
+        return Collections.emptyList();
+    }
+
+    private void commit(String commitUser, List<PaimonAggregatedCommitInfo> aggregatedCommitInfo) {
+        try (TableCommitImpl tableCommit = table.newCommit(commitUser)) {
             PaimonSecurityContext.runSecured(
                     () -> {
                         log.debug("Trying to commit states streaming mode");
-                        aggregatedCommitInfo.stream()
-                                .flatMap(
-                                        paimonAggregatedCommitInfo ->
-                                                paimonAggregatedCommitInfo.getCommittablesMap()
-                                                        .entrySet().stream())
-                                .forEach(
-                                        entry ->
-                                                ((StreamTableCommit) tableCommit)
-                                                        .commit(entry.getKey(), entry.getValue()));
+                        Map<Long, List<CommitMessage>> committablesMap =
+                                aggregatedCommitInfo.stream()
+                                        .flatMap(
+                                                paimonAggregatedCommitInfo ->
+                                                        paimonAggregatedCommitInfo
+                                                                .getCommittablesMap().entrySet()
+                                                                .stream())
+                                        .collect(
+                                                Collectors.toMap(
+                                                        Map.Entry::getKey, Map.Entry::getValue));
+                        if (!committablesMap.isEmpty()) {
+                            tableCommit.filterAndCommit(committablesMap);
+                        }
                         return null;
                     });
         } catch (Exception e) {
             throw new PaimonConnectorException(
-                    PaimonConnectorErrorCode.TABLE_WRITE_COMMIT_FAILED,
-                    "Paimon table storage write-commit Failed.",
-                    e);
+                    PaimonConnectorErrorCode.TABLE_WRITE_COMMIT_FAILED, e);
         }
-        return Collections.emptyList();
     }
 
     @Override
     public PaimonAggregatedCommitInfo combine(List<PaimonCommitInfo> commitInfos) {
-        Map<Long, List<CommitMessage>> committables = new HashMap<>();
+        String commitUser = commitInfos.get(0).getCommitUser();
+        Map<Long, List<CommitMessage>> commitTables = new HashMap<>();
         commitInfos.forEach(
                 commitInfo ->
-                        committables
+                        commitTables
                                 .computeIfAbsent(
                                         commitInfo.getCheckpointId(),
                                         id -> new CopyOnWriteArrayList<>())
                                 .addAll(commitInfo.getCommittables()));
-        return new PaimonAggregatedCommitInfo(committables);
+        return new PaimonAggregatedCommitInfo(commitTables, commitUser);
     }
 
     @Override
     public void abort(List<PaimonAggregatedCommitInfo> aggregatedCommitInfo) throws Exception {
-        // TODO find the right way to abort
+        aggregatedCommitInfo.stream()
+                .collect(Collectors.groupingBy(PaimonAggregatedCommitInfo::getCommitUser))
+                .forEach(this::abort);
+    }
+
+    private void abort(String commitUser, List<PaimonAggregatedCommitInfo> aggregatedCommitInfo) {
+        try (TableCommitImpl tableCommit = table.newCommit(commitUser)) {
+            PaimonSecurityContext.runSecured(
+                    () -> {
+                        log.debug("Trying to commit states streaming mode");
+                        Map<Long, List<CommitMessage>> committablesMap =
+                                aggregatedCommitInfo.stream()
+                                        .flatMap(
+                                                paimonAggregatedCommitInfo ->
+                                                        paimonAggregatedCommitInfo
+                                                                .getCommittablesMap().entrySet()
+                                                                .stream())
+                                        .collect(
+                                                Collectors.toMap(
+                                                        Map.Entry::getKey, Map.Entry::getValue));
+                        if (!committablesMap.isEmpty()) {
+                            committablesMap.values().forEach(tableCommit::abort);
+                        }
+                        return null;
+                    });
+        } catch (Exception e) {
+            throw new PaimonConnectorException(
+                    PaimonConnectorErrorCode.TABLE_WRITE_COMMIT_FAILED, e);
+        }
     }
 
     @Override
