@@ -32,7 +32,7 @@ public class PaimonSinkState implements Serializable {
 
     private static final long serialVersionUID = 1L;
 
-    private List<CommitMessage> committables;
+    private List<CommitMessage> commitTables;
 
     private String commitUser;
 
