@@ -17,6 +17,9 @@
 
 package org.apache.seatunnel.connectors.seatunnel.paimon.source;
 
+import org.apache.seatunnel.shade.com.google.common.collect.Lists;
+import org.apache.seatunnel.shade.com.google.common.collect.Maps;
+
 import org.apache.seatunnel.api.common.JobContext;
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.source.Boundedness;
@@ -42,9 +45,9 @@ import org.apache.paimon.types.RowType;
 
 import net.sf.jsqlparser.statement.select.PlainSelect;
 
-import java.util.Collections;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.Map;
 import java.util.Objects;
 
 import static org.apache.seatunnel.connectors.seatunnel.paimon.source.converter.SqlToPaimonPredicateConverter.convertSqlSelectToPaimonProjectionIndex;
@@ -58,43 +61,57 @@ public class PaimonSource
 
     public static final String PLUGIN_NAME = "Paimon";
 
-    private SeaTunnelRowType seaTunnelRowType;
-
-    private Table paimonTable;
-
     private JobContext jobContext;
 
-    private CatalogTable catalogTable;
-
-    protected final ReadBuilder readBuilder;
+    private List<CatalogTable> catalogTables = Lists.newArrayList();
+    private Map<String, Table> paimonTables = Maps.newHashMap();
+    private Map<String, SeaTunnelRowType> seaTunnelRowTypes = Maps.newHashMap();
+    private Map<String, ReadBuilder> readBuilders = Maps.newHashMap();
 
     public PaimonSource(ReadonlyConfig readonlyConfig, PaimonCatalog paimonCatalog) {
-        PaimonSourceConfig paimonSourceConfig = new PaimonSourceConfig(readonlyConfig);
-        TablePath tablePath =
-                TablePath.of(paimonSourceConfig.getNamespace(), paimonSourceConfig.getTable());
-        this.catalogTable = paimonCatalog.getTable(tablePath);
-        this.paimonTable = paimonCatalog.getPaimonTable(tablePath);
+        new PaimonSourceConfig(readonlyConfig)
+                .getTableConfigList()
+                .forEach(
+                        tableConfig -> {
+                            TablePath tablePath = tableConfig.getTablePath();
+                            CatalogTable catalogTable = paimonCatalog.getTable(tablePath);
+                            Table paimonTable = paimonCatalog.getPaimonTable(tablePath);
+                            RowType paimonRowType = paimonTable.rowType();
+                            String[] filedNames =
+                                    paimonRowType.getFieldNames().toArray(new String[0]);
 
-        String filterSql = paimonSourceConfig.getQuery();
-        PlainSelect plainSelect = convertToPlainSelect(filterSql);
-        RowType paimonRowType = this.paimonTable.rowType();
-        String[] filedNames = paimonRowType.getFieldNames().toArray(new String[0]);
+                            PlainSelect plainSelect = convertToPlainSelect(tableConfig.getQuery());
+                            Predicate predicate = null;
+                            int[] projectionIndex = null;
+                            if (!Objects.isNull(plainSelect)) {
+                                projectionIndex =
+                                        convertSqlSelectToPaimonProjectionIndex(
+                                                filedNames, plainSelect);
+                                if (!Objects.isNull(projectionIndex)) {
+                                    catalogTable =
+                                            paimonCatalog.getTableWithProjection(
+                                                    tablePath, projectionIndex);
+                                }
+                                predicate =
+                                        SqlToPaimonPredicateConverter
+                                                .convertSqlWhereToPaimonPredicate(
+                                                        paimonRowType, plainSelect);
+                            }
+                            this.catalogTables.add(catalogTable);
+                            String tableKey = tablePath.toString();
+                            this.seaTunnelRowTypes.put(
+                                    tableKey,
+                                    RowTypeConverter.convert(paimonRowType, projectionIndex));
 
-        Predicate predicate = null;
-        int[] projectionIndex = null;
-        if (!Objects.isNull(plainSelect)) {
-            projectionIndex = convertSqlSelectToPaimonProjectionIndex(filedNames, plainSelect);
-            if (!Objects.isNull(projectionIndex)) {
-                this.catalogTable =
-                        paimonCatalog.getTableWithProjection(tablePath, projectionIndex);
-            }
-            predicate =
-                    SqlToPaimonPredicateConverter.convertSqlWhereToPaimonPredicate(
-                            paimonRowType, plainSelect);
-        }
-        this.seaTunnelRowType = RowTypeConverter.convert(paimonRowType, projectionIndex);
-        this.readBuilder =
-                paimonTable.newReadBuilder().withProjection(projectionIndex).withFilter(predicate);
+                            ReadBuilder readBuilder =
+                                    paimonTable
+                                            .newReadBuilder()
+                                            .withProjection(projectionIndex)
+                                            .withFilter(predicate);
+
+                            this.paimonTables.put(tableKey, paimonTable);
+                            this.readBuilders.put(tableKey, readBuilder);
+                        });
     }
 
     @Override
@@ -104,7 +121,7 @@ public class PaimonSource
 
     @Override
     public List<CatalogTable> getProducedCatalogTables() {
-        return Collections.singletonList(catalogTable);
+        return catalogTables;
     }
 
     @Override
@@ -122,8 +139,7 @@ public class PaimonSource
     @Override
     public SourceReader<SeaTunnelRow, PaimonSourceSplit> createReader(
             SourceReader.Context readerContext) throws Exception {
-        return new PaimonSourceReader(
-                readerContext, paimonTable, seaTunnelRowType, readBuilder.newRead());
+        return new PaimonSourceReader(readerContext, paimonTables, seaTunnelRowTypes, readBuilders);
     }
 
     @Override
@@ -131,10 +147,10 @@ public class PaimonSource
             SourceSplitEnumerator.Context<PaimonSourceSplit> enumeratorContext) throws Exception {
         if (getBoundedness() == Boundedness.BOUNDED) {
             return new PaimonBatchSourceSplitEnumerator(
-                    enumeratorContext, new LinkedList<>(), null, readBuilder.newScan(), 1);
+                    enumeratorContext, new LinkedList<>(), null, readBuilders, 1);
         }
         return new PaimonStreamSourceSplitEnumerator(
-                enumeratorContext, new LinkedList<>(), null, readBuilder.newStreamScan(), 1);
+                enumeratorContext, new LinkedList<>(), null, readBuilders, 1);
     }
 
     @Override
@@ -147,14 +163,14 @@ public class PaimonSource
                     enumeratorContext,
                     checkpointState.getAssignedSplits(),
                     checkpointState.getCurrentSnapshotId(),
-                    readBuilder.newScan(),
+                    readBuilders,
                     1);
         }
         return new PaimonStreamSourceSplitEnumerator(
                 enumeratorContext,
                 checkpointState.getAssignedSplits(),
                 checkpointState.getCurrentSnapshotId(),
-                readBuilder.newStreamScan(),
+                readBuilders,
                 1);
     }
 }
