@@ -21,20 +21,26 @@ import org.apache.seatunnel.api.source.SourceSplit;
 
 import org.apache.paimon.table.source.Split;
 
-import lombok.AllArgsConstructor;
 import lombok.Getter;
 
 /** Paimon source split, wrapped the {@link Split} of paimon table. */
 @Getter
-@AllArgsConstructor
 public class PaimonSourceSplit implements SourceSplit {
     private static final long serialVersionUID = 1L;
 
     /** The unique ID of the split. Unique within the scope of this source. */
     private final String id;
 
+    private final String tableId;
+
     private final Split split;
 
+    public PaimonSourceSplit(String id, String tableId, Split split) {
+        this.id = id;
+        this.tableId = tableId;
+        this.split = split;
+    }
+
     @Override
     public String splitId() {
         return split.toString();
