@@ -37,37 +37,44 @@ import java.util.function.Function;
 @Slf4j
 public class DefaultSeaTunnelRowSerializer implements SeaTunnelRowSerializer<byte[], byte[]> {
     private final String topic;
+    private final String tag;
     private final SerializationSchema keySerialization;
     private final SerializationSchema valueSerialization;
 
     public DefaultSeaTunnelRowSerializer(
             String topic,
+            String tag,
             SeaTunnelRowType seaTunnelRowType,
             SchemaFormat format,
             String delimiter) {
         this(
                 topic,
+                tag,
                 element -> null,
                 createSerializationSchema(seaTunnelRowType, format, delimiter));
     }
 
     public DefaultSeaTunnelRowSerializer(
             String topic,
+            String tag,
             List<String> keyFieldNames,
             SeaTunnelRowType seaTunnelRowType,
             SchemaFormat format,
             String delimiter) {
         this(
                 topic,
+                tag,
                 createKeySerializationSchema(keyFieldNames, seaTunnelRowType),
                 createSerializationSchema(seaTunnelRowType, format, delimiter));
     }
 
     public DefaultSeaTunnelRowSerializer(
             String topic,
+            String tag,
             SerializationSchema keySerialization,
             SerializationSchema valueSerialization) {
         this.topic = topic;
+        this.tag = tag;
         this.keySerialization = keySerialization;
         this.valueSerialization = valueSerialization;
     }
@@ -123,6 +130,6 @@ public class DefaultSeaTunnelRowSerializer implements SeaTunnelRowSerializer<byt
             return null;
         }
         byte[] key = keySerialization.serialize(row);
-        return new Message(topic, null, key == null ? null : new String(key), value);
+        return new Message(topic, tag, key == null ? null : new String(key), value);
     }
 }
