@@ -17,6 +17,8 @@
 
 package org.apache.seatunnel.connectors.seatunnel.starrocks.catalog;
 
+import org.apache.seatunnel.shade.com.google.common.collect.ImmutableMap;
+
 import org.apache.seatunnel.api.table.catalog.DataTypeConvertor;
 import org.apache.seatunnel.api.table.type.BasicType;
 import org.apache.seatunnel.api.table.type.DecimalType;
@@ -29,13 +31,12 @@ import org.apache.seatunnel.common.exception.CommonError;
 import org.apache.commons.collections4.MapUtils;
 
 import com.google.auto.service.AutoService;
-import com.google.common.collect.ImmutableMap;
 import com.mysql.cj.MysqlType;
 
 import java.util.Collections;
 import java.util.Map;
 
-import static com.google.common.base.Preconditions.checkNotNull;
+import static org.apache.seatunnel.shade.com.google.common.base.Preconditions.checkNotNull;
 
 @AutoService(DataTypeConvertor.class)
 public class StarRocksDataTypeConvertor implements DataTypeConvertor<MysqlType> {
