@@ -36,12 +36,19 @@ public class StarRocksSaveModeUtil extends CatalogUtil {
 
     public String columnToConnectorType(Column column) {
         checkNotNull(column, "The column is required.");
+        String columnType;
+        if (column.getSinkType() != null) {
+            columnType = column.getSinkType();
+        } else {
+            columnType =
+                    dataTypeToStarrocksType(
+                            column.getDataType(),
+                            column.getColumnLength() == null ? 0 : column.getColumnLength());
+        }
         return String.format(
                 "`%s` %s %s %s",
                 column.getName(),
-                dataTypeToStarrocksType(
-                        column.getDataType(),
-                        column.getColumnLength() == null ? 0 : column.getColumnLength()),
+                columnType,
                 column.isNullable() ? "NULL" : "NOT NULL",
                 StringUtils.isEmpty(column.getComment())
                         ? ""
