@@ -35,10 +35,12 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Base64;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.ServiceLoader;
+import java.util.Set;
 import java.util.function.BiFunction;
 
 /** Config shade utilities */
@@ -46,9 +48,11 @@ import java.util.function.BiFunction;
 public final class ConfigShadeUtils {
 
     private static final String SHADE_IDENTIFIER_OPTION = "shade.identifier";
+    private static final String SHADE_PROPS_OPTION = "shade.properties";
+    private static final String SHADE_OPTIONS_OPTION = "shade.options";
 
     public static final String[] DEFAULT_SENSITIVE_KEYWORDS =
-            new String[] {"password", "username", "auth", "token"};
+            new String[] {"password", "username", "auth", "token", "access_key", "secret_key"};
 
     private static final Map<String, ConfigShade> CONFIG_SHADES = new HashMap<>();
 
@@ -101,7 +105,14 @@ public final class ConfigShadeUtils {
                                 : ConfigFactory.empty(),
                         SHADE_IDENTIFIER_OPTION,
                         DEFAULT_SHADE.getIdentifier());
-        return decryptConfig(identifier, config);
+        Map<String, Object> props =
+                TypesafeConfigUtils.getConfig(
+                        config.hasPath(Constants.ENV)
+                                ? config.getConfig(Constants.ENV)
+                                : ConfigFactory.empty(),
+                        SHADE_PROPS_OPTION,
+                        new HashMap<>());
+        return decryptConfig(identifier, config, props);
     }
 
     public static Config encryptConfig(Config config) {
@@ -112,28 +123,51 @@ public final class ConfigShadeUtils {
                                 : ConfigFactory.empty(),
                         SHADE_IDENTIFIER_OPTION,
                         DEFAULT_SHADE.getIdentifier());
-        return encryptConfig(identifier, config);
+        Map<String, Object> props =
+                TypesafeConfigUtils.getConfig(
+                        config.hasPath(Constants.ENV)
+                                ? config.getConfig(Constants.ENV)
+                                : ConfigFactory.empty(),
+                        SHADE_PROPS_OPTION,
+                        new HashMap<>());
+        return encryptConfig(identifier, config, props);
     }
 
-    public static Config decryptConfig(String identifier, Config config) {
-        return processConfig(identifier, config, true);
+    private static Config decryptConfig(
+            String identifier, Config config, Map<String, Object> props) {
+        return processConfig(identifier, config, true, props);
     }
 
-    public static Config encryptConfig(String identifier, Config config) {
-        return processConfig(identifier, config, false);
+    private static Config encryptConfig(
+            String identifier, Config config, Map<String, Object> props) {
+        return processConfig(identifier, config, false, props);
     }
 
     @SuppressWarnings("unchecked")
-    private static Config processConfig(String identifier, Config config, boolean isDecrypted) {
+    private static Config processConfig(
+            String identifier, Config config, boolean isDecrypted, Map<String, Object> props) {
         ConfigShade configShade = CONFIG_SHADES.getOrDefault(identifier, DEFAULT_SHADE);
-        List<String> sensitiveOptions = new ArrayList<>(Arrays.asList(DEFAULT_SENSITIVE_KEYWORDS));
+        // call open method before the encrypt/decrypt
+        configShade.open(props);
+
+        Set<String> sensitiveOptions = new HashSet<>(getSensitiveOptions(config));
         sensitiveOptions.addAll(Arrays.asList(configShade.sensitiveOptions()));
-        BiFunction<String, Object, String> processFunction =
+        BiFunction<String, Object, Object> processFunction =
                 (key, value) -> {
-                    if (isDecrypted) {
-                        return configShade.decrypt(value.toString());
+                    if (value instanceof List) {
+                        List<String> list = (List<String>) value;
+                        List<String> processedList = new ArrayList<>();
+                        for (String element : list) {
+                            processedList.add(
+                                    isDecrypted
+                                            ? configShade.decrypt(element)
+                                            : configShade.encrypt(element));
+                        }
+                        return processedList;
                     } else {
-                        return configShade.encrypt(value.toString());
+                        return isDecrypted
+                                ? configShade.decrypt((String) value)
+                                : configShade.encrypt((String) value);
                     }
                 };
         String jsonString = config.root().render(ConfigRenderOptions.concise());
@@ -164,6 +198,19 @@ public final class ConfigShadeUtils {
         return ConfigFactory.parseMap(configMap);
     }
 
+    public static Set<String> getSensitiveOptions(Config config) {
+        Set<String> sensitiveOptions =
+                new HashSet<>(
+                        TypesafeConfigUtils.getConfig(
+                                config != null && config.hasPath(Constants.ENV)
+                                        ? config.getConfig(Constants.ENV)
+                                        : ConfigFactory.empty(),
+                                SHADE_OPTIONS_OPTION,
+                                new ArrayList<>()));
+        sensitiveOptions.addAll(Arrays.asList(DEFAULT_SENSITIVE_KEYWORDS));
+        return sensitiveOptions;
+    }
+
     public static class Base64ConfigShade implements ConfigShade {
 
         private static final Base64.Encoder ENCODER = Base64.getEncoder();
