@@ -45,9 +45,12 @@ import java.io.File;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.nio.file.Path;
+import java.sql.DriverManager;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.Collections;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 import java.util.stream.Collectors;
@@ -56,6 +59,18 @@ import java.util.stream.Stream;
 /** Used to execute a SeaTunnelTask. */
 public class FlinkExecution implements TaskExecution {
 
+    static {
+        // Load DriverManager first to avoid deadlock between DriverManager's
+        // static initialization block and specific driver class's static
+        // initialization block when two different driver classes are loading
+        // concurrently using Class.forName while DriverManager is uninitialized
+        // before.
+        //
+        // This could happen in JDK 8 but not above as driver loading has been
+        // moved out of DriverManager's static initialization block since JDK 9.
+        DriverManager.getDrivers();
+    }
+
     private static final Logger LOGGER = LoggerFactory.getLogger(FlinkExecution.class);
 
     private final FlinkRuntimeEnvironment flinkRuntimeEnvironment;
@@ -102,7 +117,8 @@ public class FlinkExecution implements TaskExecution {
                         jarPaths, envConfig, config.getConfigList(Constants.SINK), jobContext);
 
         this.flinkRuntimeEnvironment =
-                FlinkRuntimeEnvironment.getInstance(this.registerPlugin(config, jarPaths));
+                FlinkRuntimeEnvironment.getInstance(
+                        this.registerPlugin(config, new HashSet<>(jarPaths)));
 
         this.sourcePluginExecuteProcessor.setRuntimeEnvironment(flinkRuntimeEnvironment);
         this.transformPluginExecuteProcessor.setRuntimeEnvironment(flinkRuntimeEnvironment);
@@ -154,7 +170,7 @@ public class FlinkExecution implements TaskExecution {
                             Common.getThirdPartyJars(
                                     envConfig.getString(EnvCommonOptions.JARS.key())));
         }
-        thirdPartyJars.addAll(Common.getPluginsJarDependencies());
+        thirdPartyJars.addAll(Common.getPluginsJarDependenciesWithoutConnectorDependency());
         List<URL> jarDependencies =
                 Stream.concat(thirdPartyJars.stream(), Common.getLibJars().stream())
                         .map(Path::toUri)
@@ -168,14 +184,12 @@ public class FlinkExecution implements TaskExecution {
                                     }
                                 })
                         .collect(Collectors.toList());
-        jarDependencies.forEach(
-                url ->
-                        FlinkAbstractPluginExecuteProcessor.ADD_URL_TO_CLASSLOADER.accept(
-                                Thread.currentThread().getContextClassLoader(), url));
+        FlinkAbstractPluginExecuteProcessor.ADD_URL_TO_CLASSLOADER.accept(
+                Thread.currentThread().getContextClassLoader(), jarDependencies);
         jarPaths.addAll(jarDependencies);
     }
 
-    private Config registerPlugin(Config config, List<URL> jars) {
+    private Config registerPlugin(Config config, Collection<URL> jars) {
         config =
                 this.injectJarsToConfig(
                         config, ConfigUtil.joinPath("env", "pipeline", "jars"), jars);
@@ -183,7 +197,7 @@ public class FlinkExecution implements TaskExecution {
                 config, ConfigUtil.joinPath("env", "pipeline", "classpaths"), jars);
     }
 
-    private Config injectJarsToConfig(Config config, String path, List<URL> jars) {
+    private Config injectJarsToConfig(Config config, String path, Collection<URL> jars) {
         List<URL> validJars = new ArrayList<>();
         for (URL jarUrl : jars) {
             if (new File(jarUrl.getFile()).exists()) {
