@@ -17,12 +17,13 @@
 
 package org.apache.seatunnel.core.starter.flink.execution;
 
+import org.apache.seatunnel.shade.com.google.common.collect.Lists;
 import org.apache.seatunnel.shade.com.typesafe.config.Config;
 
-import org.apache.seatunnel.api.common.CommonOptions;
 import org.apache.seatunnel.api.common.JobContext;
+import org.apache.seatunnel.api.common.PluginIdentifier;
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
-import org.apache.seatunnel.api.configuration.util.ConfigValidator;
+import org.apache.seatunnel.api.options.EnvCommonOptions;
 import org.apache.seatunnel.api.sink.SaveModeExecuteWrapper;
 import org.apache.seatunnel.api.sink.SaveModeHandler;
 import org.apache.seatunnel.api.sink.SeaTunnelSink;
@@ -30,17 +31,15 @@ import org.apache.seatunnel.api.sink.SupportMultiTableSink;
 import org.apache.seatunnel.api.sink.SupportSaveMode;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.TableIdentifier;
+import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.factory.Factory;
 import org.apache.seatunnel.api.table.factory.FactoryUtil;
 import org.apache.seatunnel.api.table.factory.TableSinkFactory;
-import org.apache.seatunnel.api.table.factory.TableSinkFactoryContext;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
-import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
+import org.apache.seatunnel.common.constants.EngineType;
+import org.apache.seatunnel.common.constants.PluginType;
 import org.apache.seatunnel.common.exception.SeaTunnelRuntimeException;
-import org.apache.seatunnel.core.starter.enums.PluginType;
 import org.apache.seatunnel.core.starter.exception.TaskExecuteException;
-import org.apache.seatunnel.core.starter.execution.PluginUtil;
-import org.apache.seatunnel.plugin.discovery.PluginIdentifier;
 import org.apache.seatunnel.plugin.discovery.seatunnel.SeaTunnelFactoryDiscovery;
 import org.apache.seatunnel.plugin.discovery.seatunnel.SeaTunnelSinkPluginDiscovery;
 import org.apache.seatunnel.translation.flink.sink.FlinkSink;
@@ -55,18 +54,18 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
+import java.util.function.Function;
 import java.util.stream.Collectors;
 
-import static org.apache.seatunnel.api.common.CommonOptions.PLUGIN_NAME;
 import static org.apache.seatunnel.api.common.SeaTunnelAPIErrorCode.HANDLE_SAVE_MODE_FAILED;
+import static org.apache.seatunnel.api.options.ConnectorCommonOptions.PLUGIN_NAME;
+import static org.apache.seatunnel.api.table.factory.FactoryUtil.discoverOptionalFactory;
 
 @Slf4j
 @SuppressWarnings("unchecked,rawtypes")
 public class SinkExecuteProcessor
         extends FlinkAbstractPluginExecuteProcessor<Optional<? extends Factory>> {
 
-    private static final String PLUGIN_TYPE = PluginType.SINK.getType();
-
     protected SinkExecuteProcessor(
             List<URL> jarPaths,
             Config envConfig,
@@ -78,18 +77,39 @@ public class SinkExecuteProcessor
     @Override
     protected List<Optional<? extends Factory>> initializePlugins(
             List<URL> jarPaths, List<? extends Config> pluginConfigs) {
+
         SeaTunnelFactoryDiscovery factoryDiscovery =
                 new SeaTunnelFactoryDiscovery(TableSinkFactory.class, ADD_URL_TO_CLASSLOADER);
         SeaTunnelSinkPluginDiscovery sinkPluginDiscovery =
                 new SeaTunnelSinkPluginDiscovery(ADD_URL_TO_CLASSLOADER);
+        Function<String, TableSinkFactory> discoverOptionalFactoryFunction =
+                pluginName ->
+                        (TableSinkFactory)
+                                factoryDiscovery
+                                        .createOptionalPluginInstance(
+                                                PluginIdentifier.of(
+                                                        EngineType.SEATUNNEL.getEngine(),
+                                                        PluginType.SINK.getType(),
+                                                        pluginName))
+                                        .orElse(null);
+
         return pluginConfigs.stream()
                 .map(
-                        sinkConfig ->
-                                PluginUtil.createSinkFactory(
-                                        factoryDiscovery,
-                                        sinkPluginDiscovery,
-                                        sinkConfig,
-                                        jarPaths))
+                        sinkConfig -> {
+                            jarPaths.addAll(
+                                    sinkPluginDiscovery.getPluginJarPaths(
+                                            Lists.newArrayList(
+                                                    PluginIdentifier.of(
+                                                            EngineType.SEATUNNEL.getEngine(),
+                                                            PluginType.SINK.getType(),
+                                                            sinkConfig.getString(
+                                                                    PLUGIN_NAME.key())))));
+                            return discoverOptionalFactory(
+                                    classLoader,
+                                    TableSinkFactory.class,
+                                    sinkConfig.getString(PLUGIN_NAME.key()),
+                                    discoverOptionalFactoryFunction);
+                        })
                 .distinct()
                 .collect(Collectors.toList());
     }
@@ -100,62 +120,38 @@ public class SinkExecuteProcessor
         SeaTunnelSinkPluginDiscovery sinkPluginDiscovery =
                 new SeaTunnelSinkPluginDiscovery(ADD_URL_TO_CLASSLOADER);
         DataStreamTableInfo input = upstreamDataStreams.get(upstreamDataStreams.size() - 1);
-        ClassLoader classLoader = Thread.currentThread().getContextClassLoader();
+        Function<PluginIdentifier, SeaTunnelSink> fallbackCreateSink =
+                sinkPluginDiscovery::createPluginInstance;
         for (int i = 0; i < plugins.size(); i++) {
+            Optional<? extends Factory> factory = plugins.get(i);
             Config sinkConfig = pluginConfigs.get(i);
             DataStreamTableInfo stream =
                     fromSourceTable(sinkConfig, upstreamDataStreams).orElse(input);
-            Optional<? extends Factory> factory = plugins.get(i);
-            boolean fallBack = !factory.isPresent() || isFallback(factory.get());
-            Map<String, SeaTunnelSink> sinks = new HashMap<>();
-            if (fallBack) {
-                for (CatalogTable catalogTable : stream.getCatalogTables()) {
-                    SeaTunnelSink fallBackSink =
-                            fallbackCreateSink(
-                                    sinkPluginDiscovery,
-                                    PluginIdentifier.of(
-                                            ENGINE_TYPE,
-                                            PLUGIN_TYPE,
-                                            sinkConfig.getString(PLUGIN_NAME.key())),
-                                    sinkConfig);
-                    fallBackSink.setJobContext(jobContext);
-                    SeaTunnelRowType sourceType = catalogTable.getSeaTunnelRowType();
-                    fallBackSink.setTypeInfo(sourceType);
-                    handleSaveMode(fallBackSink);
-                    TableIdentifier tableId = catalogTable.getTableId();
-                    String tableIdName = tableId.toTablePath().toString();
-                    sinks.put(tableIdName, fallBackSink);
-                }
-            } else {
-                for (CatalogTable catalogTable : stream.getCatalogTables()) {
-                    SeaTunnelSink seaTunnelSink;
-                    TableSinkFactoryContext context =
-                            TableSinkFactoryContext.replacePlaceholderAndCreate(
-                                    catalogTable,
-                                    ReadonlyConfig.fromConfig(sinkConfig),
-                                    classLoader,
-                                    ((TableSinkFactory) factory.get())
-                                            .excludeTablePlaceholderReplaceKeys());
-                    ConfigValidator.of(context.getOptions()).validate(factory.get().optionRule());
-                    seaTunnelSink =
-                            ((TableSinkFactory) factory.get()).createSink(context).createSink();
-                    seaTunnelSink.setJobContext(jobContext);
-                    handleSaveMode(seaTunnelSink);
-                    TableIdentifier tableId = catalogTable.getTableId();
-                    String tableIdName = tableId.toTablePath().toString();
-                    sinks.put(tableIdName, seaTunnelSink);
-                }
+            Map<TablePath, SeaTunnelSink> sinks = new HashMap<>();
+            for (CatalogTable catalogTable : stream.getCatalogTables()) {
+                SeaTunnelSink sink =
+                        FactoryUtil.createAndPrepareSink(
+                                catalogTable,
+                                ReadonlyConfig.fromConfig(sinkConfig),
+                                classLoader,
+                                sinkConfig.getString(PLUGIN_NAME.key()),
+                                fallbackCreateSink,
+                                ((TableSinkFactory) (factory.orElse(null))));
+                sink.setJobContext(jobContext);
+                handleSaveMode(sink);
+                TableIdentifier tableId = catalogTable.getTableId();
+                sinks.put(tableId.toTablePath(), sink);
             }
             SeaTunnelSink sink =
                     tryGenerateMultiTableSink(
                             sinks, ReadonlyConfig.fromConfig(sinkConfig), classLoader);
-            boolean sinkParallelism = sinkConfig.hasPath(CommonOptions.PARALLELISM.key());
-            boolean envParallelism = envConfig.hasPath(CommonOptions.PARALLELISM.key());
+            boolean sinkParallelism = sinkConfig.hasPath(EnvCommonOptions.PARALLELISM.key());
+            boolean envParallelism = envConfig.hasPath(EnvCommonOptions.PARALLELISM.key());
             int parallelism =
                     sinkParallelism
-                            ? sinkConfig.getInt(CommonOptions.PARALLELISM.key())
+                            ? sinkConfig.getInt(EnvCommonOptions.PARALLELISM.key())
                             : envParallelism
-                                    ? envConfig.getInt(CommonOptions.PARALLELISM.key())
+                                    ? envConfig.getInt(EnvCommonOptions.PARALLELISM.key())
                                     : 1;
             DataStreamSink<SeaTunnelRow> dataStreamSink =
                     stream.getDataStream()
@@ -174,7 +170,9 @@ public class SinkExecuteProcessor
 
     // if not support multi table, rollback
     public SeaTunnelSink tryGenerateMultiTableSink(
-            Map<String, SeaTunnelSink> sinks, ReadonlyConfig sinkConfig, ClassLoader classLoader) {
+            Map<TablePath, SeaTunnelSink> sinks,
+            ReadonlyConfig sinkConfig,
+            ClassLoader classLoader) {
         if (sinks.values().stream().anyMatch(sink -> !(sink instanceof SupportMultiTableSink))) {
             log.info("Unsupported multi table sink api, rollback to sink template");
             // choose the first sink
@@ -183,28 +181,6 @@ public class SinkExecuteProcessor
         return FactoryUtil.createMultiTableSink(sinks, sinkConfig, classLoader);
     }
 
-    public boolean isFallback(Factory factory) {
-        try {
-            ((TableSinkFactory) factory).createSink(null);
-        } catch (Exception e) {
-            if (e instanceof UnsupportedOperationException
-                    && "The Factory has not been implemented and the deprecated Plugin will be used."
-                            .equals(e.getMessage())) {
-                return true;
-            }
-        }
-        return false;
-    }
-
-    public SeaTunnelSink fallbackCreateSink(
-            SeaTunnelSinkPluginDiscovery sinkPluginDiscovery,
-            PluginIdentifier pluginIdentifier,
-            Config pluginConfig) {
-        SeaTunnelSink source = sinkPluginDiscovery.createPluginInstance(pluginIdentifier);
-        source.prepare(pluginConfig);
-        return source;
-    }
-
     public void handleSaveMode(SeaTunnelSink seaTunnelSink) {
         if (seaTunnelSink instanceof SupportSaveMode) {
             SupportSaveMode saveModeSink = (SupportSaveMode) seaTunnelSink;
