@@ -23,6 +23,7 @@ import org.apache.seatunnel.core.starter.exception.CommandException;
 import org.apache.seatunnel.core.starter.seatunnel.args.ClientCommandArgs;
 import org.apache.seatunnel.e2e.sink.inmemory.InMemoryAggregatedCommitter;
 import org.apache.seatunnel.e2e.sink.inmemory.InMemorySinkWriter;
+import org.apache.seatunnel.e2e.source.inmemory.InMemorySourceSplitEnumerator;
 
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Order;
@@ -45,7 +46,7 @@ public class MultiTableSinkTest {
     @DisabledOnOs(value = {OS.WINDOWS})
     public void testMultiTableSink()
             throws FileNotFoundException, URISyntaxException, CommandException {
-        String configurePath = "/config/fake_to_inmemory_multi_table.conf";
+        String configurePath = "/config/inmemory_to_inmemory_multi_table.conf";
         String configFile = getTestConfigFile(configurePath);
         ClientCommandArgs clientCommandArgs = new ClientCommandArgs();
         clientCommandArgs.setConfigFile(configFile);
@@ -74,6 +75,10 @@ public class MultiTableSinkTest {
         Assertions.assertIterableEquals(
                 Collections.singletonList("InMemoryMultiTableResourceManager::close"),
                 committerResourceManagersEvents);
+
+        Assertions.assertIterableEquals(
+                Arrays.asList("registerReader_0", "run"),
+                InMemorySourceSplitEnumerator.getMethodInvoked());
     }
 
     public static String getTestConfigFile(String configFile)
