@@ -46,6 +46,18 @@ public class FakeSourceToAssertIT extends TestSuiteBase {
         Assertions.assertEquals(0, execResult.getExitCode());
     }
 
+    @TestTemplate
+    @DisabledOnContainer(
+            value = {},
+            type = {EngineType.FLINK},
+            disabledReason = "Currently FLINK unsupported multi table")
+    public void testFakeSourceToMultiAssertSink(TestContainer container)
+            throws IOException, InterruptedException {
+        Container.ExecResult execResult =
+                container.executeJob("/assertion/fakesource_to_multi_table_assert.conf");
+        Assertions.assertEquals(0, execResult.getExitCode());
+    }
+
     @TestTemplate
     @DisabledOnContainer(
             value = {},
