@@ -17,6 +17,7 @@
 
 package org.apache.seatunnel.connectors.seatunnel.cdc.mysql;
 
+import org.apache.seatunnel.connectors.cdc.base.config.JdbcSourceConfig;
 import org.apache.seatunnel.connectors.cdc.base.config.JdbcSourceConfigFactory;
 import org.apache.seatunnel.connectors.seatunnel.cdc.mysql.config.MySqlSourceConfigFactory;
 import org.apache.seatunnel.connectors.seatunnel.cdc.mysql.source.MySqlDialect;
@@ -43,6 +44,11 @@ import org.testcontainers.containers.output.Slf4jLogConsumer;
 import org.testcontainers.lifecycle.Startables;
 import org.testcontainers.utility.DockerLoggerFactory;
 
+import com.github.shyiko.mysql.binlog.BinaryLogClient;
+import com.github.shyiko.mysql.binlog.event.EventData;
+import com.github.shyiko.mysql.binlog.event.EventHeaderV4;
+import com.github.shyiko.mysql.binlog.event.FormatDescriptionEventData;
+import com.github.shyiko.mysql.binlog.event.RotateEventData;
 import io.debezium.jdbc.JdbcConnection;
 import lombok.extern.slf4j.Slf4j;
 
@@ -55,8 +61,10 @@ import java.sql.Statement;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
+import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.TimeUnit;
+import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
 import static org.awaitility.Awaitility.await;
@@ -401,6 +409,168 @@ public class MysqlCDCSpecificStartingOffsetIT extends TestSuiteBase implements T
                         });
     }
 
+    @TestTemplate
+    public void testMysqlCdcTimestampOffset(TestContainer container) throws Exception {
+        log.info("begin testMysqlCdcTimestampOffset");
+        clearTable(MYSQL_DATABASE, SOURCE_TABLE_1);
+        clearTable(MYSQL_DATABASE, SINK_TABLE);
+
+        // write error data
+        executeSql(
+                String.format(
+                        "INSERT INTO %s.%s ( id, f_binary, f_blob, f_long_varbinary, f_longblob, f_tinyblob, f_varbinary, f_smallint,\n"
+                                + "                                         f_smallint_unsigned, f_mediumint, f_mediumint_unsigned, f_int, f_int_unsigned, f_integer,\n"
+                                + "                                         f_integer_unsigned, f_bigint, f_bigint_unsigned, f_numeric, f_decimal, f_float, f_double,\n"
+                                + "                                         f_double_precision, f_longtext, f_mediumtext, f_text, f_tinytext, f_varchar, f_date, f_datetime,\n"
+                                + "                                         f_timestamp, f_bit1, f_bit64, f_char, f_enum, f_mediumblob, f_long_varchar, f_real, f_time,\n"
+                                + "                                         f_tinyint, f_tinyint_unsigned, f_json, f_year )\n"
+                                + "VALUES ( 10, 0x61626374000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000,\n"
+                                + "         0x68656C6C6F, 0x18000000789C0BC9C82C5600A244859CFCBC7485B2C4A2A4CCBCC4A24A00697308D4, NULL,\n"
+                                + "         0x74696E79626C6F62, 0x48656C6C6F20776F726C64, 12345, 54321, 123456, 654321, 1234567, 7654321, 1234567, 7654321,\n"
+                                + "         123456789, 987654321, 123, 789, 12.34, 56.78, 90.12, 'This is a long text field', 'This is a medium text field',\n"
+                                + "         'This is a text field', 'This is a tiny text field', '测试字段4', '2022-04-27', '2022-04-27 14:30:00',\n"
+                                + "         '2023-04-27 11:08:40', 1, b'0101010101010101010101010101010101010101010101010101010101010101', 'C', 'enum2',\n"
+                                + "         0x1B000000789C0BC9C82C5600A24485DCD494CCD25C85A49CFC2485B4CCD49C140083FF099A, 'This is a long varchar field',\n"
+                                + "         12.345, '14:30:00', -128, 255, '{ \"key\": \"value4\" }', 2022 )",
+                        MYSQL_DATABASE, SOURCE_TABLE_1));
+        executeSql(
+                String.format(
+                        "INSERT INTO %s.%s ( id, f_binary, f_blob, f_long_varbinary, f_longblob, f_tinyblob, f_varbinary, f_smallint,\n"
+                                + "                                         f_smallint_unsigned, f_mediumint, f_mediumint_unsigned, f_int, f_int_unsigned, f_integer,\n"
+                                + "                                         f_integer_unsigned, f_bigint, f_bigint_unsigned, f_numeric, f_decimal, f_float, f_double,\n"
+                                + "                                         f_double_precision, f_longtext, f_mediumtext, f_text, f_tinytext, f_varchar, f_date, f_datetime,\n"
+                                + "                                         f_timestamp, f_bit1, f_bit64, f_char, f_enum, f_mediumblob, f_long_varchar, f_real, f_time,\n"
+                                + "                                         f_tinyint, f_tinyint_unsigned, f_json, f_year )\n"
+                                + "VALUES ( 11, 0x61626374000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000,\n"
+                                + "         0x68656C6C6F, 0x18000000789C0BC9C82C5600A244859CFCBC7485B2C4A2A4CCBCC4A24A00697308D4, NULL, 0x74696E79626C6F62,\n"
+                                + "         0x48656C6C6F20776F726C64, 12345, 54321, 123456, 654321, 1234567, 7654321, 1234567, 7654321, 123456789, 987654321,\n"
+                                + "         123, 789, 12.34, 56.78, 90.12, 'This is a long text field', 'This is a medium text field', 'This is a text field',\n"
+                                + "         'This is a tiny text field', '测试字段5', '2022-04-27', '2022-04-27 14:30:00', '2023-04-27 11:08:40',\n"
+                                + "         1, b'0101010101010101010101010101010101010101010101010101010101010101', 'C', 'enum2',\n"
+                                + "         0x1B000000789C0BC9C82C5600A24485DCD494CCD25C85A49CFC2485B4CCD49C140083FF099A, 'This is a long varchar field',\n"
+                                + "         112.345, '14:30:00', -128, 22, '{ \"key\": \"value5\" }', 2013 )",
+                        MYSQL_DATABASE, SOURCE_TABLE_1));
+        //  mysql binlog timestamp is second, wait for 3 seconds to make sure the timestamp is
+        // different
+        Thread.sleep(3000);
+
+        // get latest binlog timestamp
+        String[] variables = {
+            "timestamp=" + (getCurrentBinlogTimestamp() + 2000L),
+        };
+        log.info("offset start with timestamp :{}", variables[0]);
+
+        // Insert data
+        executeSql(
+                String.format(
+                        "INSERT INTO %s.%s ( id, f_binary, f_blob, f_long_varbinary, f_longblob, f_tinyblob, f_varbinary, f_smallint,\n"
+                                + "                                         f_smallint_unsigned, f_mediumint, f_mediumint_unsigned, f_int, f_int_unsigned, f_integer,\n"
+                                + "                                         f_integer_unsigned, f_bigint, f_bigint_unsigned, f_numeric, f_decimal, f_float, f_double,\n"
+                                + "                                         f_double_precision, f_longtext, f_mediumtext, f_text, f_tinytext, f_varchar, f_date, f_datetime,\n"
+                                + "                                         f_timestamp, f_bit1, f_bit64, f_char, f_enum, f_mediumblob, f_long_varchar, f_real, f_time,\n"
+                                + "                                         f_tinyint, f_tinyint_unsigned, f_json, f_year )\n"
+                                + "VALUES ( 14, 0x61626374000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000,\n"
+                                + "         0x68656C6C6F, 0x18000000789C0BC9C82C5600A244859CFCBC7485B2C4A2A4CCBCC4A24A00697308D4, NULL,\n"
+                                + "         0x74696E79626C6F62, 0x48656C6C6F20776F726C64, 12345, 54321, 123456, 654321, 1234567, 7654321, 1234567, 7654321,\n"
+                                + "         123456789, 987654321, 123, 789, 12.34, 56.78, 90.12, 'This is a long text field', 'This is a medium text field',\n"
+                                + "         'This is a text field', 'This is a tiny text field', '测试字段4', '2022-04-27', '2022-04-27 14:30:00',\n"
+                                + "         '2023-04-27 11:08:40', 1, b'0101010101010101010101010101010101010101010101010101010101010101', 'C', 'enum2',\n"
+                                + "         0x1B000000789C0BC9C82C5600A24485DCD494CCD25C85A49CFC2485B4CCD49C140083FF099A, 'This is a long varchar field',\n"
+                                + "         12.345, '14:30:00', -128, 255, '{ \"key\": \"value4\" }', 2022 )",
+                        MYSQL_DATABASE, SOURCE_TABLE_1));
+        executeSql(
+                String.format(
+                        "INSERT INTO %s.%s ( id, f_binary, f_blob, f_long_varbinary, f_longblob, f_tinyblob, f_varbinary, f_smallint,\n"
+                                + "                                         f_smallint_unsigned, f_mediumint, f_mediumint_unsigned, f_int, f_int_unsigned, f_integer,\n"
+                                + "                                         f_integer_unsigned, f_bigint, f_bigint_unsigned, f_numeric, f_decimal, f_float, f_double,\n"
+                                + "                                         f_double_precision, f_longtext, f_mediumtext, f_text, f_tinytext, f_varchar, f_date, f_datetime,\n"
+                                + "                                         f_timestamp, f_bit1, f_bit64, f_char, f_enum, f_mediumblob, f_long_varchar, f_real, f_time,\n"
+                                + "                                         f_tinyint, f_tinyint_unsigned, f_json, f_year )\n"
+                                + "VALUES ( 15, 0x61626374000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000,\n"
+                                + "         0x68656C6C6F, 0x18000000789C0BC9C82C5600A244859CFCBC7485B2C4A2A4CCBCC4A24A00697308D4, NULL, 0x74696E79626C6F62,\n"
+                                + "         0x48656C6C6F20776F726C64, 12345, 54321, 123456, 654321, 1234567, 7654321, 1234567, 7654321, 123456789, 987654321,\n"
+                                + "         123, 789, 12.34, 56.78, 90.12, 'This is a long text field', 'This is a medium text field', 'This is a text field',\n"
+                                + "         'This is a tiny text field', '测试字段5', '2022-04-27', '2022-04-27 14:30:00', '2023-04-27 11:08:40',\n"
+                                + "         1, b'0101010101010101010101010101010101010101010101010101010101010101', 'C', 'enum2',\n"
+                                + "         0x1B000000789C0BC9C82C5600A24485DCD494CCD25C85A49CFC2485B4CCD49C140083FF099A, 'This is a long varchar field',\n"
+                                + "         112.345, '14:30:00', -128, 22, '{ \"key\": \"value5\" }', 2013 )",
+                        MYSQL_DATABASE, SOURCE_TABLE_1));
+
+        String jobId = String.valueOf(JobIdGenerator.newJobId());
+        String jobConfigFile = "/mysqlcdc_timestamp_offset.conf";
+        String source_sql_where_id_template =
+                "select id, cast(f_binary as char) as f_binary, cast(f_blob as char) as f_blob, cast(f_long_varbinary as char) as f_long_varbinary,"
+                        + " cast(f_longblob as char) as f_longblob, cast(f_tinyblob as char) as f_tinyblob, cast(f_varbinary as char) as f_varbinary,"
+                        + " f_smallint, f_smallint_unsigned, f_mediumint, f_mediumint_unsigned, f_int, f_int_unsigned, f_integer, f_integer_unsigned,"
+                        + " f_bigint, f_bigint_unsigned, f_numeric, f_decimal, f_float, f_double, f_double_precision, f_longtext, f_mediumtext,"
+                        + " f_text, f_tinytext, f_varchar, f_date, f_datetime, f_timestamp, f_bit1, cast(f_bit64 as char) as f_bit64, f_char,"
+                        + " f_enum, cast(f_mediumblob as char) as f_mediumblob, f_long_varchar, f_real, f_time, f_tinyint, f_tinyint_unsigned,"
+                        + " f_json, f_year from %s.%s where id in (%s)";
+
+        CompletableFuture.supplyAsync(
+                () -> {
+                    try {
+                        container.executeJob(jobConfigFile, jobId, variables);
+                    } catch (Exception e) {
+                        log.error("Commit task exception :" + e.getMessage());
+                        throw new RuntimeException(e);
+                    }
+                    return null;
+                });
+
+        // validate results
+        await().atMost(90000, TimeUnit.MILLISECONDS)
+                .untilAsserted(
+                        () -> {
+                            Assertions.assertIterableEquals(
+                                    query(
+                                            String.format(
+                                                    source_sql_where_id_template,
+                                                    MYSQL_DATABASE,
+                                                    SOURCE_TABLE_1,
+                                                    "14,15")),
+                                    query(getSinkQuerySQL(MYSQL_DATABASE, SINK_TABLE)));
+                        });
+
+        // Take a savepoint
+        Assertions.assertEquals(0, container.savepointJob(jobId).getExitCode());
+        // Make some changes after the savepoint
+        executeSql(
+                String.format(
+                        "UPDATE %s.%s SET f_year = '2025' WHERE id = 15",
+                        MYSQL_DATABASE, SOURCE_TABLE_1));
+
+        CompletableFuture.supplyAsync(
+                () -> {
+                    try {
+                        container.restoreJob(jobConfigFile, jobId, variables);
+                    } catch (Exception e) {
+                        log.error("Commit task exception :" + e.getMessage());
+                        throw new RuntimeException(e);
+                    }
+                    return null;
+                });
+
+        // Make some changes after the restore
+        executeSql(
+                String.format(
+                        "UPDATE %s.%s SET f_tinyint_unsigned = '77' WHERE id = 15",
+                        MYSQL_DATABASE, SOURCE_TABLE_1));
+
+        await().atMost(60000, TimeUnit.MILLISECONDS)
+                .untilAsserted(
+                        () -> {
+                            Assertions.assertIterableEquals(
+                                    query(
+                                            String.format(
+                                                    source_sql_where_id_template,
+                                                    MYSQL_DATABASE,
+                                                    SOURCE_TABLE_1,
+                                                    "14,15")),
+                                    query(getSinkQuerySQL(MYSQL_DATABASE, SINK_TABLE)));
+                        });
+    }
+
     @Override
     @AfterAll
     public void tearDown() {
@@ -444,4 +614,80 @@ public class MysqlCDCSpecificStartingOffsetIT extends TestSuiteBase implements T
         executeSql(
                 String.format("PURGE BINARY LOGS TO '%s'", getCurrentBinlogOffset().getFilename()));
     }
+
+    private long getCurrentBinlogTimestamp() {
+        BinlogOffset binlogOffset = getCurrentBinlogOffset();
+
+        JdbcSourceConfigFactory configFactory =
+                new MySqlSourceConfigFactory()
+                        .hostname(MYSQL_CONTAINER.getHost())
+                        .port(MYSQL_CONTAINER.getDatabasePort())
+                        .username(MYSQL_CONTAINER.getUsername())
+                        .password(MYSQL_CONTAINER.getPassword())
+                        .databaseList(MYSQL_CONTAINER.getDatabaseName());
+        JdbcSourceConfig jdbcSourceConfig = configFactory.create(0);
+        MySqlDialect mySqlDialect =
+                new MySqlDialect((MySqlSourceConfigFactory) configFactory, Collections.emptyList());
+        BinaryLogClient client =
+                MySqlConnectionUtils.createBinaryClient(jdbcSourceConfig.getDbzConfiguration());
+
+        final String showBinaryLogStmt =
+                "SHOW BINLOG EVENTS IN '" + binlogOffset.getFilename() + "'";
+        List<Long> logPosList = new ArrayList<>();
+        JdbcConnection.ResultSetConsumer rsc =
+                rs -> {
+                    while (rs.next()) {
+                        logPosList.add(rs.getLong(5));
+                    }
+                };
+        try (JdbcConnection jdbc = mySqlDialect.openJdbcConnection(jdbcSourceConfig)) {
+            jdbc.query(showBinaryLogStmt, rsc);
+            if (logPosList.isEmpty()) {
+                return System.currentTimeMillis();
+            }
+            log.info("SHOW BINLOG EVENTS result :{}", logPosList);
+            Long pos =
+                    logPosList.stream()
+                            .distinct()
+                            .sorted(Collections.reverseOrder())
+                            .collect(Collectors.toList())
+                            .get(1);
+
+            ArrayBlockingQueue<Long> binlogTimestamps = new ArrayBlockingQueue<>(1);
+            BinaryLogClient.EventListener eventListener =
+                    event -> {
+                        EventData data = event.getData();
+                        if (data instanceof RotateEventData
+                                || data instanceof FormatDescriptionEventData) {
+                            // We skip RotateEventData because it does not contain the timestamp we
+                            // are
+                            // interested in.
+                            return;
+                        }
+
+                        EventHeaderV4 header = event.getHeader();
+                        long timestamp = header.getTimestamp();
+                        if (timestamp > 0) {
+                            binlogTimestamps.offer(timestamp);
+                            try {
+                                client.disconnect();
+                            } catch (IOException e) {
+                                throw new RuntimeException(e);
+                            }
+                        }
+                    };
+
+            try {
+                client.registerEventListener(eventListener);
+                client.setBinlogFilename(binlogOffset.getFilename());
+                client.setBinlogPosition(pos);
+                client.connect();
+            } finally {
+                client.unregisterEventListener(eventListener);
+            }
+            return binlogTimestamps.take();
+        } catch (Exception e) {
+            throw new RuntimeException(e);
+        }
+    }
 }
