@@ -37,7 +37,9 @@ import org.apache.seatunnel.connectors.seatunnel.elasticsearch.dto.BulkResponse;
 import org.apache.seatunnel.connectors.seatunnel.elasticsearch.dto.source.ScrollResult;
 import org.apache.seatunnel.e2e.common.TestResource;
 import org.apache.seatunnel.e2e.common.TestSuiteBase;
+import org.apache.seatunnel.e2e.common.container.EngineType;
 import org.apache.seatunnel.e2e.common.container.TestContainer;
+import org.apache.seatunnel.e2e.common.junit.DisabledOnContainer;
 import org.apache.seatunnel.e2e.common.util.ContainerUtil;
 
 import org.apache.commons.io.IOUtils;
@@ -74,7 +76,6 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
-import java.util.Optional;
 import java.util.Set;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.TimeUnit;
@@ -116,17 +117,16 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
                                         DockerLoggerFactory.getLogger("elasticsearch:8.9.0")));
         Startables.deepStart(Stream.of(container)).join();
         log.info("Elasticsearch container started");
-        esRestClient =
-                EsRestClient.createInstance(
-                        Lists.newArrayList("https://" + container.getHttpHostAddress()),
-                        Optional.of("elastic"),
-                        Optional.of("elasticsearch"),
-                        false,
-                        false,
-                        Optional.empty(),
-                        Optional.empty(),
-                        Optional.empty(),
-                        Optional.empty());
+        // Create configuration for EsRestClient
+        Map<String, Object> configMap = new HashMap<>();
+        configMap.put("hosts", Lists.newArrayList("https://" + container.getHttpHostAddress()));
+        configMap.put("username", "elastic");
+        configMap.put("password", "elasticsearch");
+        configMap.put("tls_verify_certificate", false);
+        configMap.put("tls_verify_hostname", false);
+
+        ReadonlyConfig config = ReadonlyConfig.fromMap(configMap);
+        esRestClient = EsRestClient.createInstance(config);
         testDataset1 = generateTestDataSet1();
         testDataset2 = generateTestDataSet2();
         createIndexForResourceNull("st_index");
@@ -316,6 +316,49 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
         Assertions.assertIterableEquals(mapTestDatasetForDSL(), sinkData);
     }
 
+    @TestTemplate
+    @DisabledOnContainer(
+            value = {},
+            type = {EngineType.SPARK, EngineType.FLINK},
+            disabledReason = "Currently SPARK and FLINK not support adapt")
+    public void testElasticsearchWithVector(TestContainer container)
+            throws IOException, InterruptedException {
+        String mapping =
+                "{\n"
+                        + "  \"mappings\": {\n"
+                        + "    \"properties\": {\n"
+                        + "      \"review_id\": {\"type\": \"long\"},\n"
+                        + "      \"review_embedding\": {\n"
+                        + "        \"type\": \"dense_vector\",\n"
+                        + "        \"dims\": 1024\n"
+                        + "      },\n"
+                        + "      \"review_text\": {\"type\": \"text\"},\n"
+                        + "      \"review_score\": {\"type\": \"float\"}\n"
+                        + "    }\n"
+                        + "  }\n"
+                        + "}";
+
+        // create index
+        esRestClient.createIndex("vector_test", mapping);
+        Thread.sleep(INDEX_REFRESH_MILL_DELAY);
+
+        Container.ExecResult execResult =
+                container.executeJob("/elasticsearch/fake-to-elasticsearch-vector.conf");
+        Assertions.assertEquals(0, execResult.getExitCode());
+
+        // Wait for index refresh
+        Thread.sleep(INDEX_REFRESH_MILL_DELAY);
+
+        // Verify that 10 documents were inserted as specified in the config
+        Assertions.assertEquals(
+                10, esRestClient.getIndexDocsCount("vector_test").get(0).getDocsCount());
+
+        // Verify vector field exists in the mapping
+        Map<String, BasicTypeDefine<EsType>> fieldTypes =
+                esRestClient.getFieldTypeMapping("vector_test", Collections.emptyList());
+        Assertions.assertTrue(fieldTypes.containsKey("review_embedding"));
+    }
+
     @TestTemplate
     public void testElasticsearchWithPIT(TestContainer container)
             throws IOException, InterruptedException {
