@@ -286,6 +286,11 @@ public class LocalFileIT extends TestSuiteBase {
                         "/seatunnel/read/excel_filter/name=tyrantlucifer/hobby=coding/e2e_filter.xlsx",
                         container);
 
+                ContainerUtil.copyFileIntoContainers(
+                        "/excel/e2e.xlsx",
+                        "/seatunnel/read/excel_filter_regex/name=tyrantlucifer/hobby=coding/e2e_filter.xlsx",
+                        container);
+
                 ContainerUtil.copyFileIntoContainers(
                         "/csv/break_line.csv",
                         "/seatunnel/read/csv/break_line/break_line.csv",
@@ -361,6 +366,8 @@ public class LocalFileIT extends TestSuiteBase {
         helper.execute("/parquet/local_file_parquet_projection_to_assert.conf");
         // test read filtered local file
         helper.execute("/excel/local_filter_excel_to_assert.conf");
+        // test read filtered local file with regex
+        helper.execute("/excel/local_filter_regex_excel_to_assert.conf");
 
         // test read empty directory
         helper.execute("/json/local_file_to_console.conf");
