@@ -17,14 +17,11 @@
 
 package org.apache.seatunnel.e2e.connector.hudi;
 
-import org.apache.seatunnel.common.utils.FileUtils;
 import org.apache.seatunnel.e2e.common.TestSuiteBase;
-import org.apache.seatunnel.e2e.common.container.ContainerExtendedFactory;
 import org.apache.seatunnel.e2e.common.container.EngineType;
 import org.apache.seatunnel.e2e.common.container.TestContainer;
 import org.apache.seatunnel.e2e.common.container.TestContainerId;
 import org.apache.seatunnel.e2e.common.junit.DisabledOnContainer;
-import org.apache.seatunnel.e2e.common.junit.TestContainerExtension;
 
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileUtil;
@@ -37,7 +34,6 @@ import org.apache.parquet.hadoop.example.GroupReadSupport;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.TestTemplate;
 import org.testcontainers.containers.Container;
-import org.testcontainers.containers.GenericContainer;
 
 import lombok.extern.slf4j.Slf4j;
 
@@ -46,6 +42,7 @@ import java.io.IOException;
 import java.util.Arrays;
 import java.util.concurrent.TimeUnit;
 
+import static org.apache.seatunnel.e2e.common.container.AbstractTestContainer.HOST_VOLUME_MOUNT_PATH;
 import static org.awaitility.Awaitility.given;
 
 @Slf4j
@@ -55,49 +52,7 @@ public class HudiMultiTableIT extends TestSuiteBase {
     private static final String TABLE_NAME_1 = "st_test_1";
     private static final String DATABASE_2 = "default";
     private static final String TABLE_NAME_2 = "st_test_2";
-    private static final String TABLE_PATH = "/tmp/hudi/";
-    private static final String NAMESPACE = "hudi";
-    private static final String NAMESPACE_TAR = "hudi.tar.gz";
-
-    protected final ContainerExtendedFactory containerExtendedFactory =
-            new ContainerExtendedFactory() {
-                @Override
-                public void extend(GenericContainer<?> container)
-                        throws IOException, InterruptedException {
-                    container.execInContainer(
-                            "sh",
-                            "-c",
-                            "cd /tmp" + " && tar -czvf " + NAMESPACE_TAR + " " + NAMESPACE);
-                    container.copyFileFromContainer(
-                            "/tmp/" + NAMESPACE_TAR, "/tmp/" + NAMESPACE_TAR);
-
-                    extractFiles();
-                }
-
-                private void extractFiles() {
-                    ProcessBuilder processBuilder = new ProcessBuilder();
-                    processBuilder.command(
-                            "sh", "-c", "cd /tmp" + " && tar -zxvf " + NAMESPACE_TAR);
-                    try {
-                        Process process = processBuilder.start();
-                        int exitCode = process.waitFor();
-                        if (exitCode == 0) {
-                            log.info("Extract files successful.");
-                        } else {
-                            log.error("Extract files failed with exit code " + exitCode);
-                        }
-                    } catch (IOException | InterruptedException e) {
-                        e.printStackTrace();
-                    }
-                }
-            };
-
-    @TestContainerExtension
-    protected final ContainerExtendedFactory extendedFactory =
-            container -> {
-                container.execInContainer("sh", "-c", "mkdir -p " + TABLE_PATH);
-                container.execInContainer("sh", "-c", "chmod -R 777  " + TABLE_PATH);
-            };
+    private static final String TABLE_PATH = HOST_VOLUME_MOUNT_PATH + "/hudi/";
 
     @TestTemplate
     @DisabledOnContainer(
@@ -115,8 +70,6 @@ public class HudiMultiTableIT extends TestSuiteBase {
                 .atMost(60000, TimeUnit.MILLISECONDS)
                 .untilAsserted(
                         () -> {
-                            // copy hudi to local
-                            container.executeExtraCommands(containerExtendedFactory);
                             Path inputPath1 =
                                     getNewestCommitFilePath(
                                             new File(
@@ -155,7 +108,6 @@ public class HudiMultiTableIT extends TestSuiteBase {
                             Assertions.assertEquals(100, rowCount1);
                             Assertions.assertEquals(240, rowCount2);
                         });
-        FileUtils.deleteFile(TABLE_PATH);
     }
 
     public static Path getNewestCommitFilePath(File tablePathDir) throws IOException {
