@@ -18,7 +18,6 @@
 package org.apache.seatunnel.e2e.connector.iceberg;
 
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
-import org.apache.seatunnel.common.utils.FileUtils;
 import org.apache.seatunnel.connectors.seatunnel.iceberg.IcebergTableLoader;
 import org.apache.seatunnel.connectors.seatunnel.iceberg.config.IcebergCommonOptions;
 import org.apache.seatunnel.connectors.seatunnel.iceberg.config.IcebergSourceConfig;
@@ -46,7 +45,6 @@ import org.junit.jupiter.api.TestTemplate;
 import org.junit.jupiter.api.condition.DisabledOnOs;
 import org.junit.jupiter.api.condition.OS;
 import org.testcontainers.containers.Container;
-import org.testcontainers.containers.GenericContainer;
 
 import lombok.extern.slf4j.Slf4j;
 
@@ -68,9 +66,7 @@ import static org.awaitility.Awaitility.given;
 @DisabledOnOs(OS.WINDOWS)
 public class IcebergSinkWithBranchIT extends TestSuiteBase {
 
-    private static final String CATALOG_DIR = "/tmp/seatunnel/iceberg/hadoop-sink/";
-
-    private static final String NAMESPACE = "seatunnel_namespace";
+    private static final String CATALOG_DIR = "/tmp/seatunnel_mnt/iceberg/hadoop-sink/";
 
     private static final String commitBranch = "commit-branch";
 
@@ -81,8 +77,21 @@ public class IcebergSinkWithBranchIT extends TestSuiteBase {
     @TestContainerExtension
     protected final ContainerExtendedFactory extendedFactory =
             container -> {
-                container.execInContainer("sh", "-c", "mkdir -p " + CATALOG_DIR);
+                // TODO: remove this after fix the issue of encountering a failure to create the
+                // metadata and data directories under the /tmp/seatunnel_mnt path in the container
+                // Manually create iceberg metadata and data directory in container
+                container.execInContainer(
+                        "sh",
+                        "-c",
+                        "mkdir -p " + CATALOG_DIR + "seatunnel_namespace/iceberg_sink_table/data");
+                container.execInContainer(
+                        "sh",
+                        "-c",
+                        "mkdir -p "
+                                + CATALOG_DIR
+                                + "seatunnel_namespace/iceberg_sink_table/metadata");
                 container.execInContainer("sh", "-c", "chmod -R 777  " + CATALOG_DIR);
+
                 container.execInContainer(
                         "sh",
                         "-c",
@@ -90,45 +99,6 @@ public class IcebergSinkWithBranchIT extends TestSuiteBase {
                                 + zstdUrl());
             };
 
-    private final String NAMESPACE_TAR = NAMESPACE + ".tar.gz";
-    protected final ContainerExtendedFactory containerExtendedFactory =
-            new ContainerExtendedFactory() {
-                @Override
-                public void extend(GenericContainer<?> container)
-                        throws IOException, InterruptedException {
-                    FileUtils.createNewDir(CATALOG_DIR);
-                    container.execInContainer(
-                            "sh",
-                            "-c",
-                            "cd "
-                                    + CATALOG_DIR
-                                    + " && tar -czvf "
-                                    + NAMESPACE_TAR
-                                    + " "
-                                    + NAMESPACE);
-                    container.copyFileFromContainer(
-                            CATALOG_DIR + NAMESPACE_TAR, CATALOG_DIR + NAMESPACE_TAR);
-                    extractFiles();
-                }
-
-                private void extractFiles() {
-                    ProcessBuilder processBuilder = new ProcessBuilder();
-                    processBuilder.command(
-                            "sh", "-c", "cd " + CATALOG_DIR + " && tar -zxvf " + NAMESPACE_TAR);
-                    try {
-                        Process process = processBuilder.start();
-                        int exitCode = process.waitFor();
-                        if (exitCode == 0) {
-                            log.info("Extract files successful.");
-                        } else {
-                            log.error("Extract files failed with exit code " + exitCode);
-                        }
-                    } catch (IOException | InterruptedException e) {
-                        log.error("Extract data files from container error :", e);
-                    }
-                }
-            };
-
     @TestTemplate
     public void testInsertAndCheckDataE2e(TestContainer container)
             throws IOException, InterruptedException {
@@ -141,8 +111,6 @@ public class IcebergSinkWithBranchIT extends TestSuiteBase {
                 .atMost(60000, TimeUnit.MILLISECONDS)
                 .untilAsserted(
                         () -> {
-                            // copy iceberg to local
-                            container.executeExtraCommands(containerExtendedFactory);
                             // check branch exists
                             Assertions.assertEquals(true, checkBranchExists());
                             // load from branch
