@@ -48,6 +48,8 @@ public class JdbcCase {
     private String jdbcUrl;
     private String createSql;
     private String sinkCreateSql;
+    private String additionalSqlOnSource;
+    private String additionalSqlOnSink;
     private String insertSql;
     private List<String> configFile;
     private Pair<String[], List<SeaTunnelRow>> testData;
