@@ -49,7 +49,7 @@ CREATE TABLE sink_table WITH (
 
 
 CREATE TABLE temp1 AS
-    SELECT `c-bit_1`, c_bit_8, c_bit_16, c_bit_32, c_bit_64, c_boolean, c_tinyint, c_tinyint_unsigned, c_smallint, c_smallint_unsigned,
+    SELECT `c-bit_1`, c_bit_8, c_bit_16, c_bit_32, c_bit_64, c_tinyint_1, c_tinyint, c_tinyint_unsigned, c_smallint, c_smallint_unsigned,
            c_mediumint, c_mediumint_unsigned, c_int, c_integer, c_bigint, c_bigint_unsigned,
            c_decimal, c_decimal_unsigned, c_float, c_float_unsigned, c_double, c_double_unsigned,
            c_char, c_tinytext, c_mediumtext, c_text, c_varchar, c_json, c_longtext, c_date,
