@@ -24,6 +24,7 @@ import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 
 import org.apache.commons.lang3.tuple.Pair;
 
+import org.junit.jupiter.api.Disabled;
 import org.testcontainers.containers.GenericContainer;
 import org.testcontainers.containers.output.Slf4jLogConsumer;
 import org.testcontainers.utility.DockerLoggerFactory;
@@ -33,6 +34,8 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+@Disabled(
+        "Disabled until Vertica image is available, please follow https://github.com/vertica/vertica-containers/issues/64")
 public class JdbcVerticaIT extends AbstractJdbcIT {
 
     private static final String VERTICA_IMAGE = "vertica/vertica-ce:latest";
