@@ -36,7 +36,7 @@ public class PaimonRecordWithFullType {
     public int[] c_array;
     public BinaryString c_string;
     public boolean c_boolean;
-    public short c_tinyint;
+    public byte c_tinyint;
     public short c_smallint;
     public int c_int;
     public long c_bigint;
