@@ -18,24 +18,26 @@
 package org.apache.seatunnel.e2e.connector.paimon;
 
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
-import org.apache.seatunnel.common.utils.FileUtils;
 import org.apache.seatunnel.common.utils.SeaTunnelException;
+import org.apache.seatunnel.connectors.seatunnel.cdc.mysql.testutils.MySqlContainer;
+import org.apache.seatunnel.connectors.seatunnel.cdc.mysql.testutils.MySqlVersion;
+import org.apache.seatunnel.connectors.seatunnel.cdc.mysql.testutils.UniqueDatabase;
 import org.apache.seatunnel.connectors.seatunnel.paimon.catalog.PaimonCatalogLoader;
 import org.apache.seatunnel.connectors.seatunnel.paimon.config.PaimonSinkConfig;
-import org.apache.seatunnel.core.starter.utils.CompressionUtils;
 import org.apache.seatunnel.e2e.common.TestResource;
 import org.apache.seatunnel.e2e.common.TestSuiteBase;
 import org.apache.seatunnel.e2e.common.container.ContainerExtendedFactory;
 import org.apache.seatunnel.e2e.common.container.EngineType;
 import org.apache.seatunnel.e2e.common.container.TestContainer;
 import org.apache.seatunnel.e2e.common.junit.DisabledOnContainer;
+import org.apache.seatunnel.e2e.common.junit.TestContainerExtension;
 
-import org.apache.commons.compress.archivers.ArchiveException;
 import org.apache.paimon.catalog.Catalog;
 import org.apache.paimon.catalog.CatalogContext;
 import org.apache.paimon.catalog.CatalogFactory;
 import org.apache.paimon.catalog.Identifier;
 import org.apache.paimon.crosspartition.IndexBootstrap;
+import org.apache.paimon.data.GenericRow;
 import org.apache.paimon.data.InternalArray;
 import org.apache.paimon.data.InternalMap;
 import org.apache.paimon.data.InternalRow;
@@ -45,9 +47,12 @@ import org.apache.paimon.table.FileStoreTable;
 import org.apache.paimon.table.Table;
 import org.apache.paimon.table.sink.RowPartitionKeyExtractor;
 import org.apache.paimon.table.source.ReadBuilder;
+import org.apache.paimon.table.source.Split;
 import org.apache.paimon.table.source.TableRead;
 import org.apache.paimon.table.source.TableScan;
 import org.apache.paimon.types.DataField;
+import org.apache.paimon.types.DataType;
+import org.apache.paimon.types.RowType;
 import org.apache.paimon.types.TimestampType;
 
 import org.junit.jupiter.api.AfterAll;
@@ -56,20 +61,30 @@ import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Disabled;
 import org.junit.jupiter.api.TestTemplate;
 import org.testcontainers.containers.Container;
+import org.testcontainers.containers.output.Slf4jLogConsumer;
+import org.testcontainers.lifecycle.Startables;
+import org.testcontainers.utility.DockerLoggerFactory;
 
 import lombok.extern.slf4j.Slf4j;
 
-import java.io.File;
 import java.io.IOException;
+import java.sql.Connection;
+import java.sql.SQLException;
+import java.sql.Statement;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.TimeUnit;
+import java.util.function.Function;
 import java.util.stream.Collectors;
+import java.util.stream.IntStream;
+import java.util.stream.Stream;
 
+import static org.apache.seatunnel.e2e.common.container.AbstractTestContainer.HOST_VOLUME_MOUNT_PATH;
 import static org.awaitility.Awaitility.given;
 
 @DisabledOnContainer(
@@ -80,23 +95,58 @@ import static org.awaitility.Awaitility.given;
 @Slf4j
 public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestResource {
 
-    private static String CATALOG_ROOT_DIR = "/tmp/";
-    private static final String NAMESPACE = "paimon";
-    private static final String NAMESPACE_TAR = "paimon.tar.gz";
-    private static final String CATALOG_DIR = CATALOG_ROOT_DIR + NAMESPACE + "/";
-    private String CATALOG_ROOT_DIR_WIN = "C:/Users/";
-    private String CATALOG_DIR_WIN = CATALOG_ROOT_DIR_WIN + NAMESPACE + "/";
     private boolean isWindows;
+    private static final String NAMESPACE = "paimon";
 
     private Map<String, Object> PAIMON_SINK_PROPERTIES;
 
+    private static final String MYSQL_DATABASE = "bucket";
+    private static final String SOURCE_TABLE = "test_dynamic_bucket";
+
+    private static final String MYSQL_HOST = "mysql_e2e";
+    private static final String MYSQL_USER_NAME = "mysqluser";
+    private static final String MYSQL_USER_PASSWORD = "mysqlpw";
+
+    private static final MySqlContainer MYSQL_CONTAINER = createMySqlContainer(MySqlVersion.V8_0);
+
+    private final UniqueDatabase bucketDatabase =
+            new UniqueDatabase(
+                    MYSQL_CONTAINER, MYSQL_DATABASE, "mysqluser", "mysqlpw", MYSQL_DATABASE);
+
+    private static MySqlContainer createMySqlContainer(MySqlVersion version) {
+        return new MySqlContainer(version)
+                .withConfigurationOverride("docker/server-gtids/my.cnf")
+                .withSetupSQL("docker/setup.sql")
+                .withNetwork(NETWORK)
+                .withNetworkAliases(MYSQL_HOST)
+                .withDatabaseName(MYSQL_DATABASE)
+                .withUsername(MYSQL_USER_NAME)
+                .withPassword(MYSQL_USER_PASSWORD)
+                .withLogConsumer(
+                        new Slf4jLogConsumer(DockerLoggerFactory.getLogger("mysql-docker-image")));
+    }
+
+    private String driverUrl() {
+        return "https://repo1.maven.org/maven2/com/mysql/mysql-connector-j/8.0.32/mysql-connector-j-8.0.32.jar";
+    }
+
+    @TestContainerExtension
+    protected final ContainerExtendedFactory extendedFactory =
+            container -> {
+                Container.ExecResult extraCommands =
+                        container.execInContainer(
+                                "bash",
+                                "-c",
+                                "mkdir -p /tmp/seatunnel/plugins/MySQL-CDC/lib && cd /tmp/seatunnel/plugins/MySQL-CDC/lib && wget "
+                                        + driverUrl());
+                Assertions.assertEquals(0, extraCommands.getExitCode(), extraCommands.getStderr());
+            };
+
     @BeforeAll
     @Override
     public void startUp() throws Exception {
         this.isWindows =
                 System.getProperties().getProperty("os.name").toUpperCase().contains("WINDOWS");
-        CATALOG_ROOT_DIR_WIN = CATALOG_ROOT_DIR_WIN + System.getProperty("user.name") + "/tmp/";
-        CATALOG_DIR_WIN = CATALOG_ROOT_DIR_WIN + NAMESPACE + "/";
         Map<String, Object> map = new HashMap<>();
         map.put("warehouse", "hdfs:///tmp/paimon");
         map.put("database", "default");
@@ -113,11 +163,20 @@ public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestReso
         paimonHadoopConf.put("dfs.client.use.datanode.hostname", "true");
         map.put("paimon.hadoop.conf", paimonHadoopConf);
         this.PAIMON_SINK_PROPERTIES = map;
+        log.info("The second stage: Starting Mysql containers...");
+        Startables.deepStart(Stream.of(MYSQL_CONTAINER)).join();
+        log.info("Mysql Containers are started");
+        bucketDatabase.createAndInitialize();
+        log.info("Mysql ddl execution is complete");
     }
 
     @AfterAll
     @Override
-    public void tearDown() throws Exception {}
+    public void tearDown() throws Exception {
+        if (MYSQL_CONTAINER != null) {
+            MYSQL_CONTAINER.close();
+        }
+    }
 
     @TestTemplate
     public void testWriteAndReadPaimon(TestContainer container)
@@ -132,6 +191,93 @@ public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestReso
         Assertions.assertEquals(0, readProjectionResult.getExitCode());
     }
 
+    @TestTemplate
+    public void testWriteForDifferentParallelism(TestContainer container)
+            throws IOException, InterruptedException, SQLException {
+        // parallelism = 3
+        Container.ExecResult textWriteResult1 =
+                container.executeJob("/mysql_jdbc_to_dynamic_bucket_paimon_case1.conf");
+        Assertions.assertEquals(0, textWriteResult1.getExitCode());
+        try (Connection jdbcConnection = bucketDatabase.getJdbcConnection();
+                Statement statement = jdbcConnection.createStatement()) {
+            statement.executeUpdate(
+                    "update bucket.test_dynamic_bucket set version = '2' where id <= 102");
+            statement.executeUpdate(
+                    "update bucket.test_dynamic_bucket set version = '3' where id = 105");
+            statement.executeUpdate(
+                    "update bucket.test_dynamic_bucket set version = '4' where id = 109");
+        }
+        // parallelism = 1
+        Container.ExecResult textWriteResult2 =
+                container.executeJob("/mysql_jdbc_to_dynamic_bucket_paimon_case2.conf");
+        Assertions.assertEquals(0, textWriteResult2.getExitCode());
+        List<String> parallelism_1 = verifyData(container);
+
+        // parallelism = 2
+        Container.ExecResult textWriteResult3 =
+                container.executeJob("/mysql_jdbc_to_dynamic_bucket_paimon_case3.conf");
+        Assertions.assertEquals(0, textWriteResult3.getExitCode());
+
+        List<String> parallelism_2 = verifyData(container);
+        Assertions.assertEquals(parallelism_1, parallelism_2);
+    }
+
+    private List<String> verifyData(TestContainer container) {
+        List<InternalRow> actual = new ArrayList<>();
+        given().ignoreExceptions()
+                .await()
+                .atLeast(100L, TimeUnit.MILLISECONDS)
+                .atMost(30L, TimeUnit.SECONDS)
+                .untilAsserted(
+                        () -> {
+                            FileStoreTable table =
+                                    (FileStoreTable) getTable("mysql_to_paimon", SOURCE_TABLE);
+                            RowType rowType = table.rowType();
+                            String[] fields = new String[] {"id", "version"};
+                            int[] projection = getProjection(fields, rowType);
+                            DataType[] projectionDataTypes =
+                                    getProjectionFieldTypes(fields, rowType);
+                            ReadBuilder readBuilder =
+                                    table.newReadBuilder().withProjection(projection);
+                            List<Split> splits = readBuilder.newScan().plan().splits();
+
+                            try (RecordReader<InternalRow> reader =
+                                    readBuilder.newRead().executeFilter().createReader(splits)) {
+
+                                reader.forEachRemaining(
+                                        row -> {
+                                            GenericRow binaryRow =
+                                                    new GenericRow(projectionDataTypes.length);
+                                            for (int i = 0; i < projectionDataTypes.length; i++) {
+                                                DataType type = projectionDataTypes[i];
+                                                binaryRow.setField(
+                                                        i,
+                                                        InternalRow.createFieldGetter(type, i)
+                                                                .getFieldOrNull(row));
+                                            }
+                                            actual.add(binaryRow);
+                                        });
+                            }
+                            Assertions.assertEquals(10, actual.size());
+                        });
+        return actual.stream().map(Object::toString).collect(Collectors.toList());
+    }
+
+    private static DataType[] getProjectionFieldTypes(String[] projection, RowType rowType) {
+        List<String> fieldNames = rowType.getFieldNames();
+        Map<String, Integer> collect =
+                IntStream.range(0, fieldNames.size())
+                        .boxed()
+                        .collect(Collectors.toMap(fieldNames::get, Function.identity()));
+        return Arrays.stream(projection)
+                .map(field -> rowType.getTypeAt(collect.get(field)))
+                .toArray(DataType[]::new);
+    }
+
+    private int[] getProjection(String[] projection, RowType rowType) {
+        return Arrays.stream(projection).mapToInt(rowType::getFieldIndex).toArray();
+    }
+
     @TestTemplate
     public void testBucketCount(TestContainer container) throws IOException, InterruptedException {
         Container.ExecResult textWriteResult =
@@ -143,8 +289,6 @@ public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestReso
                 .atMost(30L, TimeUnit.SECONDS)
                 .untilAsserted(
                         () -> {
-                            // copy paimon to local
-                            container.executeExtraCommands(containerExtendedFactory);
                             FileStoreTable table =
                                     (FileStoreTable) getTable("default", "st_test_2");
                             IndexBootstrap indexBootstrap = new IndexBootstrap(table);
@@ -168,13 +312,15 @@ public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestReso
     @Disabled(
             "Spark and Flink engine can not auto create paimon table on worker node in local file, this e2e case work on hdfs environment, please set up your own HDFS environment in the test case file and the below setup")
     public void testPaimonBucketCountOnSparkAndFlink(TestContainer container)
-            throws IOException, InterruptedException, Catalog.TableNotExistException {
+            throws IOException, InterruptedException, Catalog.TableNotExistException,
+                    Catalog.DatabaseNotExistException {
         PaimonSinkConfig paimonSinkConfig =
                 new PaimonSinkConfig(ReadonlyConfig.fromMap(PAIMON_SINK_PROPERTIES));
         PaimonCatalogLoader paimonCatalogLoader = new PaimonCatalogLoader(paimonSinkConfig);
         Catalog catalog = paimonCatalogLoader.loadCatalog();
         Identifier identifier = Identifier.create("default", "st_test_5");
-        if (catalog.tableExists(identifier)) {
+        List<String> tables = catalog.listTables(identifier.getDatabaseName());
+        if (tables.contains(identifier.getTableName())) {
             catalog.dropTable(identifier, true);
         }
         Container.ExecResult textWriteResult =
@@ -213,8 +359,6 @@ public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestReso
                 .atMost(30L, TimeUnit.SECONDS)
                 .untilAsserted(
                         () -> {
-                            // copy paimon to local
-                            container.executeExtraCommands(containerExtendedFactory);
                             FileStoreTable table =
                                     (FileStoreTable) getTable("default", "st_test_3");
                             IndexBootstrap indexBootstrap = new IndexBootstrap(table);
@@ -242,16 +386,17 @@ public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestReso
     public void testCDCParallelismBucketCount(TestContainer container)
             throws IOException, InterruptedException {
         Container.ExecResult textWriteResult =
-                container.executeJob("/fake_to_dynamic_bucket_paimon_case4.conf");
+                container.executeJob("/fake_to_dynamic_bucket_paimon_case8.conf");
         Assertions.assertEquals(0, textWriteResult.getExitCode());
+        Container.ExecResult textWriteResult1 =
+                container.executeJob("/fake_to_dynamic_bucket_paimon_case4.conf");
+        Assertions.assertEquals(0, textWriteResult1.getExitCode());
         given().ignoreExceptions()
                 .await()
                 .atLeast(100L, TimeUnit.MILLISECONDS)
                 .atMost(120L, TimeUnit.SECONDS)
                 .untilAsserted(
                         () -> {
-                            // copy paimon to local
-                            container.executeExtraCommands(containerExtendedFactory);
                             FileStoreTable table =
                                     (FileStoreTable) getTable("default", "st_test_4");
                             IndexBootstrap indexBootstrap = new IndexBootstrap(table);
@@ -275,7 +420,7 @@ public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestReso
                                                             Map.Entry::getValue,
                                                             HashMap::new,
                                                             Collectors.counting()));
-                            Assertions.assertEquals(4, bucketCountMap.size());
+                            Assertions.assertEquals(2, bucketCountMap.size());
                             Assertions.assertEquals(5, bucketCountMap.get(0));
                         });
     }
@@ -291,10 +436,8 @@ public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestReso
                 .atMost(30L, TimeUnit.SECONDS)
                 .untilAsserted(
                         () -> {
-                            // copy paimon to local
-                            container.executeExtraCommands(containerExtendedFactory);
                             FileStoreTable table =
-                                    (FileStoreTable) getTable("default", "st_test_3");
+                                    (FileStoreTable) getTable("default", "st_test_cdc_write");
                             List<DataField> fields = table.schema().fields();
                             for (DataField field : fields) {
                                 if (field.name().equalsIgnoreCase("one_time")) {
@@ -333,15 +476,15 @@ public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestReso
                             Assertions.assertEquals(2, result.size());
                             for (PaimonRecord paimonRecord : result) {
                                 Assertions.assertEquals(
-                                        paimonRecord.oneTime.toString(), "2024-03-10T10:00:12");
+                                        "2024-03-10T10:00:12", paimonRecord.oneTime.toString());
                                 Assertions.assertEquals(
-                                        paimonRecord.twoTime.toString(), "2024-03-10T10:00:00.123");
+                                        "2024-03-10T10:00:00.123", paimonRecord.twoTime.toString());
                                 Assertions.assertEquals(
-                                        paimonRecord.threeTime.toString(),
-                                        "2024-03-10T10:00:00.123456");
+                                        "2024-03-10T10:00:00.123456",
+                                        paimonRecord.threeTime.toString());
                                 Assertions.assertEquals(
-                                        paimonRecord.fourTime.toString(),
-                                        "2024-03-10T10:00:00.123456789");
+                                        "2024-03-10T10:00:00.123456789",
+                                        paimonRecord.fourTime.toString());
                             }
                         });
     }
@@ -359,7 +502,6 @@ public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestReso
                 .atMost(60L, TimeUnit.SECONDS)
                 .untilAsserted(
                         () -> {
-                            container.executeExtraCommands(containerExtendedFactory);
                             FileStoreTable table =
                                     (FileStoreTable) getTable("full_type", "st_test");
                             List<String> primaryKeys = table.schema().primaryKeys();
@@ -374,72 +516,12 @@ public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestReso
         Assertions.assertEquals(0, writeResult1.getExitCode());
     }
 
-    protected final ContainerExtendedFactory containerExtendedFactory =
-            container -> {
-                if (isWindows) {
-                    FileUtils.deleteFile(CATALOG_ROOT_DIR_WIN + NAMESPACE_TAR);
-                    FileUtils.deleteFile(CATALOG_ROOT_DIR_WIN + "paimon.tar");
-                    FileUtils.createNewDir(CATALOG_ROOT_DIR_WIN);
-                } else {
-                    FileUtils.deleteFile(CATALOG_ROOT_DIR + NAMESPACE_TAR);
-                    FileUtils.createNewDir(CATALOG_DIR);
-                }
-
-                container.execInContainer(
-                        "sh",
-                        "-c",
-                        "cd "
-                                + CATALOG_ROOT_DIR
-                                + " && tar -czvf "
-                                + NAMESPACE_TAR
-                                + " "
-                                + NAMESPACE);
-                container.copyFileFromContainer(
-                        CATALOG_ROOT_DIR + NAMESPACE_TAR,
-                        (isWindows ? CATALOG_ROOT_DIR_WIN : CATALOG_ROOT_DIR) + NAMESPACE_TAR);
-                if (isWindows) {
-                    extractFilesWin();
-                } else {
-                    extractFiles();
-                }
-            };
-
-    private void extractFiles() {
-        ProcessBuilder processBuilder = new ProcessBuilder();
-        processBuilder.command(
-                "sh", "-c", "cd " + CATALOG_ROOT_DIR + " && tar -zxvf " + NAMESPACE_TAR);
-        try {
-            Process process = processBuilder.start();
-            // wait command completed
-            int exitCode = process.waitFor();
-            if (exitCode == 0) {
-                log.info("Extract files successful.");
-            } else {
-                log.error("Extract files failed with exit code " + exitCode);
-            }
-        } catch (IOException | InterruptedException e) {
-            e.printStackTrace();
-        }
-    }
-
-    private void extractFilesWin() {
-        try {
-            CompressionUtils.unGzip(
-                    new File(CATALOG_ROOT_DIR_WIN + NAMESPACE_TAR), new File(CATALOG_ROOT_DIR_WIN));
-            CompressionUtils.unTar(
-                    new File(CATALOG_ROOT_DIR_WIN + "paimon.tar"), new File(CATALOG_ROOT_DIR_WIN));
-        } catch (IOException | ArchiveException e) {
-            throw new RuntimeException(e);
-        }
-    }
-
     protected Table getTable(String dbName, String tbName) {
         Options options = new Options();
-        if (isWindows) {
-            options.set("warehouse", CATALOG_DIR_WIN);
-        } else {
-            options.set("warehouse", "file://" + CATALOG_DIR);
-        }
+        String warehouse =
+                String.format(
+                        "%s%s/%s", isWindows ? "" : "file://", HOST_VOLUME_MOUNT_PATH, NAMESPACE);
+        options.set("warehouse", warehouse);
         try {
             Catalog catalog = CatalogFactory.createCatalog(CatalogContext.create(options));
             return catalog.getTable(Identifier.create(dbName, tbName));
@@ -472,7 +554,7 @@ public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestReso
                                         intArray,
                                         row.getString(2),
                                         row.getBoolean(3),
-                                        row.getShort(4),
+                                        row.getByte(4),
                                         row.getShort(5),
                                         row.getInt(6),
                                         row.getLong(7),
