@@ -33,6 +33,7 @@ import org.apache.seatunnel.e2e.common.container.EngineType;
 import org.apache.seatunnel.e2e.common.container.TestContainer;
 import org.apache.seatunnel.e2e.common.junit.DisabledOnContainer;
 import org.apache.seatunnel.e2e.common.junit.TestContainerExtension;
+import org.apache.seatunnel.e2e.common.util.JobIdGenerator;
 
 import org.apache.paimon.data.BinaryString;
 import org.apache.paimon.data.Decimal;
@@ -70,6 +71,7 @@ import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Comparator;
 import java.util.List;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.TimeUnit;
@@ -152,26 +154,24 @@ public class PaimonSinkWithSchemaEvolutionIT extends AbstractPaimonIT implements
     }
 
     @TestTemplate
-    public void testMysqlCdcSinkPaimonWithSchemaChange(TestContainer container) throws Exception {
+    public void testMysqlCdcSinkPaimonWithSchemaChangeAndRestore(TestContainer container)
+            throws Exception {
+        String jobId = String.valueOf(JobIdGenerator.newJobId());
         String jobConfigFile = "/mysql_cdc_to_paimon_with_schema_change.conf";
         CompletableFuture.runAsync(
                 () -> {
                     try {
-                        container.executeJob(jobConfigFile);
+                        container.executeJob(jobConfigFile, jobId);
                     } catch (Exception e) {
                         log.error("Commit task exception :" + e.getMessage());
                         throw new RuntimeException(e);
                     }
                 });
-
-        // Waiting for auto create sink table
-        Thread.sleep(15000);
+        verifyJobStatus(container, jobId);
 
         await().atMost(30, TimeUnit.SECONDS)
                 .untilAsserted(
                         () -> {
-                            // copy paimon to local
-                            container.executeExtraCommands(containerExtendedFactory);
                             Assertions.assertIterableEquals(
                                     queryMysql(String.format(QUERY, MYSQL_DATABASE, SOURCE_TABLE)),
                                     queryPaimon(null, 0, Integer.MAX_VALUE));
@@ -183,25 +183,50 @@ public class PaimonSinkWithSchemaEvolutionIT extends AbstractPaimonIT implements
         // with default value at same time, the history data in paimon has no value.
         List<ImmutableTriple<String[], Integer, Integer>> idRangesWithFiledProjection1 =
                 getIdRangesWithFiledProjectionImmutableTriplesCase1();
-        vertifySchemaAndData(container, idRangesWithFiledProjection1);
+        verifySchemaAndData(container, idRangesWithFiledProjection1);
+
+        // savepoint job
+        Container.ExecResult execResult = container.savepointJob(jobId);
+        Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
+        // restore job
+        CompletableFuture.runAsync(
+                () -> {
+                    try {
+                        container.restoreJob(jobConfigFile, jobId);
+                    } catch (Exception e) {
+                        log.error("Commit task exception :" + e.getMessage());
+                        throw new RuntimeException(e);
+                    }
+                });
+        verifyJobStatus(container, jobId);
 
         // Case 2: Drop columns with data at same time
         shopDatabase.setTemplateName("drop_columns").createAndInitialize();
         List<ImmutableTriple<String[], Integer, Integer>> idRangesWithFiledProjection2 =
                 getIdRangesWithFiledProjectionImmutableTriplesCase2();
-        vertifySchemaAndData(container, idRangesWithFiledProjection2);
+        verifySchemaAndData(container, idRangesWithFiledProjection2);
 
         // Case 3: Change columns with data at same time
         shopDatabase.setTemplateName("change_columns").createAndInitialize();
         List<ImmutableTriple<String[], Integer, Integer>> idRangesWithFiledProjection3 =
                 getIdRangesWithFiledProjectionImmutableTriplesCase3();
-        vertifySchemaAndData(container, idRangesWithFiledProjection3);
+        verifySchemaAndData(container, idRangesWithFiledProjection3);
 
         // Case 4: Modify columns with data at same time
         shopDatabase.setTemplateName("modify_columns").createAndInitialize();
         List<ImmutableTriple<String[], Integer, Integer>> idRangesWithFiledProjection4 =
                 getIdRangesWithFiledProjectionImmutableTriplesCase4();
-        vertifySchemaAndData(container, idRangesWithFiledProjection4);
+        verifySchemaAndData(container, idRangesWithFiledProjection4);
+    }
+
+    private void verifyJobStatus(TestContainer container, String jobId) {
+        await().pollDelay(30, TimeUnit.SECONDS)
+                .atMost(45, TimeUnit.SECONDS)
+                .untilAsserted(
+                        () -> {
+                            String jobStatus = container.getJobStatus(jobId);
+                            Assertions.assertEquals("RUNNING", jobStatus);
+                        });
     }
 
     private List<ImmutableTriple<String[], Integer, Integer>>
@@ -329,16 +354,15 @@ public class PaimonSinkWithSchemaEvolutionIT extends AbstractPaimonIT implements
         };
     }
 
-    private void vertifySchemaAndData(
+    private void verifySchemaAndData(
             TestContainer container,
             List<ImmutableTriple<String[], Integer, Integer>> idRangesWithFiledProjection) {
-        await().atMost(30, TimeUnit.SECONDS)
+        await().pollDelay(5, TimeUnit.SECONDS)
+                .atMost(40, TimeUnit.SECONDS)
                 .untilAsserted(
                         () -> {
-                            // copy paimon to local
-                            container.executeExtraCommands(containerExtendedFactory);
                             // 1. Vertify the schema
-                            vertifySchema();
+                            verifySchema();
 
                             // 2. Vertify the data
                             idRangesWithFiledProjection.forEach(
@@ -364,7 +388,7 @@ public class PaimonSinkWithSchemaEvolutionIT extends AbstractPaimonIT implements
                         });
     }
 
-    private void vertifySchema() {
+    private void verifySchema() {
         try (MySqlCatalog mySqlCatalog =
                 new MySqlCatalog(
                         "mysql",
@@ -447,7 +471,9 @@ public class PaimonSinkWithSchemaEvolutionIT extends AbstractPaimonIT implements
                         results.add(rowRecords);
                     });
         }
-        return results;
+        return results.stream()
+                .sorted(Comparator.comparing(o -> Integer.valueOf(o.get(0).toString())))
+                .collect(Collectors.toList());
     }
 
     private Predicate getPredicateWithBound(int lowerBound, int upperBound, FileStoreTable table) {
