@@ -134,6 +134,12 @@ public class TDengineIT extends TestSuiteBase implements TestResource {
                     "CREATE STABLE power2.meters4 (ts TIMESTAMP, current FLOAT, voltage INT, phase FLOAT, off BOOL, nc NCHAR(10)) "
                             + "TAGS (location BINARY(64), groupId INT)");
         }
+        try (Statement stmt = connection2.createStatement()) {
+            stmt.execute("CREATE DATABASE power3 KEEP 3650");
+            stmt.execute(
+                    "CREATE STABLE power3.meters5 (ts TIMESTAMP, current FLOAT, voltage INT, phase FLOAT, off BOOL, nc NCHAR(10)) "
+                            + "TAGS (location BINARY(64), groupId INT)");
+        }
         return rowCount;
     }
 
@@ -143,7 +149,7 @@ public class TDengineIT extends TestSuiteBase implements TestResource {
                 container.executeJob("/tdengine/tdengine_source_to_sink.conf");
         Assertions.assertEquals(0, execResult.getExitCode());
 
-        long rowCountInserted = readSinkDataset("meters2");
+        long rowCountInserted = readSinkDataset("power2", "meters2");
         Assertions.assertEquals(rowCountInserted, testDataCount);
     }
 
@@ -153,21 +159,32 @@ public class TDengineIT extends TestSuiteBase implements TestResource {
                 container.executeJob("/tdengine/tdengine_fake_to_sink_multitable.conf");
         Assertions.assertEquals(0, execResult.getExitCode());
 
-        long rowCountInserted = readSinkDataset("meters3");
-        long rowCountInserted2 = readSinkDataset("meters4");
+        long rowCountInserted = readSinkDataset("power2", "meters3");
+        long rowCountInserted2 = readSinkDataset("power2", "meters4");
         Assertions.assertEquals(rowCountInserted, testDataCountMulti_Table1);
         Assertions.assertEquals(rowCountInserted2, testDataCountMulti_Table2);
     }
 
+    @TestTemplate
+    public void testTDEngineSourceToSinkFilterByFieldName(TestContainer container)
+            throws Exception {
+        Container.ExecResult execResult =
+                container.executeJob("/tdengine/tdengine_source_to_sink_filter_by_fieldNames.conf");
+        Assertions.assertEquals(0, execResult.getExitCode());
+
+        long rowCountInserted = readSinkDataset("power3", "meters5");
+        Assertions.assertEquals(4, rowCountInserted);
+    }
+
     @SneakyThrows
-    private long readSinkDataset(String stableName) {
+    private long readSinkDataset(String database, String stableName) {
         // Validate table name
         if (stableName == null || !stableName.matches("^[a-zA-Z0-9_]+$")) {
             throw new IllegalArgumentException("Invalid table name provided: " + stableName);
         }
 
         long rowCount;
-        String sql = String.format("SELECT COUNT(1) FROM power2.%s;", stableName);
+        String sql = String.format("SELECT COUNT(1) FROM %s.%s;", database, stableName);
         try (Statement stmt = connection2.createStatement();
                 ResultSet resultSet = stmt.executeQuery(sql); ) {
             resultSet.next();
