@@ -33,7 +33,7 @@ import org.apache.seatunnel.api.table.catalog.exception.TableNotExistException;
 import org.apache.seatunnel.api.table.type.BasicType;
 import org.apache.seatunnel.connectors.seatunnel.typesense.catalog.TypesenseCatalog;
 import org.apache.seatunnel.connectors.seatunnel.typesense.client.TypesenseClient;
-import org.apache.seatunnel.connectors.seatunnel.typesense.config.TypesenseConnectionConfig;
+import org.apache.seatunnel.connectors.seatunnel.typesense.config.TypesenseBaseOptions;
 import org.apache.seatunnel.e2e.common.TestResource;
 import org.apache.seatunnel.e2e.common.TestSuiteBase;
 import org.apache.seatunnel.e2e.common.container.TestContainer;
@@ -110,9 +110,9 @@ public class TypesenseIT extends TestSuiteBase implements TestResource {
     private void initConnection() {
         String host = typesenseServer.getContainerIpAddress();
         Map<String, Object> config = new HashMap<>();
-        config.put(TypesenseConnectionConfig.HOSTS.key(), Lists.newArrayList(host + ":8108"));
-        config.put(TypesenseConnectionConfig.APIKEY.key(), "xyz");
-        config.put(TypesenseConnectionConfig.PROTOCOL.key(), "http");
+        config.put(TypesenseBaseOptions.HOSTS.key(), Lists.newArrayList(host + ":8108"));
+        config.put(TypesenseBaseOptions.APIKEY.key(), "xyz");
+        config.put(TypesenseBaseOptions.PROTOCOL.key(), "http");
         ReadonlyConfig readonlyConfig = ReadonlyConfig.fromMap(config);
 
         typesenseClient = TypesenseClient.createInstance(readonlyConfig);
