@@ -26,9 +26,9 @@ import org.apache.seatunnel.engine.common.config.EngineConfig;
 import org.apache.seatunnel.engine.common.config.JobConfig;
 import org.apache.seatunnel.engine.common.config.SeaTunnelConfig;
 import org.apache.seatunnel.engine.common.config.server.ScheduleStrategy;
+import org.apache.seatunnel.engine.common.job.JobResult;
+import org.apache.seatunnel.engine.common.job.JobStatus;
 import org.apache.seatunnel.engine.common.utils.PassiveCompletableFuture;
-import org.apache.seatunnel.engine.core.job.JobResult;
-import org.apache.seatunnel.engine.core.job.JobStatus;
 import org.apache.seatunnel.engine.server.SeaTunnelServerStarter;
 
 import org.awaitility.Awaitility;
@@ -64,7 +64,7 @@ public class SeaTunnelEngineClusterRoleTest {
         SeaTunnelConfig seaTunnelConfig = ConfigProvider.locateAndGetSeaTunnelConfig();
         seaTunnelConfig
                 .getHazelcastConfig()
-                .setClusterName(TestUtils.getClusterName(testClusterName));
+                .setClusterName(ContentFormatUtilTest.getClusterName(testClusterName));
 
         try {
             // master node must start first in ci
@@ -126,11 +126,11 @@ public class SeaTunnelEngineClusterRoleTest {
         SeaTunnelConfig seaTunnelConfig = ConfigProvider.locateAndGetSeaTunnelConfig();
         seaTunnelConfig
                 .getHazelcastConfig()
-                .setClusterName(TestUtils.getClusterName(testClusterName));
+                .setClusterName(ContentFormatUtilTest.getClusterName(testClusterName));
 
         // submit job
         Common.setDeployMode(DeployMode.CLIENT);
-        String filePath = TestUtils.getResource("/client_test.conf");
+        String filePath = ContentFormatUtilTest.getResource("/client_test.conf");
         JobConfig jobConfig = new JobConfig();
         jobConfig.setName("Test_canNotSubmitJobWhenHaveNoWorkerNode");
 
@@ -151,18 +151,17 @@ public class SeaTunnelEngineClusterRoleTest {
             ClientJobExecutionEnvironment jobExecutionEnv =
                     seaTunnelClient.createExecutionContext(filePath, jobConfig, seaTunnelConfig);
             final ClientJobProxy clientJobProxy = jobExecutionEnv.execute();
-            await().atMost(60000, TimeUnit.MILLISECONDS)
-                    .until(
+            PassiveCompletableFuture<JobResult> jobResultPassiveCompletableFuture =
+                    clientJobProxy.doWaitForJobComplete();
+            await().pollDelay(30, TimeUnit.SECONDS)
+                    .atMost(60000, TimeUnit.MILLISECONDS)
+                    .untilAsserted(
                             () -> {
-                                try {
-                                    PassiveCompletableFuture<JobResult>
-                                            jobResultPassiveCompletableFuture =
-                                                    clientJobProxy.doWaitForJobComplete();
-                                    String mes = jobResultPassiveCompletableFuture.get().getError();
-                                    return mes.contains("NoEnoughResourceException");
-                                } catch (Exception e) {
-                                    return false;
+                                String mes = "";
+                                if (jobResultPassiveCompletableFuture.isDone()) {
+                                    mes = jobResultPassiveCompletableFuture.get().getError();
                                 }
+                                Assertions.assertTrue(mes.contains("NoEnoughResourceException"));
                             });
 
         } catch (ExecutionException | InterruptedException e) {
@@ -192,11 +191,11 @@ public class SeaTunnelEngineClusterRoleTest {
         engineConfig.getSlotServiceConfig().setSlotNum(3);
         seaTunnelConfig
                 .getHazelcastConfig()
-                .setClusterName(TestUtils.getClusterName(testClusterName));
+                .setClusterName(ContentFormatUtilTest.getClusterName(testClusterName));
 
         // submit job
         Common.setDeployMode(DeployMode.CLIENT);
-        String filePath = TestUtils.getResource("/client_test.conf");
+        String filePath = ContentFormatUtilTest.getResource("/client_test.conf");
         JobConfig jobConfig = new JobConfig();
         jobConfig.setName("Test_enterPendingWhenResourcesNotEnough");
 
@@ -223,6 +222,9 @@ public class SeaTunnelEngineClusterRoleTest {
                             () ->
                                     Assertions.assertEquals(
                                             clientJobProxy.getJobStatus(), JobStatus.PENDING));
+            String status = seaTunnelClient.listJobStatus();
+            status.contains("PENDING");
+
             // start two worker nodes
             SeaTunnelServerStarter.createWorkerHazelcastInstance(seaTunnelConfig);
             SeaTunnelServerStarter.createWorkerHazelcastInstance(seaTunnelConfig);
@@ -262,11 +264,11 @@ public class SeaTunnelEngineClusterRoleTest {
 
         seaTunnelConfig
                 .getHazelcastConfig()
-                .setClusterName(TestUtils.getClusterName(clusterAndJobName));
+                .setClusterName(ContentFormatUtilTest.getClusterName(clusterAndJobName));
 
         // submit job
         Common.setDeployMode(DeployMode.CLIENT);
-        String filePath = TestUtils.getResource("/client_test.conf");
+        String filePath = ContentFormatUtilTest.getResource("/client_test.conf");
         JobConfig jobConfig = new JobConfig();
         jobConfig.setName(clusterAndJobName);
 
@@ -285,6 +287,8 @@ public class SeaTunnelEngineClusterRoleTest {
                             () ->
                                     Assertions.assertEquals(
                                             clientJobProxy.getJobStatus(), JobStatus.PENDING));
+            String status = seaTunnelClient.listJobStatus();
+            status.contains("PENDING");
 
             // Cancel the job in the pending state
             seaTunnelClient.getJobClient().cancelJob(clientJobProxy.getJobId());
@@ -365,7 +369,7 @@ public class SeaTunnelEngineClusterRoleTest {
 
     private SeaTunnelClient createSeaTunnelClient(String clusterName) {
         ClientConfig clientConfig = ConfigProvider.locateAndGetClientConfig();
-        clientConfig.setClusterName(TestUtils.getClusterName(clusterName));
+        clientConfig.setClusterName(ContentFormatUtilTest.getClusterName(clusterName));
         return new SeaTunnelClient(clientConfig);
     }
 }
