@@ -41,35 +41,44 @@ import static com.hazelcast.internal.util.Preconditions.checkPositive;
 @Data
 public class EngineConfig {
 
-    private int backupCount = ServerConfigOptions.BACKUP_COUNT.defaultValue();
+    private int backupCount =
+            ServerConfigOptions.MasterServerConfigOptions.BACKUP_COUNT.defaultValue();
     private int printExecutionInfoInterval =
-            ServerConfigOptions.PRINT_EXECUTION_INFO_INTERVAL.defaultValue();
+            ServerConfigOptions.MasterServerConfigOptions.PRINT_EXECUTION_INFO_INTERVAL
+                    .defaultValue();
 
     private int printJobMetricsInfoInterval =
-            ServerConfigOptions.PRINT_JOB_METRICS_INFO_INTERVAL.defaultValue();
+            ServerConfigOptions.MasterServerConfigOptions.PRINT_JOB_METRICS_INFO_INTERVAL
+                    .defaultValue();
 
     private int jobMetricsBackupInterval =
-            ServerConfigOptions.JOB_METRICS_BACKUP_INTERVAL.defaultValue();
+            ServerConfigOptions.MasterServerConfigOptions.JOB_METRICS_BACKUP_INTERVAL
+                    .defaultValue();
 
     private ThreadShareMode taskExecutionThreadShareMode =
-            ServerConfigOptions.TASK_EXECUTION_THREAD_SHARE_MODE.defaultValue();
+            ServerConfigOptions.WorkerServerConfigOptions.TASK_EXECUTION_THREAD_SHARE_MODE
+                    .defaultValue();
 
-    private SlotServiceConfig slotServiceConfig = ServerConfigOptions.SLOT_SERVICE.defaultValue();
+    private SlotServiceConfig slotServiceConfig =
+            ServerConfigOptions.WorkerServerConfigOptions.SLOT_SERVICE.defaultValue();
 
-    private CheckpointConfig checkpointConfig = ServerConfigOptions.CHECKPOINT.defaultValue();
+    private CheckpointConfig checkpointConfig =
+            ServerConfigOptions.MasterServerConfigOptions.CHECKPOINT.defaultValue();
 
     private CoordinatorServiceConfig coordinatorServiceConfig =
-            ServerConfigOptions.COORDINATOR_SERVICE.defaultValue();
+            ServerConfigOptions.MasterServerConfigOptions.COORDINATOR_SERVICE.defaultValue();
 
     private ConnectorJarStorageConfig connectorJarStorageConfig =
-            ServerConfigOptions.CONNECTOR_JAR_STORAGE_CONFIG.defaultValue();
+            ServerConfigOptions.MasterServerConfigOptions.CONNECTOR_JAR_STORAGE_CONFIG
+                    .defaultValue();
 
     private boolean classloaderCacheMode =
             ServerConfigOptions.CLASSLOADER_CACHE_MODE.defaultValue();
 
-    private QueueType queueType = ServerConfigOptions.QUEUE_TYPE.defaultValue();
+    private QueueType queueType =
+            ServerConfigOptions.WorkerServerConfigOptions.QUEUE_TYPE.defaultValue();
     private int historyJobExpireMinutes =
-            ServerConfigOptions.HISTORY_JOB_EXPIRE_MINUTES.defaultValue();
+            ServerConfigOptions.MasterServerConfigOptions.HISTORY_JOB_EXPIRE_MINUTES.defaultValue();
 
     private ClusterRole clusterRole = ClusterRole.MASTER_AND_WORKER;
 
@@ -81,9 +90,10 @@ public class EngineConfig {
     private TelemetryConfig telemetryConfig = ServerConfigOptions.TELEMETRY.defaultValue();
 
     private ScheduleStrategy scheduleStrategy =
-            ServerConfigOptions.JOB_SCHEDULE_STRATEGY.defaultValue();
+            ServerConfigOptions.MasterServerConfigOptions.JOB_SCHEDULE_STRATEGY.defaultValue();
 
-    private HttpConfig httpConfig = ServerConfigOptions.HTTP.defaultValue();
+    private HttpConfig httpConfig =
+            ServerConfigOptions.MasterServerConfigOptions.HTTP.defaultValue();
 
     public void setBackupCount(int newBackupCount) {
         checkBackupCount(newBackupCount, 0);
@@ -97,21 +107,24 @@ public class EngineConfig {
     public void setPrintExecutionInfoInterval(int printExecutionInfoInterval) {
         checkPositive(
                 printExecutionInfoInterval,
-                ServerConfigOptions.PRINT_EXECUTION_INFO_INTERVAL + " must be > 0");
+                ServerConfigOptions.MasterServerConfigOptions.PRINT_EXECUTION_INFO_INTERVAL
+                        + " must be > 0");
         this.printExecutionInfoInterval = printExecutionInfoInterval;
     }
 
     public void setPrintJobMetricsInfoInterval(int printJobMetricsInfoInterval) {
         checkPositive(
                 printJobMetricsInfoInterval,
-                ServerConfigOptions.PRINT_JOB_METRICS_INFO_INTERVAL + " must be > 0");
+                ServerConfigOptions.MasterServerConfigOptions.PRINT_JOB_METRICS_INFO_INTERVAL
+                        + " must be > 0");
         this.printJobMetricsInfoInterval = printJobMetricsInfoInterval;
     }
 
     public void setJobMetricsBackupInterval(int jobMetricsBackupInterval) {
         checkPositive(
                 jobMetricsBackupInterval,
-                ServerConfigOptions.JOB_METRICS_BACKUP_INTERVAL + " must be > 0");
+                ServerConfigOptions.MasterServerConfigOptions.JOB_METRICS_BACKUP_INTERVAL
+                        + " must be > 0");
         this.jobMetricsBackupInterval = jobMetricsBackupInterval;
     }
 
@@ -123,7 +136,8 @@ public class EngineConfig {
     public void setHistoryJobExpireMinutes(int historyJobExpireMinutes) {
         checkPositive(
                 historyJobExpireMinutes,
-                ServerConfigOptions.HISTORY_JOB_EXPIRE_MINUTES + " must be > 0");
+                ServerConfigOptions.MasterServerConfigOptions.HISTORY_JOB_EXPIRE_MINUTES
+                        + " must be > 0");
         this.historyJobExpireMinutes = historyJobExpireMinutes;
     }
 
