@@ -202,6 +202,7 @@ public class SeaTunnelHealthMonitor {
         public String render() {
             update();
             sb.setLength(0);
+            isMasterFlag();
             ipPort();
             renderProcessors();
             renderPhysicalMemory();
@@ -226,6 +227,10 @@ public class SeaTunnelHealthMonitor {
             sb.append("port=").append(node.address.getPort()).append(", ");
         }
 
+        private void isMasterFlag() {
+            sb.append("isMaster=").append(node.isMaster()).append(", ");
+        }
+
         private void renderConnection() {
             sb.append("connection.active.count=")
                     .append(tcpConnectionActiveCount.read())
