@@ -19,7 +19,6 @@ package org.apache.seatunnel.engine.server.dag.execution;
 
 import org.apache.seatunnel.engine.common.utils.IdGenerator;
 import org.apache.seatunnel.engine.core.dag.actions.Action;
-import org.apache.seatunnel.engine.core.dag.actions.ShuffleAction;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -135,10 +134,7 @@ public class PipelineGenerator {
 
     /** If this execution vertex have partition transform, can't be spilt */
     private boolean checkCanSplit(List<ExecutionEdge> edges) {
-        return edges.stream()
-                        .noneMatch(e -> e.getRightVertex().getAction() instanceof ShuffleAction)
-                && edges.stream()
-                        .anyMatch(e -> inputVerticesMap.get(e.getRightVertexId()).size() > 1);
+        return edges.stream().anyMatch(e -> inputVerticesMap.get(e.getRightVertexId()).size() > 1);
     }
 
     private void splitUnionVertex(
@@ -184,9 +180,7 @@ public class PipelineGenerator {
         long id = idGenerator.getNextId();
         Action action = vertex.getAction();
         return new ExecutionVertex(
-                id,
-                ExecutionPlanGenerator.recreateAction(action, id, parallelism),
-                action instanceof ShuffleAction ? vertex.getParallelism() : parallelism);
+                id, ExecutionPlanGenerator.recreateAction(action, id, parallelism), parallelism);
     }
 
     private void fillVerticesMap(List<ExecutionEdge> edges) {
