@@ -24,11 +24,11 @@ import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.node.ObjectNode
 
 import org.apache.seatunnel.api.common.metrics.JobMetrics;
 import org.apache.seatunnel.engine.common.exception.SeaTunnelEngineException;
+import org.apache.seatunnel.engine.common.job.JobStatus;
+import org.apache.seatunnel.engine.common.job.JobStatusData;
 import org.apache.seatunnel.engine.core.job.ExecutionAddress;
 import org.apache.seatunnel.engine.core.job.JobDAGInfo;
 import org.apache.seatunnel.engine.core.job.JobImmutableInformation;
-import org.apache.seatunnel.engine.core.job.JobStatus;
-import org.apache.seatunnel.engine.core.job.JobStatusData;
 import org.apache.seatunnel.engine.core.job.PipelineStatus;
 import org.apache.seatunnel.engine.server.dag.physical.PipelineLocation;
 import org.apache.seatunnel.engine.server.execution.ExecutionState;
@@ -144,10 +144,36 @@ public class JobHistoryService {
                         .collect(Collectors.toList());
         Set<Long> runningJonIds =
                 runningJobStateList.stream().map(JobState::getJobId).collect(Collectors.toSet());
+
+        List<JobState> pendingJobStateList =
+                pendingJobMasterMap.entrySet().stream()
+                        .map(
+                                entry -> {
+                                    Long jobId = entry.getKey();
+                                    JobImmutableInformation jobImmutableInformation =
+                                            entry.getValue()._2.getJobImmutableInformation();
+                                    return new JobState(
+                                            jobId,
+                                            jobImmutableInformation.getJobName(),
+                                            JobStatus.PENDING,
+                                            jobImmutableInformation.getCreateTime(),
+                                            null,
+                                            null,
+                                            null,
+                                            null);
+                                })
+                        .collect(Collectors.toList());
+        Set<Long> pendingJobIds =
+                pendingJobStateList.stream().map(JobState::getJobId).collect(Collectors.toSet());
+
         Stream.concat(
-                        runningJobStateList.stream(),
+                        Stream.concat(runningJobStateList.stream(), pendingJobStateList.stream()),
                         finishedJobStateImap.values().stream()
-                                .filter(jobState -> !runningJonIds.contains(jobState.getJobId())))
+                                .filter(
+                                        jobState ->
+                                                !runningJonIds.contains(jobState.getJobId())
+                                                        && !pendingJobIds.contains(
+                                                                jobState.getJobId())))
                 .forEach(
                         jobState -> {
                             JobStatusData jobStatusData =
@@ -156,6 +182,7 @@ public class JobHistoryService {
                                             jobState.getJobName(),
                                             jobState.getJobStatus(),
                                             jobState.getSubmitTime(),
+                                            jobState.getStartTime(),
                                             jobState.getFinishTime());
                             status.add(jobStatusData);
                         });
@@ -175,6 +202,7 @@ public class JobHistoryService {
                     jobImmutableInformation.getCreateTime(),
                     null,
                     null,
+                    null,
                     null);
         }
         return runningJobMasterMap.containsKey(jobId)
@@ -210,6 +238,7 @@ public class JobHistoryService {
 
     public void storeFinishedJobState(JobMaster jobMaster) {
         JobState jobState = toJobStateMapper(jobMaster, false);
+        jobState.setStartTime(jobMaster.getStateTimestamp(JobStatus.SCHEDULED));
         jobState.setFinishTime(System.currentTimeMillis());
         jobState.setErrorMessage(jobMaster.getErrorMessage());
         finishedJobStateImap.put(jobState.jobId, jobState, finishedJobExpireTime, TimeUnit.MINUTES);
@@ -273,8 +302,16 @@ public class JobHistoryService {
         JobStatus jobStatus = (JobStatus) runningJobStateIMap.get(jobId);
         String jobName = jobMaster.getJobImmutableInformation().getJobName();
         long submitTime = jobMaster.getJobImmutableInformation().getCreateTime();
+        Long startTime = jobMaster.getStateTimestamp(JobStatus.SCHEDULED);
         return new JobState(
-                jobId, jobName, jobStatus, submitTime, null, pipelineStateMapperMap, null);
+                jobId,
+                jobName,
+                jobStatus,
+                submitTime,
+                startTime,
+                null,
+                pipelineStateMapperMap,
+                null);
     }
 
     public void storeJobInfo(long jobId, JobDAGInfo jobInfo) {
@@ -289,6 +326,7 @@ public class JobHistoryService {
         private String jobName;
         private JobStatus jobStatus;
         private long submitTime;
+        private Long startTime;
         private Long finishTime;
         private Map<PipelineLocation, PipelineStateData> pipelineStateMapperMap;
         private String errorMessage;
