@@ -17,6 +17,9 @@
 
 package org.apache.seatunnel.engine.server.master;
 
+import org.apache.seatunnel.common.utils.JsonUtils;
+import org.apache.seatunnel.engine.common.job.JobStatus;
+import org.apache.seatunnel.engine.common.job.JobStatusData;
 import org.apache.seatunnel.engine.common.utils.PassiveCompletableFuture;
 import org.apache.seatunnel.engine.core.dag.logical.LogicalDag;
 import org.apache.seatunnel.engine.core.job.JobImmutableInformation;
@@ -32,6 +35,8 @@ import org.junit.jupiter.api.condition.OS;
 import com.hazelcast.internal.serialization.Data;
 
 import java.util.Collections;
+import java.util.List;
+import java.util.Optional;
 import java.util.concurrent.TimeUnit;
 
 import static org.awaitility.Awaitility.await;
@@ -51,49 +56,65 @@ class JobHistoryServiceTest extends AbstractSeaTunnelServerTest {
         // waiting for JOB_1 status turn to RUNNING
         await().atMost(60000, TimeUnit.MILLISECONDS)
                 .untilAsserted(
-                        () ->
-                                Assertions.assertTrue(
-                                        server.getCoordinatorService()
-                                                .getJobHistoryService()
-                                                .listAllJob()
-                                                .contains(
-                                                        String.format(
-                                                                "\"jobId\":%s,\"jobName\":\"Test\",\"jobStatus\":\"RUNNING\"",
-                                                                JOB_1))));
+                        () -> {
+                            List<JobStatusData> jobStatusData = listJob();
+                            Optional<JobStatusData> job =
+                                    jobStatusData.stream()
+                                            .filter(jobStatus -> jobStatus.getJobId().equals(JOB_1))
+                                            .findFirst();
+                            Assertions.assertTrue(job.isPresent());
+                            Assertions.assertEquals(JobStatus.RUNNING, job.get().getJobStatus());
+                            Assertions.assertEquals("Test", job.get().getJobName());
+                            Assertions.assertNotNull(job.get().getStartTime());
+                            Assertions.assertNotNull(
+                                    job.get().getStartTime() > job.get().getSubmitTime());
+                        });
 
         // waiting for JOB_1 status turn to FINISHED
-        await().atMost(60000, TimeUnit.MILLISECONDS)
+        await().pollDelay(5, TimeUnit.SECONDS)
+                .atMost(60000, TimeUnit.MILLISECONDS)
                 .untilAsserted(
-                        () ->
-                                Assertions.assertTrue(
-                                        server.getCoordinatorService()
-                                                .getJobHistoryService()
-                                                .listAllJob()
-                                                .contains(
-                                                        String.format(
-                                                                "\"jobId\":%s,\"jobName\":\"Test\",\"jobStatus\":\"FINISHED\"",
-                                                                JOB_1))));
+                        () -> {
+                            List<JobStatusData> jobStatusData = listJob();
+                            Optional<JobStatusData> job =
+                                    jobStatusData.stream()
+                                            .filter(jobStatus -> jobStatus.getJobId().equals(JOB_1))
+                                            .findFirst();
+                            Assertions.assertTrue(job.isPresent());
+                            Assertions.assertEquals(JobStatus.FINISHED, job.get().getJobStatus());
+                            Assertions.assertEquals("Test", job.get().getJobName());
+                            Assertions.assertNotNull(job.get().getStartTime());
+                            Assertions.assertNotNull(job.get().getFinishTime());
+                            Assertions.assertNotNull(
+                                    job.get().getFinishTime() > job.get().getStartTime());
+                        });
 
         startJob(JOB_2, "fake_to_console.conf");
         // waiting for JOB_2 status turn to FINISHED and JOB_2 status turn to RUNNING
         await().atMost(60000, TimeUnit.MILLISECONDS)
                 .untilAsserted(
-                        () ->
-                                Assertions.assertTrue(
-                                        server.getCoordinatorService()
-                                                        .getJobHistoryService()
-                                                        .listAllJob()
-                                                        .contains(
-                                                                String.format(
-                                                                        "\"jobId\":%s,\"jobName\":\"Test\",\"jobStatus\":\"FINISHED\"",
-                                                                        JOB_1))
-                                                && server.getCoordinatorService()
-                                                        .getJobHistoryService()
-                                                        .listAllJob()
-                                                        .contains(
-                                                                String.format(
-                                                                        "\"jobId\":%s,\"jobName\":\"Test\",\"jobStatus\":\"RUNNING\"",
-                                                                        JOB_2))));
+                        () -> {
+                            List<JobStatusData> jobStatusData = listJob();
+                            Optional<JobStatusData> job1 =
+                                    jobStatusData.stream()
+                                            .filter(jobStatus -> jobStatus.getJobId().equals(JOB_1))
+                                            .findFirst();
+                            Assertions.assertTrue(job1.isPresent());
+                            Assertions.assertEquals(JobStatus.FINISHED, job1.get().getJobStatus());
+                            Assertions.assertEquals("Test", job1.get().getJobName());
+                            Assertions.assertNotNull(job1.get().getStartTime());
+                            Assertions.assertNotNull(job1.get().getFinishTime());
+                            Optional<JobStatusData> job2 =
+                                    jobStatusData.stream()
+                                            .filter(jobStatus -> jobStatus.getJobId().equals(JOB_2))
+                                            .findFirst();
+                            Assertions.assertTrue(job2.isPresent());
+                            Assertions.assertEquals(JobStatus.RUNNING, job2.get().getJobStatus());
+                            Assertions.assertEquals("Test", job2.get().getJobName());
+                            Assertions.assertNotNull(job2.get().getStartTime());
+                            Assertions.assertNotNull(
+                                    job2.get().getStartTime() > job2.get().getSubmitTime());
+                        });
     }
 
     @Test
@@ -147,4 +168,9 @@ class JobHistoryServiceTest extends AbstractSeaTunnelServerTest {
                         .submitJob(jobid, data, jobImmutableInformation.isStartWithSavePoint());
         voidPassiveCompletableFuture.join();
     }
+
+    private List<JobStatusData> listJob() {
+        String listAllJob = server.getCoordinatorService().getJobHistoryService().listAllJob();
+        return JsonUtils.toList(listAllJob, JobStatusData.class);
+    }
 }
