@@ -256,6 +256,9 @@ public class JsonToRowConverters implements Serializable {
             dateFormatter = DateUtils.matchDateFormatter(dateStr);
             fieldFormatterMap.put(fieldName, dateFormatter);
         }
+        if (dateFormatter == null) {
+            throw CommonError.formatDateError(dateStr, fieldName);
+        }
 
         return dateFormatter.parse(jsonNode.asText()).query(TemporalQueries.localDate());
     }
@@ -272,6 +275,9 @@ public class JsonToRowConverters implements Serializable {
             dateTimeFormatter = DateTimeUtils.matchDateTimeFormatter(datetimeStr);
             fieldFormatterMap.put(fieldName, dateTimeFormatter);
         }
+        if (dateTimeFormatter == null) {
+            throw CommonError.formatDateTimeError(datetimeStr, fieldName);
+        }
 
         TemporalAccessor parsedTimestamp = dateTimeFormatter.parse(datetimeStr);
         LocalTime localTime = parsedTimestamp.query(TemporalQueries.localTime());
