@@ -25,17 +25,20 @@ import org.apache.seatunnel.api.serialization.DeserializationSchema;
 import org.apache.seatunnel.api.source.Collector;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.TablePath;
+import org.apache.seatunnel.api.table.type.MetadataUtil;
 import org.apache.seatunnel.api.table.type.RowKind;
 import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
 import org.apache.seatunnel.common.exception.CommonError;
 import org.apache.seatunnel.common.exception.SeaTunnelRuntimeException;
+import org.apache.seatunnel.common.utils.DateTimeUtils;
 import org.apache.seatunnel.format.json.JsonDeserializationSchema;
 
 import lombok.NonNull;
 
 import java.io.IOException;
+import java.time.ZoneOffset;
 import java.util.Optional;
 import java.util.regex.Pattern;
 
@@ -49,6 +52,8 @@ public class OggJsonDeserializationSchema implements DeserializationSchema<SeaTu
 
     private static final String FIELD_DATABASE_TABLE = "table";
 
+    private static final String FIELD_TS = "op_ts";
+
     private static final String DATA_BEFORE = "before"; // BEFORE
 
     private static final String DATA_AFTER = "after"; // AFTER
@@ -151,7 +156,13 @@ public class OggJsonDeserializationSchema implements DeserializationSchema<SeaTu
             }
 
             String op = jsonNode.get(FIELD_TYPE).asText().trim();
-
+            JsonNode tsNode = jsonNode.get(FIELD_TS);
+            // ogg json ts is date, eg "2020-05-13 15:40:07.000000"
+            long ts = 0;
+            if (tsNode != null) {
+                String tsDateTime = tsNode.asText();
+                ts = DateTimeUtils.parse(tsDateTime).toEpochSecond(ZoneOffset.UTC) * 1000;
+            }
             switch (op) {
                 case OP_INSERT:
                     // Gets the data for the INSERT operation
@@ -160,6 +171,9 @@ public class OggJsonDeserializationSchema implements DeserializationSchema<SeaTu
                     if (tablePath != null) {
                         row.setTableId(tablePath.toString());
                     }
+                    if (tsNode != null) {
+                        MetadataUtil.setEventTime(row, ts);
+                    }
                     out.collect(row);
                     break;
                 case OP_UPDATE:
@@ -178,12 +192,18 @@ public class OggJsonDeserializationSchema implements DeserializationSchema<SeaTu
                     if (tablePath != null) {
                         before.setTableId(tablePath.toString());
                     }
+                    if (tsNode != null) {
+                        MetadataUtil.setEventTime(before, ts);
+                    }
                     out.collect(before);
 
                     after.setRowKind(RowKind.UPDATE_AFTER);
                     if (tablePath != null) {
                         after.setTableId(tablePath.toString());
                     }
+                    if (tsNode != null) {
+                        MetadataUtil.setEventTime(after, ts);
+                    }
                     out.collect(after);
                     break;
                 case OP_DELETE:
@@ -202,6 +222,9 @@ public class OggJsonDeserializationSchema implements DeserializationSchema<SeaTu
                     if (tablePath != null) {
                         beforeDelete.setTableId(tablePath.toString());
                     }
+                    if (tsNode != null) {
+                        MetadataUtil.setEventTime(beforeDelete, ts);
+                    }
                     out.collect(beforeDelete);
                     break;
                 default:
