@@ -24,6 +24,7 @@ import org.apache.seatunnel.plugin.discovery.AbstractPluginDiscovery;
 import org.apache.commons.lang3.StringUtils;
 
 import java.net.URL;
+import java.util.List;
 import java.util.ServiceLoader;
 import java.util.function.BiConsumer;
 
@@ -38,7 +39,7 @@ public class SeaTunnelFactoryDiscovery extends AbstractPluginDiscovery<Factory>
 
     public SeaTunnelFactoryDiscovery(
             Class<? extends Factory> factoryClass,
-            BiConsumer<ClassLoader, URL> addURLToClassLoader) {
+            BiConsumer<ClassLoader, List<URL>> addURLToClassLoader) {
         super(addURLToClassLoader);
         this.factoryClass = factoryClass;
     }
