@@ -70,7 +70,7 @@ public class SeaTunnelSinkPluginDiscovery extends AbstractPluginDiscovery<SeaTun
         return plugins;
     }
 
-    public SeaTunnelSinkPluginDiscovery(BiConsumer<ClassLoader, URL> addURLToClassLoader) {
+    public SeaTunnelSinkPluginDiscovery(BiConsumer<ClassLoader, List<URL>> addURLToClassLoader) {
         super(addURLToClassLoader);
     }
 
