@@ -18,11 +18,11 @@
 package org.apache.seatunnel.transform.copy;
 
 import org.apache.seatunnel.api.configuration.util.OptionRule;
-import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.connector.TableTransform;
 import org.apache.seatunnel.api.table.factory.Factory;
 import org.apache.seatunnel.api.table.factory.TableTransformFactory;
 import org.apache.seatunnel.api.table.factory.TableTransformFactoryContext;
+import org.apache.seatunnel.transform.common.TransformCommonOptions;
 
 import com.google.auto.service.AutoService;
 
@@ -38,13 +38,15 @@ public class CopyFieldTransformFactory implements TableTransformFactory {
         return OptionRule.builder()
                 .bundled(CopyTransformConfig.SRC_FIELD, CopyTransformConfig.DEST_FIELD)
                 .bundled(CopyTransformConfig.FIELDS)
+                .optional(TransformCommonOptions.MULTI_TABLES)
+                .optional(TransformCommonOptions.TABLE_MATCH_REGEX)
                 .build();
     }
 
     @Override
     public TableTransform createTransform(TableTransformFactoryContext context) {
-        CopyTransformConfig copyTransformConfig = CopyTransformConfig.of(context.getOptions());
-        CatalogTable catalogTable = context.getCatalogTables().get(0);
-        return () -> new CopyFieldTransform(copyTransformConfig, catalogTable);
+        return () ->
+                new CopyFieldMultiCatalogTransform(
+                        context.getCatalogTables(), context.getOptions());
     }
 }
