@@ -18,11 +18,11 @@
 package org.apache.seatunnel.transform.filterrowkind;
 
 import org.apache.seatunnel.api.configuration.util.OptionRule;
-import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.connector.TableTransform;
 import org.apache.seatunnel.api.table.factory.Factory;
 import org.apache.seatunnel.api.table.factory.TableTransformFactory;
 import org.apache.seatunnel.api.table.factory.TableTransformFactoryContext;
+import org.apache.seatunnel.transform.common.TransformCommonOptions;
 
 import com.google.auto.service.AutoService;
 
@@ -36,15 +36,18 @@ public class FilterRowKindTransformFactory implements TableTransformFactory {
     @Override
     public OptionRule optionRule() {
         return OptionRule.builder()
-                .exclusive(
+                .optional(
                         FilterRowKinkTransformConfig.EXCLUDE_KINDS,
                         FilterRowKinkTransformConfig.INCLUDE_KINDS)
+                .optional(TransformCommonOptions.MULTI_TABLES)
+                .optional(TransformCommonOptions.TABLE_MATCH_REGEX)
                 .build();
     }
 
     @Override
     public TableTransform createTransform(TableTransformFactoryContext context) {
-        CatalogTable catalogTable = context.getCatalogTables().get(0);
-        return () -> new FilterRowKindTransform(context.getOptions(), catalogTable);
+        return () ->
+                new FieldRowKindMultiCatalogTransform(
+                        context.getCatalogTables(), context.getOptions());
     }
 }
