@@ -16,9 +16,11 @@
  */
 package org.apache.seatunnel.transform.jsonpath;
 
+import org.apache.seatunnel.api.table.catalog.Column;
 import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.transform.common.ErrorHandleWay;
 
+import lombok.Getter;
 import lombok.ToString;
 
 import java.io.Serializable;
@@ -31,19 +33,19 @@ public class ColumnConfig implements Serializable {
 
     private final String destField;
 
-    private final SeaTunnelDataType<?> destType;
+    @Getter private final Column destColumn;
     private final ErrorHandleWay errorHandleWay;
 
     public ColumnConfig(
             String path,
             String srcField,
             String destField,
-            SeaTunnelDataType<?> destType,
+            Column destColumn,
             ErrorHandleWay errorHandleWay) {
         this.path = path;
         this.srcField = srcField;
         this.destField = destField;
-        this.destType = destType;
+        this.destColumn = destColumn;
         this.errorHandleWay = errorHandleWay;
     }
 
@@ -60,7 +62,7 @@ public class ColumnConfig implements Serializable {
     }
 
     public SeaTunnelDataType<?> getDestType() {
-        return destType;
+        return destColumn.getDataType();
     }
 
     public ErrorHandleWay errorHandleWay() {
