@@ -48,6 +48,14 @@ public class EmbeddingTransformFactory implements TableTransformFactory {
                         EmbeddingTransformConfig.API_PATH,
                         EmbeddingTransformConfig.SINGLE_VECTORIZED_INPUT_NUMBER,
                         EmbeddingTransformConfig.PROCESS_BATCH_SIZE)
+                .conditional(
+                        EmbeddingTransformConfig.MODEL_PROVIDER,
+                        ModelProvider.AMAZON,
+                        EmbeddingTransformConfig.API_KEY,
+                        EmbeddingTransformConfig.SECRET_KEY,
+                        EmbeddingTransformConfig.AWS_REGION,
+                        EmbeddingTransformConfig.MODEL,
+                        EmbeddingTransformConfig.DIMENSION)
                 .conditional(
                         EmbeddingTransformConfig.MODEL_PROVIDER,
                         Lists.newArrayList(ModelProvider.OPENAI, ModelProvider.DOUBAO),
