@@ -19,7 +19,7 @@ package org.apache.seatunnel.transform.nlpmodel.embedding.remote;
 
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.ObjectMapper;
 
-import org.apache.seatunnel.common.utils.BufferUtils;
+import org.apache.seatunnel.common.utils.VectorUtils;
 
 import org.apache.commons.lang3.ArrayUtils;
 
@@ -42,23 +42,23 @@ public abstract class AbstractModel implements Model {
     public List<ByteBuffer> vectorization(Object[] fields) throws IOException {
         List<ByteBuffer> result = new ArrayList<>();
 
-        List<List<Double>> vectors = batchProcess(fields, singleVectorizedInputNumber);
-        for (List<Double> vector : vectors) {
-            result.add(BufferUtils.toByteBuffer(vector.toArray(new Double[0])));
+        List<List<Float>> vectors = batchProcess(fields, singleVectorizedInputNumber);
+        for (List<Float> vector : vectors) {
+            result.add(VectorUtils.toByteBuffer(vector.toArray(new Float[0])));
         }
         return result;
     }
 
-    protected abstract List<List<Double>> vector(Object[] fields) throws IOException;
+    protected abstract List<List<Float>> vector(Object[] fields) throws IOException;
 
-    public List<List<Double>> batchProcess(Object[] array, int batchSize) throws IOException {
-        List<List<Double>> merged = new ArrayList<>();
+    public List<List<Float>> batchProcess(Object[] array, int batchSize) throws IOException {
+        List<List<Float>> merged = new ArrayList<>();
         if (array == null || array.length == 0) {
             return merged;
         }
         for (int i = 0; i < array.length; i += batchSize) {
             Object[] batch = ArrayUtils.subarray(array, i, i + batchSize);
-            List<List<Double>> vector = vector(batch);
+            List<List<Float>> vector = vector(batch);
             merged.addAll(vector);
         }
         if (array.length != merged.size()) {
