@@ -27,8 +27,10 @@ import java.time.Instant;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
 import java.time.LocalTime;
+import java.time.OffsetDateTime;
 import java.time.Period;
 import java.time.ZoneId;
+import java.time.ZoneOffset;
 import java.time.format.DateTimeFormatter;
 import java.time.temporal.Temporal;
 import java.time.temporal.TemporalAccessor;
@@ -352,6 +354,9 @@ public class DateTimeFunction {
                 if (datetime instanceof LocalDateTime) {
                     return ((LocalDateTime) datetime).getYear();
                 }
+                if (datetime instanceof OffsetDateTime) {
+                    return ((OffsetDateTime) datetime).getYear();
+                }
                 break;
             case "MONTH":
                 if (datetime instanceof LocalDate) {
@@ -360,6 +365,9 @@ public class DateTimeFunction {
                 if (datetime instanceof LocalDateTime) {
                     return ((LocalDateTime) datetime).getMonthValue();
                 }
+                if (datetime instanceof OffsetDateTime) {
+                    return ((OffsetDateTime) datetime).getMonthValue();
+                }
                 break;
             case "DAY":
                 if (datetime instanceof LocalDate) {
@@ -368,6 +376,9 @@ public class DateTimeFunction {
                 if (datetime instanceof LocalDateTime) {
                     return ((LocalDateTime) datetime).getDayOfMonth();
                 }
+                if (datetime instanceof OffsetDateTime) {
+                    return ((OffsetDateTime) datetime).getDayOfMonth();
+                }
                 break;
             case "HOUR":
                 if (datetime instanceof LocalTime) {
@@ -376,6 +387,9 @@ public class DateTimeFunction {
                 if (datetime instanceof LocalDateTime) {
                     return ((LocalDateTime) datetime).getHour();
                 }
+                if (datetime instanceof OffsetDateTime) {
+                    return ((OffsetDateTime) datetime).getHour();
+                }
                 break;
             case "MINUTE":
                 if (datetime instanceof LocalTime) {
@@ -384,6 +398,9 @@ public class DateTimeFunction {
                 if (datetime instanceof LocalDateTime) {
                     return ((LocalDateTime) datetime).getMinute();
                 }
+                if (datetime instanceof OffsetDateTime) {
+                    return ((OffsetDateTime) datetime).getMinute();
+                }
                 break;
             case "SECOND":
                 if (datetime instanceof LocalTime) {
@@ -392,6 +409,9 @@ public class DateTimeFunction {
                 if (datetime instanceof LocalDateTime) {
                     return ((LocalDateTime) datetime).getSecond();
                 }
+                if (datetime instanceof OffsetDateTime) {
+                    return ((OffsetDateTime) datetime).getSecond();
+                }
                 break;
             case "MILLISECOND":
                 if (datetime instanceof LocalTime) {
@@ -400,11 +420,138 @@ public class DateTimeFunction {
                 if (datetime instanceof LocalDateTime) {
                     return ((LocalDateTime) datetime).getNano() / 1000_000;
                 }
+                if (datetime instanceof OffsetDateTime) {
+                    return ((OffsetDateTime) datetime).getNano() / 1000_000;
+                }
+                break;
+            case "MICROSECONDS":
+                if (datetime instanceof LocalTime) {
+                    return ((LocalTime) datetime).getNano() / 1000;
+                }
+                if (datetime instanceof LocalDateTime) {
+                    return ((LocalDateTime) datetime).getNano() / 1000;
+                }
+                if (datetime instanceof OffsetDateTime) {
+                    return ((OffsetDateTime) datetime).getNano() / 1000;
+                }
+                break;
+            case "EPOCH":
+                if (datetime instanceof LocalDateTime) {
+                    ZoneOffset offset = ZoneOffset.UTC;
+                    return (int) ((LocalDateTime) datetime).toEpochSecond(offset);
+                }
+                if (datetime instanceof LocalDate) {
+                    LocalDateTime ldt = LocalDateTime.of((LocalDate) datetime, LocalTime.MIDNIGHT);
+                    ZoneOffset offset = ZoneOffset.UTC;
+                    return (int) ldt.toEpochSecond(offset);
+                }
+                if (datetime instanceof OffsetDateTime) {
+                    return (int) ((OffsetDateTime) datetime).toEpochSecond();
+                }
+                break;
+            case "QUARTER":
+                if (datetime instanceof LocalDate) {
+                    int month = ((LocalDate) datetime).getMonthValue();
+                    return (month - 1) / 3 + 1;
+                }
+                if (datetime instanceof LocalDateTime) {
+                    int month = ((LocalDateTime) datetime).getMonthValue();
+                    return (month - 1) / 3 + 1;
+                }
+                if (datetime instanceof OffsetDateTime) {
+                    int month = ((OffsetDateTime) datetime).getMonthValue();
+                    return (month - 1) / 3 + 1;
+                }
+                break;
+            case "WEEK":
+                if (datetime instanceof LocalDate) {
+                    return datetime.get(WeekFields.ISO.weekOfYear());
+                }
+                if (datetime instanceof LocalDateTime) {
+                    return datetime.get(WeekFields.ISO.weekOfYear());
+                }
+                if (datetime instanceof OffsetDateTime) {
+                    return datetime.get(WeekFields.ISO.weekOfYear());
+                }
+                break;
+            case "CENTURY":
+                if (datetime instanceof LocalDate) {
+                    int year = ((LocalDate) datetime).getYear();
+                    return (year > 0) ? (year - 1) / 100 + 1 : year / 100;
+                }
+                if (datetime instanceof LocalDateTime) {
+                    int year = ((LocalDateTime) datetime).getYear();
+                    return (year > 0) ? (year - 1) / 100 + 1 : year / 100;
+                }
+                if (datetime instanceof OffsetDateTime) {
+                    int year = ((OffsetDateTime) datetime).getYear();
+                    return (year > 0) ? (year - 1) / 100 + 1 : year / 100;
+                }
+                break;
+            case "DECADE":
+                if (datetime instanceof LocalDate) {
+                    return ((LocalDate) datetime).getYear() / 10;
+                }
+                if (datetime instanceof LocalDateTime) {
+                    return ((LocalDateTime) datetime).getYear() / 10;
+                }
+                if (datetime instanceof OffsetDateTime) {
+                    return ((OffsetDateTime) datetime).getYear() / 10;
+                }
+                break;
+            case "DOW":
+                if (datetime instanceof LocalDate) {
+                    return ((LocalDate) datetime).getDayOfWeek().getValue() % 7;
+                }
+                if (datetime instanceof LocalDateTime) {
+                    return ((LocalDateTime) datetime).getDayOfWeek().getValue() % 7;
+                }
+                if (datetime instanceof OffsetDateTime) {
+                    return ((OffsetDateTime) datetime).getDayOfWeek().getValue() % 7;
+                }
+                break;
+            case "ISODOW":
+                if (datetime instanceof LocalDate) {
+                    return ((LocalDate) datetime).getDayOfWeek().getValue();
+                }
+                if (datetime instanceof LocalDateTime) {
+                    return ((LocalDateTime) datetime).getDayOfWeek().getValue();
+                }
+                break;
+            case "DOY":
+            case "DAYOFYEAR":
+                if (datetime instanceof LocalDate) {
+                    return ((LocalDate) datetime).getDayOfYear();
+                }
+                if (datetime instanceof LocalDateTime) {
+                    return ((LocalDateTime) datetime).getDayOfYear();
+                }
+                if (datetime instanceof OffsetDateTime) {
+                    return ((OffsetDateTime) datetime).getDayOfYear();
+                }
+                break;
+            case "ISOYEAR":
+                if (datetime instanceof LocalDate) {
+                    LocalDate date = (LocalDate) datetime;
+                    return date.get(WeekFields.ISO.weekBasedYear());
+                }
+                if (datetime instanceof LocalDateTime) {
+                    LocalDate date = ((LocalDateTime) datetime).toLocalDate();
+                    return date.get(WeekFields.ISO.weekBasedYear());
+                }
+                break;
+            case "MILLENNIUM":
+                if (datetime instanceof LocalDate) {
+                    int year = ((LocalDate) datetime).getYear();
+                    return (year > 0) ? (year - 1) / 1000 + 1 : year / 1000;
+                }
+                if (datetime instanceof LocalDateTime) {
+                    int year = ((LocalDateTime) datetime).getYear();
+                    return (year > 0) ? (year - 1) / 1000 + 1 : year / 1000;
+                }
                 break;
             case "DAYOFWEEK":
                 return dayOfWeek(args);
-            case "DAYOFYEAR":
-                return dayOfYear(args);
             default:
                 throw new TransformException(
                         CommonErrorCodeDeprecated.UNSUPPORTED_OPERATION,
@@ -554,10 +701,11 @@ public class DateTimeFunction {
     }
 
     public static String fromUnixTime(List<Object> args) {
-        Long unixTime = (Long) args.get(0);
-        if (unixTime == null) {
+        Object unixTimeObj = args.get(0);
+        if (unixTimeObj == null) {
             return null;
         }
+        long unixTime = ((Number) unixTimeObj).longValue();
         String format = (String) args.get(1);
         ZoneId zoneId = ZoneId.systemDefault();
         if (args.size() == 3) {
