@@ -34,6 +34,7 @@ import lombok.extern.slf4j.Slf4j;
 
 import java.io.IOException;
 import java.io.Serializable;
+import java.sql.DriverManager;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
@@ -49,6 +50,19 @@ import java.util.stream.Collectors;
 @Slf4j
 public class CoordinatedSource<T, SplitT extends SourceSplit, StateT extends Serializable>
         implements BaseSourceFunction<T> {
+
+    static {
+        // Load DriverManager first to avoid deadlock between DriverManager's
+        // static initialization block and specific driver class's static
+        // initialization block when two different driver classes are loading
+        // concurrently using Class.forName while DriverManager is uninitialized
+        // before.
+        //
+        // This could happen in JDK 8 but not above as driver loading has been
+        // moved out of DriverManager's static initialization block since JDK 9.
+        DriverManager.getDrivers();
+    }
+
     protected static final long SLEEP_TIME_INTERVAL = 5L;
     protected final SeaTunnelSource<T, SplitT, StateT> source;
     protected final Map<Integer, List<byte[]>> restoredState;
@@ -145,22 +159,16 @@ public class CoordinatedSource<T, SplitT extends SourceSplit, StateT extends Ser
                 (subtaskId, splits) -> {
                     splitEnumerator.addSplitsBack(splits, subtaskId);
                 });
-        readerMap
-                .entrySet()
-                .parallelStream()
-                .forEach(
-                        entry -> {
-                            try {
-                                entry.getValue().open();
-                                readerContextMap
-                                        .get(entry.getKey())
-                                        .getEventListener()
-                                        .onEvent(new ReaderOpenEvent());
-                                splitEnumerator.registerReader(entry.getKey());
-                            } catch (Exception e) {
-                                throw new RuntimeException(e);
-                            }
-                        });
+        readerMap.forEach(
+                (key, value) -> {
+                    try {
+                        value.open();
+                        readerContextMap.get(key).getEventListener().onEvent(new ReaderOpenEvent());
+                        splitEnumerator.registerReader(key);
+                    } catch (Exception e) {
+                        throw new RuntimeException(e);
+                    }
+                });
     }
 
     @Override
