@@ -37,6 +37,7 @@ import org.apache.flink.api.java.typeutils.ResultTypeQueryable;
 import org.apache.flink.core.io.SimpleVersionedSerializer;
 
 import java.io.Serializable;
+import java.sql.DriverManager;
 
 /**
  * The source implementation of {@link Source}, used for proxy all {@link SeaTunnelSource} in flink.
@@ -48,6 +49,30 @@ public class FlinkSource<SplitT extends SourceSplit, EnumStateT extends Serializ
         implements Source<SeaTunnelRow, SplitWrapper<SplitT>, EnumStateT>,
                 ResultTypeQueryable<SeaTunnelRow> {
 
+    static {
+        // Load DriverManager first to avoid deadlock between DriverManager's
+        // static initialization block and specific driver class's static
+        // initialization block when two different driver classes are loading
+        // concurrently using Class.forName while DriverManager is uninitialized
+        // before.
+        //
+        // This could happen in JDK 8 but not above as driver loading has been
+        // moved out of DriverManager's static initialization block since JDK 9.
+        DriverManager.getDrivers();
+    }
+
+    static {
+        // Load DriverManager first to avoid deadlock between DriverManager's
+        // static initialization block and specific driver class's static
+        // initialization block when two different driver classes are loading
+        // concurrently using Class.forName while DriverManager is uninitialized
+        // before.
+        //
+        // This could happen in JDK 8 but not above as driver loading has been
+        // moved out of DriverManager's static initialization block since JDK 9.
+        DriverManager.getDrivers();
+    }
+
     private final SeaTunnelSource<SeaTunnelRow, SplitT, EnumStateT> source;
 
     private final Config envConfig;
