@@ -19,6 +19,7 @@ package org.apache.seatunnel.translation.spark.source.scan;
 
 import org.apache.seatunnel.api.source.SeaTunnelSource;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
+import org.apache.seatunnel.translation.spark.execution.MultiTableManager;
 
 import org.apache.spark.sql.connector.read.Scan;
 import org.apache.spark.sql.connector.read.ScanBuilder;
@@ -33,20 +34,25 @@ public class SeaTunnelScanBuilder implements ScanBuilder {
 
     private final CaseInsensitiveStringMap caseInsensitiveStringMap;
 
+    private final MultiTableManager multiTableManager;
+
     public SeaTunnelScanBuilder(
             SeaTunnelSource<SeaTunnelRow, ?, ?> source,
             int parallelism,
             String jobId,
-            CaseInsensitiveStringMap caseInsensitiveStringMap) {
+            CaseInsensitiveStringMap caseInsensitiveStringMap,
+            MultiTableManager multiTableManager) {
         this.source = source;
         this.parallelism = parallelism;
         this.jobId = jobId;
         this.caseInsensitiveStringMap = caseInsensitiveStringMap;
+        this.multiTableManager = multiTableManager;
     }
 
     /** Returns the {@link SeaTunnelScan} */
     @Override
     public Scan build() {
-        return new SeaTunnelScan(source, parallelism, jobId, caseInsensitiveStringMap);
+        return new SeaTunnelScan(
+                source, parallelism, jobId, caseInsensitiveStringMap, multiTableManager);
     }
 }
